<?php
/**
 * Single Event Template
 * A single event. This displays the event title, description, meta, and
 * optionally, the Google map for the event.
 *
 * Override this template in your own theme by creating a file at [your-theme]/tribe-events/single-event.php
 *
 * @package TribeEventsCalendar
 * @version 4.2.4
 *
 */

if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}
global $post;
$event_id = get_the_ID();

$data    = \CHARTIO\Includes\Classes\Common::instance()->data( 'single' )->get();
$options = chartio_WSH()->option();


$event_thumbnail_id = get_post_thumbnail_id($event_id);
$event_thumbnail_url = wp_get_attachment_url($event_thumbnail_id);
$time_format          = get_option( 'time_format', Tribe__Date_Utils::TIMEFORMAT );
$start_datetime = tribe_get_start_date();
$start_date = tribe_get_start_date( null, false );

$start_date_d = tribe_get_start_date( null, false, 'd' );
$start_date_m = tribe_get_start_date( null, false, 'M' );
$start_date_y = tribe_get_start_date( null, false, 'Y' );

$start_time = tribe_get_start_date( null, false, $time_format );
$start_ts = tribe_get_start_date( null, false, Tribe__Date_Utils::DBDATEFORMAT );

$end_datetime = tribe_get_end_date();
$end_date = tribe_get_display_end_date( null, false );
$end_time = tribe_get_end_date( null, false, $time_format );
$end_ts = tribe_get_end_date( null, false, Tribe__Date_Utils::DBDATEFORMAT );

$location = tribe_get_venue(  );
$website = tribe_get_event_website_link();
$cost = tribe_get_formatted_cost();
?>

<!-- Page Title -->
<section class="page-title" style="background-image:url(<?php echo esc_url( $data->get( 'banner' ) ); ?>)">
    <div class="auto-container">
        <h1><?php if( $data->get( 'title' ) ) echo wp_kses( $data->get( 'title' ), true ); else( wp_title( '' ) ); ?></h1>
        <ul class="bread-crumb clearfix">
            <?php echo chartio_the_breadcrumb(); ?>
        </ul>
    </div>
</section>
<!-- End Page Title -->

<!-- Event Detail -->
<section class="event-detail">
    <div class="auto-container">
        <div class="row clearfix">
        	<?php 
				while ( have_posts() ) : the_post(); 
				$chartio_event_meta = get_post_meta( get_the_ID(), 'chartio_meta_event', true );
			?>
            <div class="event-detail_content-column col-lg-8 col-md-12 col-sm-12">
                <div class="event-detail_content-inner">
                    <div class="event-detail_image">
                        <?php the_post_thumbnail('chartio_1170x427'); ?>
                    </div>
                    <h2><?php the_title();?></h2>
                    <?php do_action( 'tribe_events_single_event_before_the_content' ) ?>
					<div class="text"><?php the_content();?></div>
                    <?php do_action( 'tribe_events_single_event_after_the_content' ) ?>
                    
                </div>
            </div>
            
            <?php do_action( 'tribe_events_single_meta_details_section_start' );?>
            
            <div class="event-detail_info-column col-lg-4 col-md-12 col-sm-12">
                <div class="event-detail_info-inner">
                    <h3><?php echo wp_kses($chartio_event_meta['event_info_heading'], true ); ?></h3>
                    <p><?php echo wp_kses($chartio_event_meta['event_info_text'], true ); ?></p>
                    <ul class="event-detail_info">
                        <li><span class="icon fas fa-calendar fa-fw"></span><?php echo wp_kses($start_date_d, true); ?> <?php echo wp_kses($start_date_m, true); ?> <?php echo wp_kses($start_date_y, true); ?></li>
                        <li><span class="icon fas fa-clock fa-fw"></span><?php echo wp_kses( $start_time, true ) ?> - <?php echo wp_kses( $end_time, true ) ?></li>
                        <li><span class="icon fas fa-map-marker-alt fa-fw"></span><?php echo wp_kses( $location, true );?></li>
                        <li><span class="icon fas fa-user fa-fw"></span><?php esc_html_e( 'Organized By : ', 'chartio' );?> <span><?php the_author(); ?></span></li>
                    </ul>
                    <div class="event-detail_register">
                        <h3><?php echo wp_kses($chartio_event_meta['event_form_title'], true ); ?></h3>
                        <!-- Default Form -->
                        <div class="default-form">
                            <?php echo do_shortcode($chartio_event_meta['event_form_url'], true ); ?>
                        </div>
                        <!-- End Default Form -->
                    </div>
                </div>
            </div>            
            <?php do_action( 'tribe_events_single_meta_details_section_end' ) ?>
            
            
			<?php endwhile; ?>
        </div>
    </div>
</section>
<!--End blog area-->
