<?php
namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Css_Filter;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class About_Image extends Widget_Base {
	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'chartio_about_image';
	}
	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Chartio About Image', 'chartio-plugin' );
	}
	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image-rollover';
	}
	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'chartio-plugin' ];
	}
	
	public function get_script_depends() {
		wp_register_script( 'about-carousels', YT_URL . 'assets/js/about-carousel.js', [ 'elementor-frontend' ], '1.0.0', true );
		return [ 'about-carousels' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'about_image',
			[
				'label' => esc_html__( 'Chartio About Image', 'chartio-plugin' ),
			]
		);
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'chartio-plugin' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'chartio-plugin'),
					'2' => esc_html__( 'Style Two ', 'chartio-plugin'),
				),
			]
		);
		
		$this->add_control(
			'image',
			[
				'label' => esc_html__( 'Choose Image', 'chartio-plugin' ),
				'type' => Controls_Manager::MEDIA,
				'condition'  => [ 'layout_control' => '2', ],
				'dynamic' => [	'active' => true, ],
				'default' => [	'url' => Utils::get_placeholder_image_src(),],
			]
		);
		
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'slide_img',
			[
				'label' => esc_html__( 'Choose Image', 'chartio-plugin' ),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [	'active' => true, ],
				'default' => [	'url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'slide_images',
			[
				'label'                 => __('Add Slider Images', 'chartio'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition'  => [ 'layout_control' => '1', ],
			]
		);
			
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'chartio-plugin' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title Here', 'chartio-plugin' ),
			]
		);
		$this->add_control(
            'title_link',
			[
				'label' => __( 'External Url', 'chartio' ),
				'type' => Controls_Manager::URL,
				'condition'  => [ 'layout_control' => '1', ],
				'label_block' => true, 
				'placeholder' => __( 'https://your-link.com', 'chartio' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Text', 'chartio-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text Here', 'chartio-plugin' ),
			]
		);
		
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'block_title',
			[
				'label' => esc_html__('Block Title', 'chartio'),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Block Title', 'chartio' ),
			]
		);
		$repeater->add_control(
			'block_value',
			[
				'label' => esc_html__('Value', 'chartio'),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Value', 'chartio' ),
			]
		);
		$this->add_control(
			'goals',
			[
				'label'                 => __('Add Goal Item', 'chartio'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition'  => [ 'layout_control' => '1', ],
			]
		);
		
		$this->add_control(		
			 'counter_start2',
			[
				'label'       => __( 'Counter Start Value', 'chartio-plugin' ),				
                'type'        => Controls_Manager::TEXT,
				'condition'  => [ 'layout_control' => '1', ],
				'label_block' => true, 				
				'dynamic'     => [				
					'active' => true,
				],				
				'placeholder' => __( 'Enter your Counter Start Value', 'chartio-plugin' ),
			]
		);
		$this->add_control(		
			 'counter_stop2',
			[
				'label'       => __( 'Counter Stop Value', 'chartio-plugin' ),				
                'type'        => Controls_Manager::TEXT,
				'condition'  => [ 'layout_control' => '1', ],
				'label_block' => true, 				
				'dynamic'     => [				
					'active' => true,
				],				
				'placeholder' => __( 'Enter your Counter Stop Value', 'chartio-plugin' ),
			]
		);
		$this->add_control(		
			 'alphabet_letter2',
			[
				'label'       => __( 'Alphabet Letter', 'chartio-plugin' ),				
                'type'        => Controls_Manager::TEXT,
				'condition'  => [ 'layout_control' => '1', ],
				'label_block' => true, 				
				'dynamic'     => [				
					'active' => true,
				],				
				'placeholder' => __( 'Enter your Alphabet Letter', 'chartio-plugin' ),
			]
		);
		$this->end_controls_section();		
	}
	/**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post'); 
		$layout = $settings[ 'layout_control' ];
	 ?>
		
        <?php if( $layout == 2 ):?>
		
        <div class="fund-one_content-column">
            <div class="fund-one_content-inner">
                <div class="fund-one_content-image">
                    <img src="<?php echo esc_url(wp_get_attachment_url($settings['image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image','chartio-plugin');?>" />
                </div>
                <div class="fund-one_content-title"><?php echo wp_kses($settings['title'], true);?></div>
                <h2 class="fund-one_heading"><?php echo wp_kses($settings['text'], true);?></h2>
            </div>
        </div>
        
		<?php else:?>
		
        <div class="org-block-column">
            <div class="org-block_inner wow fadeInLeft" data-wow-delay="0ms" data-wow-duration="1500ms">
                <!-- Org Block One -->
                <div class="org-block_one">
                    <div class="org-block_one-inner">
                        <div class="single-item-slider swiper-container">
                            <div class="swiper-wrapper">
                                <?php foreach($settings['slide_images'] as $key => $item):?>
                                <!-- Slide -->
                                <div class="swiper-slide">
                                    <div class="org-block_one-image">
                                        <img src="<?php echo esc_url(wp_get_attachment_url($item['slide_img']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image','chartio-plugin');?>" />
                                    </div>
                                </div>
                                <?php endforeach;?>
                            </div>
                            <div class="tx-pagination swiper-pagination"></div>
                        </div>
                        <div class="org-block_one-content">
                            <?php
                            	$this->add_link_attributes( 'title_link', $settings['title_link']);
							 ?>
                            <h3 class="org-block_one-heading"><a <?php echo $this->get_render_attribute_string( 'title_link' ); ?>><?php echo wp_kses($settings['title'], true);?></a></h3>
                            <div class="org-block_one-text"><?php echo wp_kses($settings['text'], true);?></div>
                            <div class="d-flex justify-content-between">
                                <?php foreach($settings['goals'] as $key => $item):?>
                                <div class="org-block_one-price">
                                    <?php echo wp_kses($item['block_title'], true);?>
                                    <strong><?php echo wp_kses($item['block_value'], true);?></strong>
                                </div>
                                <?php endforeach;?>
                            </div>
                            <div class="org-block_one_progress">
                                <div class="bar progress-line" data-width="<?php echo esc_attr($settings['counter_stop2']);?>"><div class="count-box"><span class="count-text" data-speed="2500" data-stop="<?php echo esc_attr($settings['counter_stop2']);?>"><?php echo esc_attr($settings['counter_start2']);?></span><?php echo esc_attr($settings['alphabet_letter2']);?></div></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    	
    <?php endif;
	}
}