<?php namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;
/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Accordian extends Widget_Base {
    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'chartio_accordian';
    }
    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Chartio Accordian', 'chartio' );
    }
    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-accordion';
    }
    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'chartio' ];
    }
	
	
    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'accordian',
            [
                'label' => esc_html__( 'Accordian', 'chartio' ),
            ]
        );
		
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'chartio'),
					'2' => esc_html__( 'Style Two ', 'chartio'),
				),
			]
		);
		
		//Our Slider		
		$repeater = new Repeater();
				
		$repeater->add_control(
			'block_title',
			[
				'label'       => __( 'Block Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'default' => esc_html__( 'Accordion Title', 'chartio' ),
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Block Title', 'chartio' ),
			]
		);
		
		$repeater->add_control(
			'block_text',
			[
				'label'       => __( 'Block Text', 'chartio' ),
				'type'        => Controls_Manager::WYSIWYG,
				'default' => esc_html__( 'Accordion Content', 'chartio' ),
				'show_label' => false,
			]
		);
		
		$this->add_control(
			'faqs',
			[
				'label'                 => __('Add Faqs Item', 'chartio'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'default' => [
					[
						'block_title' => esc_html__( 'Welcome to Charity', 'textdomain' ),
						'block_text' => esc_html__( 'Charity is the act of extending love and kindness to is a conscious act but the There are many variations the majority have suffered alteration', 'textdomain' ),
					],
					[
						'block_title' => esc_html__( 'Welcome to Charity', 'textdomain' ),
						'block_text' => esc_html__( 'Charity is the act of extending love and kindness to is a conscious act but the There are many variations the majority have suffered alteration', 'textdomain' ),
					],
					[
						'block_title' => esc_html__( 'Welcome to Charity', 'textdomain' ),
						'block_text' => esc_html__( 'Charity is the act of extending love and kindness to is a conscious act but the There are many variations the majority have suffered alteration', 'textdomain' ),
					],
					[
						'block_title' => esc_html__( 'Welcome to Charity', 'textdomain' ),
						'block_text' => esc_html__( 'Charity is the act of extending love and kindness to is a conscious act but the There are many variations the majority have suffered alteration', 'textdomain' ),
					],
				],
				'title_field' => '{{{ block_title }}}',
			]
		);
		
		$this->add_control(
            'selected_icon_show',
            [
                'label'        => esc_html__( 'Enable Icon', 'chartio' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'chartio' ),
                'label_off'    => esc_html__( 'Off', 'chartio' ),
                'return_value' => 'yes',
                'default'      => 'no',
            ]
        );
		
		$this->add_control(
			'selected_icon',
			[
				'label' => esc_html__( 'Icon', 'elementor' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'separator' => 'before',
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'fas fa-plus',
					'library' => 'fa-solid',
				],
				'recommended' => [
					'fa-solid' => [
						'chevron-down',
						'angle-down',
						'angle-double-down',
						'caret-down',
						'caret-square-down',
					],
					'fa-regular' => [
						'caret-square-down',
					],
				],
				'skin' => 'inline',
				'label_block' => false,
				'condition'   => [ 'selected_icon_show' => 'yes' ]
			]
		);
		
		$this->add_control(
            'selected_active_icon_show',
            [
                'label'        => esc_html__( 'Enable Active Icon', 'chartio' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'chartio' ),
                'label_off'    => esc_html__( 'Off', 'chartio' ),
                'return_value' => 'yes',
                'default'      => 'no',
            ]
        );

		$this->add_control(
			'selected_active_icon',
			[
				'label' => esc_html__( 'Active Icon', 'elementor' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'fa4compatibility' => 'icon_active',
				'default' => [
					'value' => 'fas fa-minus',
					'library' => 'fa-solid',
				],
				'recommended' => [
					'fa-solid' => [
						'chevron-up',
						'angle-up',
						'angle-double-up',
						'caret-up',
						'caret-square-up',
					],
					'fa-regular' => [
						'caret-square-up',
					],
				],
				'skin' => 'inline',
				'label_block' => false,
				'condition'   => [ 'selected_active_icon_show' => 'yes' ]
			]
		);
		
		$this->end_controls_section();
		
		//General Style
		$this->start_controls_section(
			'general_style',
			[
				'label' => esc_html__( 'General Setting', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
            'general_margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .chartio-accordion-item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'general_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .chartio-accordion-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'general_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '
					{{WRAPPER}} .accordion,
					{{WRAPPER}} .chartio-accordion-item',				
			]
		);
		
		$this->add_control(
			'general_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .chartio-accordion-item' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'general_box_border_type',
				'selector' => 
					'{{WRAPPER}} .chartio-accordion-item',				
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'general_box_shadow',
				'selector' => 
					'{{WRAPPER}} .chartio-accordion-item',				
				'separator' => 'before',
			]
		);
		$this->add_control(
			'general_border_radius',
			[
				'label' => esc_html__('Border Radius', 'chartio'),
				'type' => Controls_Manager::DIMENSIONS,
				'separator' => 'before',
				'size_units' => ['px'],
				'selectors' => [
					'{{WRAPPER}} .chartio-accordion-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .accordion' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
		
		//Title Style
		$this->start_controls_section(
			'title_style',
			[
				'label' => esc_html__( 'Title', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
            'title__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .accordion-button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'title_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .accordion-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'title_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .accordion-button',				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'title_active_bgtype',
				'label' => __( 'Active Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .accordion-button.active',				
			]
		);
		
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .accordion-button' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => '{{WRAPPER}} .accordion-button',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'title_text_shadow',
				'selector' => '{{WRAPPER}} .accordion-button',
			]
		);

		$this->end_controls_section();
		
		//Text Style
		
		$this->start_controls_section(
			'text_style',
			[
				'label' => esc_html__( 'Text', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
            'text__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .accordion-body' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'text_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .accordion-body' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_control(
			'text_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .accordion-body' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => '{{WRAPPER}} .accordion-body',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'text_text_shadow',
				'selector' => '{{WRAPPER}} .accordion-body',
			]
		);

		$this->end_controls_section();
		
	}
	
	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$layout = $settings[ 'layout_control' ];
	?>
    	
        <?php if( $layout == 2 ):?>
        
        <!-- Accordion Box -->
        <ul class="accordion-box style-two chartio-accordion-item">
            <?php $i = 1; foreach($settings['faqs'] as $key => $item):?>
            <!-- Block -->
            <li class="accordion block <?php if($i == 1) echo 'active-block';?>">
                <div class="acc-btn <?php if($i == 1) echo 'active';?> accordion-button">
                    <div class="icon-outer">
                        <?php if( $settings[ 'selected_icon_show' ] === 'yes' ):?>
							<?php \Elementor\Icons_Manager::render_icon( $settings['selected_icon'] ); ?>
                        <?php else:?>
                            <span class="icon icon-plus fa fa-plus"></span>
                        <?php endif;?>                        
                        
                        <?php if( $settings[ 'selected_active_icon_show' ] === 'yes' ):?>
							<?php \Elementor\Icons_Manager::render_icon( $settings['selected_active_icon'] ); ?>
                        <?php else:?>
                            <span class="icon icon-minus fa fa-minus"></span>
                        <?php endif;?>                        
                    </div>
                	<?php echo wp_kses($item['block_title'], true) ;?>
                </div>
                <div class="acc-content <?php if($i == 1) echo 'current';?>">
                    <div class="content">
                        <div class="text accordion-body"><?php $this->print_text_editor( $item['block_text'] ); ;?></div>
                    </div>
                </div>
            </li>
            <?php $i++; endforeach;?>
        </ul>
        
        <?php else:?>
        
        <!-- Accordion Box -->
        <ul class="accordion-box chartio-accordion-item">
            <?php $i = 1; foreach($settings['faqs'] as $key => $item):?>
            <!-- Block -->
            <li class="accordion block <?php if($i == 1) echo 'active-block';?>">
                <div class="acc-btn <?php if($i == 1) echo 'active';?> accordion-button">
                    <div class="icon-outer">
                        <?php if( $settings[ 'selected_icon_show' ] === 'yes' ):?>
							<?php \Elementor\Icons_Manager::render_icon( $settings['selected_icon'] ); ?>
                        <?php else:?>
                            <span class="icon icon-plus fa fa-plus"></span>
                        <?php endif;?>                        
                        
                        <?php if( $settings[ 'selected_active_icon_show' ] === 'yes' ):?>
							<?php \Elementor\Icons_Manager::render_icon( $settings['selected_active_icon'] ); ?>
                        <?php else:?>
                            <span class="icon icon-minus fa fa-minus"></span>
                        <?php endif;?>                        
                    </div>
                	<?php echo wp_kses($item['block_title'], true) ;?>
                </div>
                <div class="acc-content <?php if($i == 1) echo 'current';?>">
                    <div class="content">
                        <div class="text accordion-body"><?php $this->print_text_editor( $item['block_text'] ); ;?></div>
                    </div>
                </div>
            </li>
            <?php $i++; endforeach;?>
        </ul>
        
        <?php endif;?>
    <?php
    }
}