<?php namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;
/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Blog_Grid extends Widget_Base {
    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'chartio_blog_grid';
    }
    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Chartio Blog Grid', 'chartio' );
    }
    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-post-list';
    }
    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'chartio' ];
    }
    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'blog_grid',
            [
                'label' => esc_html__( 'Blog Grid', 'chartio' ),
            ]
        );
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'chartio'),
					'2' => esc_html__( 'Style Two ', 'chartio'),
					'3' => esc_html__( 'Style Three ', 'chartio'),
					'4' => esc_html__( 'Style Four ', 'chartio'),
					'5' => esc_html__( 'Style Five ', 'chartio'),
					'6' => esc_html__( 'Style Six ', 'chartio'),
				),
			]
		);
		$this->add_control(
            'cat',
            [
                'label'        => esc_html__( 'Show Category', 'chartio' ),
                'type'         => Controls_Manager::SWITCHER,
				'condition' => [ 'layout_control' => ['1', '2', '3', '4', '5'], ],
                'label_on'     => esc_html__( 'On', 'chartio' ),
                'label_off'    => esc_html__( 'Off', 'chartio' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );
		$this->add_control(
            'comment',
            [
                'label'        => esc_html__( 'Show Comment', 'chartio' ),
                'type'         => Controls_Manager::SWITCHER,
				'condition' => [ 'layout_control' => ['1', '2', '3', '4'], ],
                'label_on'     => esc_html__( 'On', 'chartio' ),
                'label_off'    => esc_html__( 'Off', 'chartio' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );
		$this->add_control(
            'date',
            [
                'label'        => esc_html__( 'Show Date', 'chartio' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'chartio' ),
                'label_off'    => esc_html__( 'Off', 'chartio' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );
		$this->add_control(
            'author',
            [
                'label'        => esc_html__( 'Show Author', 'chartio' ),
                'type'         => Controls_Manager::SWITCHER,
				'condition' => [ 'layout_control' => ['1', '2', '3', '4'], ],
                'label_on'     => esc_html__( 'On', 'chartio' ),
                'label_off'    => esc_html__( 'Off', 'chartio' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );
		$this->add_control(
			'btn_title',
			[
				'label' => esc_html__( 'Button Title', 'elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Enter button title', 'elementor' ),
				'default' => esc_html__( 'Read More', 'elementor' ),
			]
		);
		$this->add_control(
			'col_grid',
			[
				'label'   => esc_html__( 'Choose Column', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'default',
				'options' => array(
					'default'  => esc_html__( 'Default', 'chartio' ),
					'one' => esc_html__( 'One Column Grid ', 'chartio'),
					'two'  => esc_html__( 'Two Column Grid', 'chartio' ),
					'three'  => esc_html__( 'Three Column Grid', 'chartio' ),
					'four'  => esc_html__( 'Four Column Grid', 'chartio' ),
					'five'  => esc_html__( 'Six Column Grid', 'chartio' ),
				),
			]
		);
		$this->add_control(
            'text_limit',
            [
                'label'   => esc_html__( 'Text Limit', 'chartio' ),
                'type'    => Controls_Manager::NUMBER,
				'condition' => [ 'layout_control' => ['1', '2', '3', '4'], ],
                'default' => 25,
                'min'     => 1,
                'max'     => 100,
                'step'    => 1,
            ]
        );
		$this->add_control(
            'query_number',
            [
                'label'   => esc_html__( 'Number of post', 'chartio' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 5,
                'min'     => 1,
                'max'     => 100,
                'step'    => 1,
            ]
        );
        $this->add_control(
            'query_orderby',
            [
                'label'   => esc_html__( 'Order By', 'chartio' ),
				'label_block' => true,
                'type'    => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => array(
                    'date'       => esc_html__( 'Date', 'chartio' ),
                    'title'      => esc_html__( 'Title', 'chartio' ),
                    'menu_order' => esc_html__( 'Menu Order', 'chartio' ),
                    'rand'       => esc_html__( 'Random', 'chartio' ),
                ),
            ]
        );
        $this->add_control(
            'query_order',
            [
                'label'   => esc_html__( 'Order', 'chartio' ),
				'label_block' => true,
                'type'    => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => array(
                    'DESC' => esc_html__( 'DESC', 'chartio' ),
                    'ASC'  => esc_html__( 'ASC', 'chartio' ),
                ),
            ]
        );
        $this->add_control(
            'query_category',
            [
                'type' => Controls_Manager::SELECT,
                'label' => esc_html__('Category', 'chartio'),
				'label_block' => true,
                'options' => get_blog_categories(),
            ]
        );
		$this->add_control(
			'show_pagination',
			[
				'label'       => __( 'Enable/Disable Pagination Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'condition' => [ 'layout_control' => '5', ],
				'label_on' => __( 'Show', 'chartio' ),
				'label_off' => __( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		
		$this->end_controls_section();
		
		//General Style
		$this->start_controls_section(
			'general_style',
			[
				'label' => esc_html__( 'General Setting', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
            'general_margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .te-blog-card' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'general_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .te-blog-card' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'general_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .te-blog-card',				
			]
		);
		
		$this->add_control(
			'general_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .te-blog-card' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'general_text_shadow',
				'selector' => '{{WRAPPER}} .te-blog-card',
			]
		);

		$this->end_controls_section();
		
		//Small Title Style
		$this->start_controls_section(
			'small_title_style',
			[
				'label' => esc_html__( 'Meta Style Setting', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
            'small_title__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .blog-card-two__meta' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'small_title_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .blog-card-two__meta' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'small_title_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .blog-card-two__meta',				
			]
		);
		
		$this->add_control(
			'small_title_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .blog-card-two__meta' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'small_title_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => '{{WRAPPER}} .blog-card-two__meta',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'small_title_text_shadow',
				'selector' => '{{WRAPPER}} .blog-card-two__meta',
			]
		);

		$this->end_controls_section();
		
		//Category Style
		$this->start_controls_section(
			'cat_style',
			[
				'label' => esc_html__( 'Category Style Setting', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
            'cat__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .blog-card-three__category' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'cat_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .blog-card-three__category' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'cat_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .blog-card-three__category',				
			]
		);
		
		$this->add_control(
			'cat_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .blog-card-three__category' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cat_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => '{{WRAPPER}} .blog-card-three__category',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'cat_text_shadow',
				'selector' => '{{WRAPPER}} .blog-card-three__category',
			]
		);

		$this->end_controls_section();
		
		//Title Style
		
		$this->start_controls_section(
			'title_style',
			[
				'label' => esc_html__( 'Title', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
            'title__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .te-blog-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'title_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .te-blog-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'title_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .te-blog-title',				
			]
		);
		
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .te-blog-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => '{{WRAPPER}} .te-blog-title',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'title_text_shadow',
				'selector' => '{{WRAPPER}} .te-blog-title',
			]
		);

		$this->end_controls_section();
		
		/**Button Style**/
		$this->start_controls_section(
			'button_style',
			[
				'label' => esc_html__('Button Style Setting', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->start_controls_tabs( 'chartio_tabs_btn' );
		
			$this->start_controls_tab(
				'chartio_tab_btn_normal',
				[
					'label' => __( 'Normal', 'chartio' ),
				]
			);
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'btn_bgtype',
						'label' => __( 'Button Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .te-btn,
							 {{WRAPPER}} .faq-one__link',				
					]
				);
				$this->add_responsive_control(
					'btn_width_size',
					[
						'label' => __( 'Width', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'size_units' => [ 'px', 'em', '%', 'custom' ],
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 500,
							],
							'%' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .te-btn' => 'width: {{SIZE}}{{UNIT}};',
							'{{WRAPPER}} .faq-one__link' => 'width: {{SIZE}}{{UNIT}};',
						],
					]
				);
				$this->add_responsive_control(
					'btn_height_size',
					[
						'label' => __( 'Height', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'size_units' => [ 'px', 'em', '%', 'custom' ],
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 500,
							],
							'%' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .te-btn' => 'height: {{SIZE}}{{UNIT}};',
							'{{WRAPPER}} .faq-one__link' => 'height: {{SIZE}}{{UNIT}};',
						],
					]
				);
				$this->add_responsive_control(
					'btn_padding',
					[
						'label'              => __( 'Padding', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .te-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .faq-one__link' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_group_control(
					Group_Control_Border::get_type(),
					[
						'name' => 'btn_border_type',
						'selector' => 
							'{{WRAPPER}} .te-btn,
							 {{WRAPPER}} .faq-one__link',				
						'separator' => 'before',
					]
				);
				$this->add_group_control(
					Group_Control_Box_Shadow::get_type(),
					[
						'name' => 'border_box_shadow',
						'selector' => 
							'{{WRAPPER}} .te-btn,
							 {{WRAPPER}} .faq-one__link',				
						'separator' => 'before',
					]
				);
				$this->add_control(
					'btn_border_radius',
					[
						'label' => esc_html__('Border Radius', 'chartio'),
						'type' => Controls_Manager::DIMENSIONS,
						'separator' => 'before',
						'size_units' => ['px'],
						'selectors' => [
							'{{WRAPPER}} .te-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .faq-one__link' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);
				$this->add_group_control(
					Group_Control_Typography::get_type(),
					[
						'name' => 'btn_title_typography',
						'label' => __('Button Text Typography', 'chartio'),
						'selector' => 
							'{{WRAPPER}} .te-btn,
							 {{WRAPPER}} .faq-one__link',				
						'separator' => 'before',
					]
				);
				$this->add_control(
					'btn_title_color',
					[
						'label' => __('Button Text Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .te-btn' => 'color: {{VALUE}}',
							'{{WRAPPER}} .faq-one__link' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
			$this->end_controls_tab();
			
			$this->start_controls_tab(
				'chartio_tab_btn_hover',
				[
					'label' => __( 'Hover', 'chartio' ),
				]
			);
			
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'btn_hover_bg_bgtype',
						'label' => __( 'Button Hover Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .te-btn:hover,
							 {{WRAPPER}} .faq-one__link:hover',				
					]
				);
				$this->add_control(
					'btn_border_hover_color',
					[
						'label' => __('Button Border Hover Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .te-btn:hover' => 'border-color: {{VALUE}}',
							'{{WRAPPER}} .faq-one__link:hover' => 'border-color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
				$this->add_control(
					'btn_title_hover_color',
					[
						'label' => __('Button Text Hover Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .te-btn:hover' => 'color: {{VALUE}}',
							'{{WRAPPER}} .faq-one__link:hover' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
			
			$this->end_controls_tab();
			
		$this->end_controls_tabs();   
		$this->end_controls_section();
		
	}
	
	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		$cat = $settings[ 'cat' ];
		$coment = $settings[ 'comment' ];
		$date = $settings[ 'date' ];
		$author = $settings[ 'author' ];
		$btn_title = $settings[ 'btn_title' ]; 
		$layout = $settings[ 'layout_control' ];
		
		$grid_col = $settings[ 'col_grid' ];
		if( $grid_col == 'one' ){
			$classes = 'col-lg-12 col-md-12 col-sm-12';
		}elseif( $grid_col == 'two' ){
			$classes = 'col-lg-6 col-md-6 col-sm-12';
		}elseif( $grid_col == 'three' ){
			$classes = 'col-lg-4 col-md-4 col-sm-12';
		}elseif( $grid_col == 'four' ){
			$classes = 'col-lg-3 col-md-4 col-sm-12';
		}elseif( $grid_col == 'five' ){
			$classes = 'col-lg-2 col-md-4 col-sm-12';
		}else{
			$classes = 'col-lg-4 col-md-6 col-sm-12';
		}
		
		$paged = get_query_var('paged');
		$paged = chartio_set($_REQUEST, 'paged') ? esc_attr($_REQUEST['paged']) : $paged;
        $this->add_render_attribute( 'wrapper', 'class', 'templatepath-greenture' );
        $args = array(
            'post_type'      => 'post',
            'posts_per_page' => chartio_set( $settings, 'query_number' ),
            'orderby'        => chartio_set( $settings, 'query_orderby' ),
            'order'          => chartio_set( $settings, 'query_order' ),
            'paged'         => $paged
        );
        if( chartio_set( $settings, 'query_category' ) ) $args['category_name'] = chartio_set( $settings, 'query_category' );
        $query = new \WP_Query( $args );
		if ( $query->have_posts() ) { 
	?>
    	
    	<?php if( $layout == 6 ):?>
		
        <div class="row clearfix">
			<?php while ( $query->have_posts() ) : $query->the_post(); ?>
            <!-- News Block Six -->
            <div class="news-block_six <?php echo esc_attr( $classes );?>">
                <div class="news-block_six-inner wow fadeInLeft" data-wow-delay="0ms" data-wow-duration="1500ms">
                    <div class="news-block_six-image">
                        <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_post_thumbnail('chartio_595x335'); ?></a>
                    </div>
                    <div class="news-block_six-lower">
                        <div class="news-block_six-content">
                            <?php if( $date == 'yes' ){?>
                            <div class="news-block_six-date"><?php echo get_the_date('d'); ?> <span><?php echo get_the_date('M'); ?></span></div>
                            <?php }; ?>
                            <h4 class="news-block_six-heading"><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h4>
                        </div>
                    </div>
                </div>
            </div>
            <?php endwhile; ?>
		</div>
        
		<?php elseif( $layout == 5 ):?>
        
        <!-- News Four -->
        <section class="news-four p-0 m-0">               
            <div class="row clearfix">
                <?php while ( $query->have_posts() ) : $query->the_post(); ?>
                <!-- News Block Four -->
                <div class="news-block_four <?php echo esc_attr( $classes );?>">
                    <div class="news-block_four-inner">
                        <div class="news-block_four-image">
                            <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_post_thumbnail('chartio_390x284'); ?></a>
                        </div>
                        <div class="news-block_four-content">
                            <div class="news-block_four-upper">
                                <div class="d-flex justify-content-between align-items-center flex-wrap">
                                    <?php if( $date == 'yes' ){?>
                                    <div class="news-block_four-date"><?php echo get_the_date( ); ?></div>
                                    <?php };?>
                                    <div class="news-block_four-button">
                                        <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>" class="theme-btn btn-style-four">
                                            <span class="btn-wrap">
                                                <span class="text-one">
													<?php if( !empty( $btn_title ) ):?>
                                                        <?php echo wp_kses( $btn_title, true );?>
                                                    <?php else:?>
                                                        <?php esc_html_e('read more ', 'chartio');?>
                                                    <?php endif;?>
                                                    <i class="fas fa-arrow-right fa-fw"></i>
                                                </span>
                                                <span class="text-two">
                                                    <?php if( !empty( $btn_title ) ):?>
                                                        <?php echo wp_kses( $btn_title, true );?>
                                                    <?php else:?>
                                                        <?php esc_html_e('read more ', 'chartio');?>
                                                    <?php endif;?>
                                                    <i class="fas fa-arrow-right fa-fw"></i>
                                                </span>
                                            </span>
                                        </a>
                                    </div>
                                </div>
                            </div>
                            <h4 class="news-block_four-heading"><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h4>
                        </div>
                    </div>
                </div>
                <?php endwhile; ?>    
            </div>
			<?php if($settings['show_pagination']) { ?>
            <!-- Styled Pagination -->
            <div class="styled-pagination text-center">
            	<?php chartio_the_pagination2(array('total'=>$query->max_num_pages, 'next_text' => '<span class="fa fa-angle-double-right"></span>', 'prev_text' => '<span class="fa fa-angle-double-left"></span>')); ?>
            </div>
            <!-- End Styled Pagination --> 
            <?php } ?>         
        </section>
        <!-- End News Four -->
        
		<?php elseif( $layout == 4 ):?>
        
        <?php $count = 0; while ( $query->have_posts() ) : $query->the_post(); ?>        
        <?php if($count % 2) { ?>
        <!-- News Block One -->
        <div class="news-block_one style-two alternate">
            <div class="news-block_one-inner">
                <div class="row clearfix">	
					
                    <!-- Content Column -->
                    <div class="news-block_one-content-column col-lg-5 col-md-12 col-sm-12">
                        <div class="news-block_one-content">
                            <div class="news-block_one-upper">
                                <?php if( $date == 'yes' ){?>
                                <div class="news-block_one-date"><?php echo get_the_date('d'); ?> <span><?php echo get_the_date('M'); ?>, <?php echo get_the_date('Y'); ?></span></div>
                                <?php };?>
                                <h3 class="news-block_one-heading"><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h3>
                                <?php if( $coment == 'yes' || $author == 'yes' ){?>
                                <ul class="news-block_one-meta">
                                    <?php if( $author == 'yes' ){?>
                                    <li><span class="icon fas fa-user-circle fa-fw"></span><?php the_author(); ?></li>
                                    <?php };?>
									<?php if( $coment == 'yes' ){?>
                                    <li><span class="icon fas fa-comments-dollar fa-fw"></span><?php comments_number( wp_kses(__('0 Comments' , 'chartio'), true), wp_kses(__('1 Comment' , 'chartio'), true), wp_kses(__('0% Comments' , 'chartio'), true)); ?></li>
                                	<?php };?>
                                </ul>
                                <?php };?>
                            </div>
                            <div class="news-block_one-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                            <div class="news-block_one-button">
                                <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>" class="theme-btn btn-style-four">
                                    <span class="btn-wrap">
                                        <span class="text-one">
                                            <?php if( !empty( $btn_title ) ):?>
                                                <?php echo wp_kses( $btn_title, true );?>
                                            <?php else:?>
                                                <?php esc_html_e('donate now ', 'chartio');?>
                                            <?php endif;?>
                                            <i class="fas fa-arrow-right fa-fw"></i>
                                        </span>
                                        <span class="text-two">
                                            <?php if( !empty( $btn_title ) ):?>
                                                <?php echo wp_kses( $btn_title, true );?>
                                            <?php else:?>
                                                <?php esc_html_e('donate now ', 'chartio');?>
                                            <?php endif;?>
                                            <i class="fas fa-arrow-right fa-fw"></i>
                                        </span>
                                    </span>
                                </a>
                            </div>
                        </div>
                    </div>
                    
                    <!-- Image Column -->
                    <div class="news-block_one-image-column col-lg-7 col-md-12 col-sm-12">
                        <div class="news-block_one-image-inner">
                            <div class="news-block_one-image">
                                <?php the_post_thumbnail('chartio_699x412'); ?>
                                <?php the_post_thumbnail('chartio_699x412'); ?>
                            </div>
                        </div>
                    </div>
                    
                </div>
            </div>
        </div>
        
        <?php } else { ?>
        
        
        <!-- News Block One -->
        <div class="news-block_one alternate">
            <div class="news-block_one-inner">
                <div class="row clearfix">

                    <!-- Image Column -->
                    <div class="news-block_one-image-column col-lg-7 col-md-12 col-sm-12">
                        <div class="news-block_one-image-inner">
                            <div class="news-block_one-image">
                                <?php the_post_thumbnail('chartio_699x412'); ?>
                                <?php the_post_thumbnail('chartio_699x412'); ?>
                            </div>
                        </div>
                    </div>

                    <!-- Content Column -->
                    <div class="news-block_one-content-column col-lg-5 col-md-12 col-sm-12">
                        <div class="news-block_one-content">
                            <div class="news-block_one-upper">
                                <?php if( $date == 'yes' ){?>
                                <div class="news-block_one-date"><?php echo get_the_date('d'); ?> <span><?php echo get_the_date('M'); ?>, <?php echo get_the_date('Y'); ?></span></div>
                                <?php };?>
                                <h3 class="news-block_one-heading"><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h3>
                                <?php if( $coment == 'yes' || $author == 'yes' ){?>
                                <ul class="news-block_one-meta">
                                    <?php if( $author == 'yes' ){?>
                                    <li><span class="icon fas fa-user-circle fa-fw"></span><?php the_author(); ?></li>
                                    <?php };?>
									<?php if( $coment == 'yes' ){?>
                                    <li><span class="icon fas fa-comments-dollar fa-fw"></span><?php comments_number( wp_kses(__('0 Comments' , 'chartio'), true), wp_kses(__('1 Comment' , 'chartio'), true), wp_kses(__('0% Comments' , 'chartio'), true)); ?></li>
                                	<?php };?>
                                </ul>
                                <?php };?>
                            </div>
                            <div class="news-block_one-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                            <div class="news-block_one-button">
                                <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>" class="theme-btn btn-style-four">
                                    <span class="btn-wrap">
                                        <span class="text-one">
                                            <?php if( !empty( $btn_title ) ):?>
                                                <?php echo wp_kses( $btn_title, true );?>
                                            <?php else:?>
                                                <?php esc_html_e('donate now ', 'chartio');?>
                                            <?php endif;?>
                                            <i class="fas fa-arrow-right fa-fw"></i>
                                        </span>
                                        <span class="text-two">
                                            <?php if( !empty( $btn_title ) ):?>
                                                <?php echo wp_kses( $btn_title, true );?>
                                            <?php else:?>
                                                <?php esc_html_e('donate now ', 'chartio');?>
                                            <?php endif;?>
                                            <i class="fas fa-arrow-right fa-fw"></i>
                                        </span>
                                    </span>
                                </a>
                            </div>
                        </div>
                    </div>

                </div>
            </div>
        </div>
        <?php } ?>
        
		<?php $count++; endwhile; ?>        
    	
        <?php elseif( $layout == 2 ):?>
        	
        <?php while ( $query->have_posts() ) : $query->the_post(); ?>    
        <!-- News Block Two -->
        <div class="news-block_two">
            <div class="news-block_two-inner">
                <div class="row clearfix">
                    <div class="news-block_two-content col-lg-6 col-md-6 col-sm-12">
                        <div class="news-block_two-content-inner">
                            <?php if( $cat == 'yes' ){?>
                            <div class="news-block_two-title"><?php the_category(' '); ?></div>
                            <?php };?>
                            <h4 class="news-block_two-heading"><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h4>
                            <?php if( $coment == 'yes' || $date == 'yes' ){?>
                            <ul class="news-block_two-meta">
                                <?php if( $coment == 'yes' ){?>
                                <li><span class="icon fas fa-comments fa-fw"></span><?php comments_number( wp_kses(__('0 Comments' , 'chartio'), true), wp_kses(__('01 Comment' , 'chartio'), true), wp_kses(__('0% Comments' , 'chartio'), true)); ?></li>
                                <?php };?>
                                <?php if( $date == 'yes' ){?>
                                <li><span class="icon fas fa-heart fa-fw"></span><?php echo get_the_date( ); ?></li>
                                <?php };?>
                            </ul>
                            <?php };?>
                            <div class="news-block_two-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                            <!-- Button -->
                            <div class="news-block_two-button">
                                <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>" class="theme-btn btn-style-four">
                                    <span class="btn-wrap">
                                        <span class="text-one">
                                        	<?php if( !empty( $btn_title ) ):?>
												<?php echo wp_kses( $btn_title, true );?>
                                            <?php else:?>
                                                <?php esc_html_e('Join Events ', 'chartio');?>
                                            <?php endif;?>
                                            <i class="fas fa-arrow-right fa-fw"></i>
                                        </span>
                                        <span class="text-two">
                                        	<?php if( !empty( $btn_title ) ):?>
												<?php echo wp_kses( $btn_title, true );?>
                                            <?php else:?>
                                                <?php esc_html_e('Join Events ', 'chartio');?>
                                            <?php endif;?>
                                            <i class="fas fa-arrow-right fa-fw"></i>
                                        </span>
                                    </span>
                                </a>
                            </div>
                        </div>
                    </div>
                    <div class="news-block_two-image col-lg-6 col-md-6 col-sm-12">
                        <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_post_thumbnail('chartio_390x470'); ?></a>
                    </div>
                </div>
            </div>
        </div>
        <?php endwhile; ?>
            
        <?php elseif( $layout == 3 ):?>
        
				<?php while ( $query->have_posts() ) : $query->the_post(); ?>
                <!-- News Block Three -->
                <div class="news-block_three">
                    <div class="news-block_three-inner">                
                        <?php if( $cat == 'yes' ){?>
                        <div class="news-block_three-title"><?php the_category(' '); ?></div>
                        <?php };?>
                        <h4 class="news-block_three-heading"><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h4>
                        <?php if( $coment == 'yes' || $date == 'yes' ){?>
                        <ul class="news-block_three-meta">
                            <?php if( $coment == 'yes' ){?>
                            <li><span class="icon fas fa-comments fa-fw"></span><?php comments_number( wp_kses(__('0 Comments' , 'chartio'), true), wp_kses(__('01 Comment' , 'chartio'), true), wp_kses(__('0% Comments' , 'chartio'), true)); ?></li>
                            <?php };?>
                            <?php if( $date == 'yes' ){?>
                            <li><span class="icon fas fa-heart fa-fw"></span><?php echo get_the_date( ); ?></li>
                            <?php };?>
                        </ul>
                        <?php };?>
                    </div>
                </div>
                <?php endwhile; ?>	
        
		
		<?php else:?>
           
        
        <?php $count = 0; while ( $query->have_posts() ) : $query->the_post(); ?>        
        <?php if($count % 2) { ?>
        <!-- News Block One -->
        <div class="news-block_one style-two">
            <div class="news-block_one-inner">
                <div class="row clearfix">
					
                    <!-- Content Column -->
                    <div class="news-block_one-content-column col-lg-5 col-md-12 col-sm-12">
                        <div class="news-block_one-content">
                            <div class="news-block_one-upper">
                                <?php if( $date == 'yes' ){?>
                                <div class="news-block_one-date"><?php echo get_the_date('d'); ?> <span><?php echo get_the_date('M'); ?>, <?php echo get_the_date('Y'); ?></span></div>
                                <?php };?>
                                <h3 class="news-block_one-heading"><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h3>
                                <?php if( $coment == 'yes' || $author == 'yes' ){?>
                                <ul class="news-block_one-meta">
                                    <?php if( $author == 'yes' ){?>
                                    <li><span class="icon fas fa-user-circle fa-fw"></span><?php the_author(); ?></li>
                                    <?php };?>
									<?php if( $coment == 'yes' ){?>
                                    <li><span class="icon fas fa-comments-dollar fa-fw"></span><?php comments_number( wp_kses(__('0 Comments' , 'chartio'), true), wp_kses(__('1 Comment' , 'chartio'), true), wp_kses(__('0% Comments' , 'chartio'), true)); ?></li>
                                	<?php };?>
                                </ul>
                                <?php };?>
                            </div>
                            <div class="news-block_one-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                            <div class="news-block_one-button">
                                <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>" class="theme-btn btn-style-one">
                                    <span class="btn-wrap">
                                        <span class="text-one">
                                            <?php if( !empty( $btn_title ) ):?>
                                                <?php echo wp_kses( $btn_title, true );?>
                                            <?php else:?>
                                                <?php esc_html_e('donate now ', 'chartio');?>
                                            <?php endif;?>
                                        </span>
                                        <span class="text-two">
                                            <?php if( !empty( $btn_title ) ):?>
                                                <?php echo wp_kses( $btn_title, true );?>
                                            <?php else:?>
                                                <?php esc_html_e('donate now ', 'chartio');?>
                                            <?php endif;?>
                                        </span>
                                    </span>
                                </a>
                            </div>
                        </div>
                    </div>
                    
                    <!-- Image Column -->
                    <div class="news-block_one-image-column col-lg-7 col-md-12 col-sm-12">
                        <div class="news-block_one-image-inner">
                            <div class="news-block_one-image">
                                <?php the_post_thumbnail('chartio_699x412'); ?>
                                <?php the_post_thumbnail('chartio_699x412'); ?>
                            </div>
                        </div>
                    </div>
                    
                </div>
            </div>
        </div>
        
        <?php } else { ?>
        
        
        <!-- News Block One -->
        <div class="news-block_one">
            <div class="news-block_one-inner">
                <div class="row clearfix">

                    <!-- Image Column -->
                    <div class="news-block_one-image-column col-lg-7 col-md-12 col-sm-12">
                        <div class="news-block_one-image-inner">
                            <div class="news-block_one-image">
                                <?php the_post_thumbnail('chartio_699x412'); ?>
                                <?php the_post_thumbnail('chartio_699x412'); ?>
                            </div>
                        </div>
                    </div>

                    <!-- Content Column -->
                    <div class="news-block_one-content-column col-lg-5 col-md-12 col-sm-12">
                        <div class="news-block_one-content">
                            <div class="news-block_one-upper">
                                <?php if( $date == 'yes' ){?>
                                <div class="news-block_one-date"><?php echo get_the_date('d'); ?> <span><?php echo get_the_date('M'); ?>, <?php echo get_the_date('Y'); ?></span></div>
                                <?php };?>
                                <h3 class="news-block_one-heading"><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h3>
                                <?php if( $coment == 'yes' || $author == 'yes' ){?>
                                <ul class="news-block_one-meta">
                                    <?php if( $author == 'yes' ){?>
                                    <li><span class="icon fas fa-user-circle fa-fw"></span><?php the_author(); ?></li>
                                    <?php };?>
									<?php if( $coment == 'yes' ){?>
                                    <li><span class="icon fas fa-comments-dollar fa-fw"></span><?php comments_number( wp_kses(__('0 Comments' , 'chartio'), true), wp_kses(__('1 Comment' , 'chartio'), true), wp_kses(__('0% Comments' , 'chartio'), true)); ?></li>
                                	<?php };?>
                                </ul>
                                <?php };?>
                            </div>
                            <div class="news-block_one-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                            <div class="news-block_one-button">
                                <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>" class="theme-btn btn-style-one">
                                    <span class="btn-wrap">
                                        <span class="text-one">
                                            <?php if( !empty( $btn_title ) ):?>
                                                <?php echo wp_kses( $btn_title, true );?>
                                            <?php else:?>
                                                <?php esc_html_e('donate now ', 'chartio');?>
                                            <?php endif;?>
                                        </span>
                                        <span class="text-two">
                                            <?php if( !empty( $btn_title ) ):?>
                                                <?php echo wp_kses( $btn_title, true );?>
                                            <?php else:?>
                                                <?php esc_html_e('donate now ', 'chartio');?>
                                            <?php endif;?>
                                        </span>
                                    </span>
                                </a>
                            </div>
                        </div>
                    </div>

                </div>
            </div>
        </div>
        <?php } ?>
        
		<?php $count++; endwhile; ?>
                
        <?php endif;?>
    
      <?php }
		wp_reset_postdata();
	}
}