<?php namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;
/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Button extends Widget_Base {
    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'chartio_button';
    }
    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Chartio Button', 'chartio' );
    }
    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-button';
    }
    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'chartio' ];
    }
    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'button',
            [
                'label' => esc_html__( 'Button', 'chartio' ),
            ]
        );
		
		$this->add_control(
			'btn_style',
			[
				'label'   => esc_html__( 'Choose Button Style', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'chartio'),
					'2' => esc_html__( 'Style Two', 'chartio' ),
					'3' => esc_html__( 'Style Three', 'chartio' ),
					'4' => esc_html__( 'Style Four', 'chartio' ),
				),
			]
		);
		
		$this->add_responsive_control(
			'btn_align',
			[
				'label' => esc_html__( 'Alignment', 'elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'elementor' ),
						'icon' => 'eicon-text-align-justify',
					],
				],
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .yt-btn' => 'text-align: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'btn_title',
			[
				'label'       => __( 'Button Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title Here', 'chartio' ),
			]
		);
		
		$this->add_control(
            'btn_link',
			[
				'label' => __( 'Button Url', 'chartio' ),
				'type' => Controls_Manager::URL,
				'label_block' => true, 
				'placeholder' => __( 'https://your-link.com', 'chartio' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);		
		
		$this->end_controls_section();
		
		/**Button Style**/
		$this->start_controls_section(
			'button_style',
			[
				'label' => esc_html__('Button Style Setting', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->start_controls_tabs( 'chartio_tabs_btn' );
		
			$this->start_controls_tab(
				'chartio_tab_btn_normal',
				[
					'label' => __( 'Normal', 'chartio' ),
				]
			);
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'btn_bgtype',
						'label' => __( 'Button Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .thm-btn,
							 {{WRAPPER}} .faq-one__link',				
					]
				);
				$this->add_responsive_control(
					'btn_width_size',
					[
						'label' => __( 'Width', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'size_units' => [ 'px', 'em', '%', 'custom' ],
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 500,
							],
							'%' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .thm-btn' => 'width: {{SIZE}}{{UNIT}};',
							'{{WRAPPER}} .faq-one__link' => 'width: {{SIZE}}{{UNIT}};',
						],
					]
				);
				$this->add_responsive_control(
					'btn_height_size',
					[
						'label' => __( 'Height', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'size_units' => [ 'px', 'em', '%', 'custom' ],
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 500,
							],
							'%' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .thm-btn' => 'height: {{SIZE}}{{UNIT}};',
							'{{WRAPPER}} .faq-one__link' => 'height: {{SIZE}}{{UNIT}};',
						],
					]
				);
				$this->add_responsive_control(
					'btn_padding',
					[
						'label'              => __( 'Padding', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .thm-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .faq-one__link' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_responsive_control(
					'btn_margin',
					[
						'label'              => __( 'Margin', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .yt-btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_group_control(
					Group_Control_Border::get_type(),
					[
						'name' => 'btn_border_type',
						'selector' => 
							'{{WRAPPER}} .thm-btn,
							 {{WRAPPER}} .faq-one__link',				
						'separator' => 'before',
					]
				);
				$this->add_group_control(
					Group_Control_Box_Shadow::get_type(),
					[
						'name' => 'border_box_shadow',
						'selector' => 
							'{{WRAPPER}} .thm-btn,
							 {{WRAPPER}} .faq-one__link',				
						'separator' => 'before',
					]
				);
				$this->add_control(
					'btn_border_radius',
					[
						'label' => esc_html__('Border Radius', 'chartio'),
						'type' => Controls_Manager::DIMENSIONS,
						'separator' => 'before',
						'size_units' => ['px'],
						'selectors' => [
							'{{WRAPPER}} .thm-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .faq-one__link' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);
				$this->add_group_control(
					Group_Control_Typography::get_type(),
					[
						'name' => 'btn_title_typography',
						'label' => __('Button Text Typography', 'chartio'),
						'selector' => 
							'{{WRAPPER}} .thm-btn,
							 {{WRAPPER}} .thm-btn .text-one,				
							 {{WRAPPER}} .thm-btn .text-two',	
						'separator' => 'before',
					]
				);
				$this->add_control(
					'btn_title_color',
					[
						'label' => __('Button Text Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .thm-btn' => 'color: {{VALUE}}',
							'{{WRAPPER}} .thm-btn .text-one' => 'color: {{VALUE}}',
							'{{WRAPPER}} .thm-btn .text-two' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
			$this->end_controls_tab();
			
			$this->start_controls_tab(
				'chartio_tab_btn_hover',
				[
					'label' => __( 'Hover', 'chartio' ),
				]
			);
			
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'btn_hover_bg_bgtype',
						'label' => __( 'Button Hover Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .thm-btn:hover,
							 {{WRAPPER}} .thm-btn:before',				
					]
				);
				$this->add_control(
					'btn_border_hover_color',
					[
						'label' => __('Button Border Hover Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .thm-btn:hover' => 'border-color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
				$this->add_control(
					'btn_title_hover_color',
					[
						'label' => __('Button Text Hover Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .thm-btn:hover' => 'color: {{VALUE}}',
							'{{WRAPPER}} .thm-btn:hover .text-one' => 'color: {{VALUE}}',
							'{{WRAPPER}} .thm-btn:hover .text-two' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
			
			$this->end_controls_tab();
			
		$this->end_controls_tabs();   
		$this->end_controls_section();
		
	}
	
	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		
		$btn_style = $settings[ 'btn_style' ];
		if( $btn_style == '1' ){
			$classes = 'thm-btn theme-btn btn-style-one';
		}elseif( $btn_style == '2' ){
			$classes = 'thm-btn theme-btn btn-style-four';
		}elseif( $btn_style == '3' ){
			$classes = 'thm-btn theme-btn btn-style-three';
		}elseif( $btn_style == '4' ){
			$classes = 'thm-btn theme-btn btn-style-seven';
		}else{
			$classes = 'thm-btn theme-btn btn-style-one';
		}
	
	?>
    	<?php if($btn_style == 4) :?>
        
        <?php if($settings['btn_title']){ ?>
        <!-- News Five Button -->
        <div class="news-five_button yt-btn">
            <?php         	
			   $this->add_link_attributes( 'btn_link', $settings['btn_link']);
			?>
            <a <?php echo $this->get_render_attribute_string( 'btn_link' ); ?> class="<?php echo esc_attr( $classes );?>">
                <span class="btn-wrap">
                    <span class="text-one"><?php echo wp_kses($settings['btn_title'], true);?> <i class="fas fa-arrow-circle-right fa-fw"></i></span>
                    <span class="text-two"><?php echo wp_kses($settings['btn_title'], true);?> <i class="fas fa-arrow-circle-right fa-fw"></i></span>
                </span>
            </a>
        </div>
        <?php } ?>
        
		<?php elseif($btn_style == 3) :?>
		
        <?php if($settings['btn_title']){ ?>
        <div class="org-one_button yt-btn">
            <?php         	
			   $this->add_link_attributes( 'btn_link', $settings['btn_link']);
			?>
            <a <?php echo $this->get_render_attribute_string( 'btn_link' ); ?> class="<?php echo esc_attr( $classes );?>">
                <span class="btn-wrap">
                    <span class="text-one"><?php echo wp_kses($settings['btn_title'], true);?> <i class="fas fa-arrow-right fa-fw"></i></span>
                    <span class="text-two"><?php echo wp_kses($settings['btn_title'], true);?> <i class="fas fa-arrow-right fa-fw"></i></span>
                </span>
            </a>
        </div>
        <?php } ?>
		
		<?php elseif($btn_style == 2) :?>
        
        <?php if($settings['btn_title']){ ?>
        <div class="inspire-one_lower-box">
            <div class="inspire-one_button yt-btn">
                <?php         	
                   $this->add_link_attributes( 'btn_link', $settings['btn_link']);
                 ?>
                <a <?php echo $this->get_render_attribute_string( 'btn_link' ); ?> class="<?php echo esc_attr( $classes );?>">
                    <span class="btn-wrap">
                        <span class="text-one"><?php echo wp_kses($settings['btn_title'], true);?> <i class="fas fa-arrow-right fa-fw"></i></span>
                        <span class="text-two"><?php echo wp_kses($settings['btn_title'], true);?> <i class="fas fa-arrow-right fa-fw"></i></span>
                    </span>
                </a>
            </div>
        </div>
        <?php } ?>
        
    	<?php else: ?>
        
        <?php if($settings['btn_title']){ ?>
        <div class="welcome-one_button-box yt-btn">
            <?php         	
		       $this->add_link_attributes( 'btn_link', $settings['btn_link']);
		     ?>
            <a <?php echo $this->get_render_attribute_string( 'btn_link' ); ?> class="<?php echo esc_attr( $classes );?>">
                <span class="btn-wrap">
                    <span class="text-one"><?php echo wp_kses($settings['btn_title'], true);?></span>
                    <span class="text-two"><?php echo wp_kses($settings['btn_title'], true);?></span>
                </span>
            </a>
        </div>
        <?php } ?>
    
    <?php endif;
    }
}