<?php namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Call_Widget extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'chartio_call_widget';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Chartio Call Widget', 'chartio' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-image-rollover';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'chartio' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'call_widget',
            [
                'label' => esc_html__( 'Call Widget', 'chartio' ),
            ]
        );
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'chartio'),
					'2' => esc_html__( 'Style Two ', 'chartio'),
					'3' => esc_html__( 'Style Three ', 'chartio'),
				),
			]
		);

		$this->add_control(
			'icons',
			[
				'label' => esc_html__('Enter The icons', 'chartio'),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'flaticon-telephone',
					'library' => 'solid',
				],
				'condition'   => [ 'layout_control' => '1', ],
			]

		);
		$this->add_control(
			'phone_title',
			[
				'label'       => __( 'Phone Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Phone Title', 'chartio' ),
			]
		);
		$this->add_control(
			'phone_no',
			[
				'label'       => __( 'Phone Number', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Phone Number', 'chartio' ),
			]
		);
		$this->end_controls_section();

		/** Style Tab **/
		$this->register_style_background_controls();
    }

	/************************************************************************
								Tab Style Start
	*************************************************************************/

	protected function register_style_background_controls()
	{
		/**Phone Title Style**/
		$this->start_controls_section(
			'phone_title_style',
			[
				'label' => esc_html__('PHONE TITLE STYLE SETTING', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		//Phone Info Background
		$this->add_control(
			'show_phone_info_bg_style',
			[
				'label'       => __( 'ON/OFF Phone Info Background Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_control(
			'phone_info_background',
			[
				'label'                 => __( 'Background', 'chartio' ),
				'type'                  => Controls_Manager::HEADING,
				'separator'             => 'before',
				'condition'             => [
					'show_phone_info_bg_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'phone_info_bgtype',
				'label' => __( 'Phone Info Background', 'chartio' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' =>
					'{{WRAPPER}} .author-box',
				'condition'             => [
					'show_phone_info_bg_style'    => 'yes',
				]
			]
		);
		//Phone Title
		$this->add_control(
			'show_phone_title_style',
			[
				'label'       => __( 'ON/OFF Phone Title Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_responsive_control(
            'phone_title__margin',
            [
                'label'      => esc_html__( 'Margin', 'chartio' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .author-box .bn-phone-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
				'condition'             => [
					'show_phone_title_style'    => 'yes',
				]
            ]
        );

        $this->add_responsive_control(
            'phone_title_padding',
            [
                'label'      => esc_html__( 'Padding', 'chartio' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .author-box .bn-phone-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
				'condition'             => [
					'show_phone_title_style'    => 'yes',
				]
            ]
        );
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'phone_title_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .author-box .bn-phone-title',
				'condition'             => [
					'show_phone_title_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'phone_title_typography',
                'label' => __('Phone Title Typography', 'chartio'),
                'selector' =>
                    '{{WRAPPER}} .author-box .bn-phone-title',
                'separator' => 'before',
				'condition'             => [
					'show_phone_title_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'phone_title_color',
            [
                'label' => __('Phone Title Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .author-box .bn-phone-title' => 'color: {{VALUE}}!important',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_phone_title_style'    => 'yes',
				]
            ]
        );
		$this->add_group_control(
			Group_Control_Text_Stroke::get_type(),
			[
				'name' => 'phone_title_stroke',
				'selector' => '{{WRAPPER}} .author-box .bn-phone-title',
				'condition'             => [
					'show_phone_title_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'phone_title_shadow',
				'selector' => '{{WRAPPER}} .author-box .bn-phone-title',
				'condition'             => [
					'show_phone_title_style'    => 'yes',
				]
			]
		);
		$this->end_controls_section();

		/**Phone Number Style**/
		$this->start_controls_section(
			'phone_no_style',
			[
				'label' => esc_html__('PHONE NUMBER STYLE SETTING', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		//Phone Number
		$this->add_control(
			'show_phone_no_style',
			[
				'label'       => __( 'ON/OFF Phone Number Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_responsive_control(
            'phone_no__margin',
            [
                'label'      => esc_html__( 'Margin', 'chartio' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .author-box .bn-phone-number' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
				'condition'             => [
					'show_phone_no_style'    => 'yes',
				]
            ]
        );

        $this->add_responsive_control(
            'phone_no_padding',
            [
                'label'      => esc_html__( 'Padding', 'chartio' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .author-box .bn-phone-number' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
				'condition'             => [
					'show_phone_no_style'    => 'yes',
				]
            ]
        );
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'phone_no_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .author-box .bn-phone-number',
				'condition'             => [
					'show_phone_no_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'phone_no_typography',
                'label' => __('Phone Number Typography', 'chartio'),
                'selector' =>
                    '{{WRAPPER}} .author-box .bn-phone-number',
                'separator' => 'before',
				'condition'             => [
					'show_phone_no_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'phone_no_color',
            [
                'label' => __('Phone Number Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .author-box .bn-phone-number' => 'color: {{VALUE}}!important',
					'{{WRAPPER}} .author-box a.bn-phone-number' => 'color: {{VALUE}}!important',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_phone_no_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'phone_no_hover_color',
            [
                'label' => __('Phone Number Hover Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .author-box .bn-phone-number a:hover' => 'color: {{VALUE}}!important',
					'{{WRAPPER}} .author-box a.bn-phone-number:hover' => 'color: {{VALUE}}!important',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_phone_no_style'    => 'yes',
				]
            ]
        );
		$this->add_group_control(
			Group_Control_Text_Stroke::get_type(),
			[
				'name' => 'phone_no_stroke',
				'selector' => '{{WRAPPER}} .author-box .bn-phone-number',
				'condition'             => [
					'show_phone_no_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'phone_no_shadow',
				'selector' => '{{WRAPPER}} .author-box .bn-phone-number',
				'condition'             => [
					'show_phone_no_style'    => 'yes',
				]
			]
		);
		$this->end_controls_section();
    }


    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
    ?>

    <?php if($settings['layout_control'] == '3') :?>


    <?php elseif($settings['layout_control'] == '2') :?>


    <?php else: ?>

    <!-- Phone Box -->
    <div class="inspire-one_lower-box">
        <div class="inspire-one_phone author-box">
            <?php \Elementor\Icons_Manager::render_icon( $settings['icons']); ?>
            <div class="bn-phone-title"><?php echo wp_kses($settings['phone_title'], true);?></div>
            <div class="bn-phone-number"><a href="tel:<?php echo esc_attr($settings['phone_no']); ?>"><?php echo wp_kses($settings['phone_no'], true);?></a></div>
        </div>
    </div>

    <?php endif;?>
    <?php
    }
}
