<?php
namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Text_Stroke;
use \Elementor\Group_Control_Css_Filter;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Causes_Carousel extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'chartio_causes_carousel';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Chartio Causes Carousel', 'chartio' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open town';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'chartio' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'causes_carousel',
            [
                'label' => esc_html__( 'Causes Carousel', 'chartio' ),
			]
        );

		$this->add_control(
			'causes_style',
			[
				'label'   => esc_html__( 'Choose Causes Style', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'chartio'),
					'2' => esc_html__( 'Style Two', 'chartio' ),
					'3' => esc_html__( 'Style Three', 'chartio' ),
					'4' => esc_html__( 'Style Four', 'chartio' ),
					'5' => esc_html__( 'Style Five', 'chartio' ),
					'6' => esc_html__( 'Style Six', 'chartio' ),
					'7' => esc_html__( 'Style Seven', 'chartio' ),
				),
			]
		);

		$this->add_control(
			'bg_image',
			[
				'label' => esc_html__('Choose Background Image ', 'chartio'),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
				'condition' => [ 'causes_style' => '5', ],
			]
		);
		$this->add_control(
			'pattern_image',
			[
				'label' => esc_html__('Choose Pattern Image ', 'chartio'),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
				'condition' => [ 'causes_style' => ['3', '5'], ],
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'condition' => [ 'causes_style' => ['1', '2', '3'], ],
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title Here', 'chartio' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Text', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'condition' => [ 'causes_style' => ['1', '2', '3'], ],
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text Here', 'chartio' ),
			]
		);

		$this->add_control(
			'text_limit',
			[
				'label'   => esc_html__( 'Text Limit', 'chartio' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 15,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'btn_title',
			[
				'label' => esc_html__( 'Button Title', 'elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Enter button title', 'elementor' ),
				'default' => esc_html__( 'Donate Now', 'elementor' ),
			]
		);
		$this->add_control(
            'query_number',
            [
                'label'   => esc_html__( 'Number of post', 'chartio' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 4,
                'min'     => 1,
                'max'     => 100,
                'step'    => 1,
            ]
        );
        $this->add_control(
            'query_orderby',
            [
                'label'   => esc_html__( 'Order By', 'chartio' ),
				'label_block' => true,
                'type'    => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => array(
                    'date'       => esc_html__( 'Date', 'chartio' ),
                    'title'      => esc_html__( 'Title', 'chartio' ),
                    'menu_order' => esc_html__( 'Menu Order', 'chartio' ),
                    'rand'       => esc_html__( 'Random', 'chartio' ),
                ),
            ]
        );
        $this->add_control(
            'query_order',
            [
                'label'   => esc_html__( 'Order', 'chartio' ),
				'label_block' => true,
                'type'    => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => array(
                    'DESC' => esc_html__( 'DESC', 'chartio' ),
                    'ASC'  => esc_html__( 'ASC', 'chartio' ),
                ),
            ]
        );
        $this->add_control(
            'query_category',
            [
                'type' => Controls_Manager::SELECT,
                'label' => esc_html__('Category', 'chartio'),
				'label_block' => true,
                'options' => get_campaign_categories()
            ]
        );
        $this->end_controls_section();

		//General Style
		$this->start_controls_section(
			'general_style',
			[
				'label' => esc_html__( 'General Setting', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
            'general_margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .chartio-causes-grid' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );

        $this->add_responsive_control(
            'general_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .chartio-causes-grid' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'general_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .chartio-causes-grid',
			]
		);
		$this->end_controls_section();

		//Small Title Style
		$this->start_controls_section(
			'small_title_style',
			[
				'label' => esc_html__( 'Small Title', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [ 'causes_style' => ['1', '2', '3'], ],
			]
		);

		$this->add_responsive_control(
            'small_title__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .sec-title__tagline' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );

        $this->add_responsive_control(
            'small_title_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .sec-title__tagline' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'small_title_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .sec-title__tagline',
			]
		);

		$this->add_control(
			'small_title_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sec-title__tagline' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'small_title_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => '{{WRAPPER}} .sec-title__tagline',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Stroke::get_type(),
			[
				'name' => 'small_title_text_stroke',
				'selector' => '{{WRAPPER}} .sec-title__tagline',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'small_title_text_shadow',
				'selector' => '{{WRAPPER}} .sec-title__tagline',
			]
		);

		$this->end_controls_section();

		//Title Style
		$this->start_controls_section(
			'title_style',
			[
				'label' => esc_html__( 'Title', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [ 'causes_style' => ['1', '2', '3'], ],
			]
		);

		$this->add_responsive_control(
            'title__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .sec-title__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );

        $this->add_responsive_control(
            'title_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .sec-title__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'title_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .sec-title__title',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sec-title__title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => '{{WRAPPER}} .sec-title__title',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Stroke::get_type(),
			[
				'name' => 'title_text_stroke',
				'selector' => '{{WRAPPER}} .sec-title__title',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'title_text_shadow',
				'selector' => '{{WRAPPER}} .sec-title__title',
			]
		);
		$this->end_controls_section();

		/**Loop Style**/
		$this->start_controls_section(
			'loop_style',
			[
				'label' => esc_html__('Loop Content Style Setting', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		//Loop Background Color Style
		$this->add_control(
			'show_loop_loop_style',
			[
				'label'       => __( 'ON/OFF  Loop Background Color Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_control(
            'loop_loop_bgcolor',
            [
                'label' => __('Loop Background Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .cause-block_one-color_layer' => 'background-color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_loop_style'    => 'yes',
				]
            ]
        );
		//Title Style
		$this->add_control(
			'show_loop_title_style',
			[
				'label'       => __( 'ON/OFF  Title Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_title_typography',
                'label' => __('Title Typography', 'chartio'),
                'selector' =>
                    '{{WRAPPER}} .chartio-grid-title,
								 .chartio-grid-title a',
                'separator' => 'before',
				'condition'             => [
					'show_loop_title_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_title_color',
            [
                'label' => __('Title Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-title a' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_title_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_title_hover_color',
            [
                'label' => __('Title Hover Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-title a:hover' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_title_style'    => 'yes',
				]
            ]
        );
		//Content Style
		$this->add_control(
			'show_loop_content_style',
			[
				'label'       => __( 'ON/OFF  Designation Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_content_typography',
                'label' => __('Price Typography', 'chartio'),
                'selector' =>
                    '{{WRAPPER}} .chartio-grid-price,
								 .chartio-grid-price span',
                'separator' => 'before',
				'condition'             => [
					'show_loop_content_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_content_color',
            [
                'label' => __('Price Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-price' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-price span' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_content_style'    => 'yes',
				]
            ]
        );
		//Button Style
		$this->add_control(
			'show_loop_icon_style',
			[
				'label'       => __( 'ON/OFF Button Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_control(
            'loop_icon_bgcolor',
            [
                'label' => __('Button Background Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-btn-title' => 'background-color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_icon_typography',
                'label' => __('Button Typography', 'chartio'),
                'selector' =>
                    '{{WRAPPER}} .chartio-grid-btn-title,
								 .chartio-grid-btn-title .text-one,
								 .chartio-grid-btn-title .text-two',
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_icon_color',
            [
                'label' => __('Button Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-btn-title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-btn-title .text-one' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-btn-title .text-two' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_icon_hover_bgcolor',
            [
                'label' => __('Button Hover Background Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-btn-title:hover' => 'background-color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_icon_hover_color',
            [
                'label' => __('Button Hover Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-btn-title:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-btn-title:hover .text-one' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-btn-title:hover .text-two' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
		$btn_title = $settings[ 'btn_title' ];

        $paged = get_query_var('paged');
		$paged = chartio_set($_REQUEST, 'paged') ? esc_attr($_REQUEST['paged']) : $paged;

        $this->add_render_attribute( 'wrapper', 'class', 'templatepath-chartio' );
        $args = array(
            'post_type'      => 'campaign',
            'posts_per_page' => chartio_set( $settings, 'query_number' ),
            'orderby'        => chartio_set( $settings, 'query_orderby' ),
            'order'          => chartio_set( $settings, 'query_order' ),
			'text_limit'     => chartio_set( $settings, 'text_limit' ),
            'paged'         => $paged
        );

        if( chartio_set( $settings, 'query_category' ) ) $args['campaign_category'] = chartio_set( $settings, 'query_category' );
        $query = new \WP_Query( $args );

        if ( $query->have_posts() ) { ?>

		<?php if($settings['causes_style'] == 7 ) : ?>

        <!-- Cause Seven -->
        <div class="cause-seven chartio-causes-grid p-0 m-0 fix">
            <div class="causes-carousel_three swiper-container" id="yt-causes-slider-v3" <?php $this->print_render_attribute_string( 'slider_settings' ); ?>>
                <div class="swiper-wrapper">
                    <?php
                        $count = 1;
						while ( $query->have_posts() ) : $query->the_post();
                        $campaign = charitable_get_current_campaign();
                    ?>
                    <!-- Slide -->
                    <div class="swiper-slide">
                        <!-- Cause Block Six -->
                        <div class="cause-block_six <?php if($count == 3) echo 'color-three'; elseif($count == 2) echo 'color-two'; else echo ''; ?>">
                            <div class="cause-block_six-inner">
                                <div class="cause-block_six-image">
                                    <?php the_post_thumbnail('chartio_387x306'); ?>
                                    <div class="cause-block_six-overlay">
                                        <div class="cause-block_six-overlay_inner">
                                            <a href="<?php echo esc_url(get_permalink(get_the_id()));?>" class="theme-btn btn-style-three chartio-grid-btn-title">
                                                <span class="btn-wrap">
                                                    <span class="text-one">
														<?php if( !empty( $btn_title ) ):?>
                                                            <?php echo wp_kses( $btn_title, true );?>
                                                        <?php else:?>
                                                            <?php esc_html_e('View More', 'chartio');?>
                                                        <?php endif;?>
                                                        <i class="fas fa-arrow-right fa-fw"></i>
                                                    </span>
                                                    <span class="text-two">
                                                        <?php if( !empty( $btn_title ) ):?>
                                                            <?php echo wp_kses( $btn_title, true );?>
                                                        <?php else:?>
                                                            <?php esc_html_e('View More', 'chartio');?>
                                                        <?php endif;?>
                                                        <i class="fas fa-arrow-right fa-fw"></i>
                                                    </span>
                                                </span>
                                            </a>
                                        </div>
                                    </div>
                                </div>
                                <div class="cause-block_six-content">
                                    <h3 class="cause-block_six-title chartio-grid-title"><a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><?php the_title();?></a></h3>
                                    <div class="cause-block_six-text chartio-grid-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                                    <div class="cause-block_six-progress">
                                        <div class="bar progress-line chartio-grid-price" data-width="<?php echo esc_attr($campaign->get_percent_donated_raw());?>"></div>
                                        <div class="count-box chartio-grid-price"><span class="count-text" data-speed="2500" data-stop="<?php echo esc_attr($campaign->get_percent_donated_raw());?>">0</span>%</div>
                                    </div>
                                    <div class="cause-block_six-price">
                                        <div class="justify-content-between d-flex flex-wrap chartio-grid-price">
                                            <span><?php echo esc_attr($campaign->get_percent_donated_raw());?>% <?php esc_html_e('Raised', 'chartio'); ?></span>
                                            <span><?php echo wp_kses($campaign->get_donation_summary(), true); ?> <?php esc_html_e('Goal', 'chartio'); ?></span>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php $count++; endwhile; ?>
                </div>
            </div>

            <!-- If we need navigation buttons -->
            <div class="cause-five-one-arrow">
                <!-- If we need navigation buttons -->
                <div class="cause-five-button-prev fas fa-arrow-left fa-fw"></div>
                <div class="cause-five-button-next fas fa-arrow-right fa-fw"></div>
            </div>

        </div>
        <!-- End Cause Seven -->

		<?php elseif($settings['causes_style'] == 6 ) : ?>
       	<div class="cause-two style-two chartio-causes-grid p-0 m-0">
            <div class="causes-carousel swiper-container" id="yt-causes-slider" <?php $this->print_render_attribute_string( 'slider_settings' ); ?>>
                <div class="swiper-wrapper">
                    <?php
                        $count = 1;
						while ( $query->have_posts() ) : $query->the_post();
                        $campaign = charitable_get_current_campaign();
                    ?>
                    <!-- Slide -->
                    <div class="swiper-slide">
                        <!-- Cause Block Two -->
                        <div class="cause-block_two <?php if($count == '3') echo 'style-three'; elseif($count == '2') echo 'style-two'; else echo ''; ?>">
                            <div class="cause-block_two-inner">
                                <div class="cause-block_two-image-outer">
                                    <div class="cause-block_two-image">
                                        <a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><?php the_post_thumbnail('chartio_327x311'); ?></a>
                                        <div class="cause-block_two-location">
                                            LOS ANGELES, CA
                                        </div>
                                    </div>
                                </div>
                                <div class="cause-block_two-content">
                                    <h3 class="cause-block_two-heading chartio-grid-title"><a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><?php the_title();?></a></h3>
                                    <div class="cause-block_two-text chartio-grid-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                                    <div class="cause-block_two-price d-flex justify-content-between align-items-center flex-wrap chartio-grid-price"><span><?php esc_html_e('Goals:  ', 'chartio'); ?><?php echo wp_kses($campaign->get_donation_summary(), true); ?></span> <i><?php esc_html_e('Raised:  ', 'chartio'); ?> <?php echo esc_attr($campaign->get_percent_donated_raw());?>%</i></div>
                                    <div class="cause-block_two-lower">
                                        <div class="d-flex justify-content-between flex-wrap align-items-center">
                                            <ul class="cause-block_two-authors">
                                                <?php
													$users = get_users(); // get array of WP_User objects
												?>
												<?php foreach ( $users as $user ) {?>
												<li><?php echo get_avatar($user->ID, 41); ?></li>
												<?php };?>
                                            </ul>
                                            <div class="cause-block_two-button">
                                                <a href="<?php echo esc_url(get_permalink(get_the_id()));?>" class="theme-btn btn-style-three chartio-grid-btn-title">
                                                    <span class="btn-wrap">
                                                        <span class="text-one">
                                                            <?php if( !empty( $btn_title ) ):?>
                                                                <?php echo wp_kses( $btn_title, true );?>
                                                            <?php else:?>
                                                                <?php esc_html_e('Donate Now', 'chartio');?>
                                                            <?php endif;?>
                                                            <i class="fas fa-arrow-right fa-fw"></i>
                                                        </span>
                                                        <span class="text-two">
                                                            <?php if( !empty( $btn_title ) ):?>
                                                                <?php echo wp_kses( $btn_title, true );?>
                                                            <?php else:?>
                                                                <?php esc_html_e('donate now', 'chartio');?>
                                                            <?php endif;?>
                                                            <i class="fas fa-arrow-right fa-fw"></i>
                                                        </span>
                                                    </span>
                                                </a>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php $count++; endwhile; ?>
                </div>
            </div>

        </div>

        <?php elseif($settings['causes_style'] == 5 ) : ?>

        <!-- CTA One -->
        <section class="cta-one chartio-causes-grid" <?php if($settings['bg_image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['bg_image']['id'])); ?>)"<?php } ?>>
            <div class="cta-one_pattern-layer" <?php if($settings['pattern_image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['pattern_image']['id'])); ?>)"<?php } ?>></div>
            <div class="auto-container">
                <div class="cta-slider swiper-container" id="yt-causes-slider-v5" <?php $this->print_render_attribute_string( 'slider_settings' ); ?>>
                    <div class="swiper-wrapper">
        				<?php
							while ( $query->have_posts() ) : $query->the_post();
							$term_list = wp_get_post_terms(get_the_id(), 'campaign_category', array("fields" => "names"));
							$campaign = charitable_get_current_campaign();
						?>
                        <!-- Slide -->
                        <div class="swiper-slide">
                            <div class="cta-one_content">
                                <div class="sec-title light centered">
                                    <div class="sec-title_title sec-title__tagline"><?php echo implode( ', ', (array)$term_list );?></div>
                                    <h2 class="sec-title_heading sec-title__title"><?php the_title();?></h2>
                                    <div class="sec-title_text chartio-grid-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                                </div>
                                <div class="cta-one_button text-center">
                                    <a href="<?php echo esc_url(get_permalink(get_the_id()));?>" class="theme-btn btn-style-one chartio-grid-btn-title">
                                        <span class="btn-wrap">
                                            <span class="text-one">
												<?php if( !empty( $btn_title ) ):?>
                                                    <?php echo wp_kses( $btn_title, true );?>
                                                <?php else:?>
                                                    <?php esc_html_e('Donate Now', 'chartio');?>
                                                <?php endif;?>
                                            </span>
                                            <span class="text-two">
                                                <?php if( !empty( $btn_title ) ):?>
                                                    <?php echo wp_kses( $btn_title, true );?>
                                                <?php else:?>
                                                    <?php esc_html_e('donate now', 'chartio');?>
                                                <?php endif;?>
                                            </span>
                                        </span>
                                    </a>
                                </div>
                            </div>
                        </div>
                        <?php endwhile; ?>
                    </div>

                    <div class="cta-one-arrow">
                        <div class="cta-one_prev-image">
                            <img src="<?php echo esc_url(get_template_directory_uri());?>/assets/images/background/cta-1.jpg" alt="<?php esc_attr_e('Awesome Image', 'chartio'); ?>" />
                        </div>
                        <!-- If we need navigation buttons -->
                        <div class="cta-one-button-prev fas fa-arrow-left fa-fw"></div>
                        <div class="cta-one-button-next fas fa-arrow-right fa-fw"></div>
                        <div class="cta-one_next-image">
                            <img src="<?php echo esc_url(get_template_directory_uri());?>/assets/images/background/cta-2.jpg" alt="<?php esc_attr_e('Awesome Image', 'chartio'); ?>" />
                        </div>
                    </div>

                </div>
            </div>
        </section>
        <!-- End CTA One -->

		<?php elseif($settings['causes_style'] == 4 ) : ?>

        <!-- Donate One -->
        <section class="donate-one chartio-causes-grid">
            <div class="outer-container">
                <div class="donate-carousel swiper-container" id="yt-causes-slider-v4" <?php $this->print_render_attribute_string( 'slider_settings' ); ?>>
                    <div class="swiper-wrapper">
                        <?php
							while ( $query->have_posts() ) : $query->the_post();
							$campaign = charitable_get_current_campaign();
						?>
                        <!-- Slide -->
                        <div class="swiper-slide">
                            <!-- Donate Block One -->
                            <div class="donate-block_one">
                                <div class="donate-block_one-inner">
                                    <div class="donate-block_one-pattern" style="background-image:url(<?php echo esc_url(get_template_directory_uri());?>/assets/images/background/pattern-1.png)"></div>
                                    <div class="donate-block_one-image">
                                        <?php the_post_thumbnail('chartio_382x618'); ?>
                                        <div class="donate-block_one-overlay">
                                            <div class="donate-block_one-location">
                                                LOS ANGELES, CA
                                            </div>
                                            <div class="donate-block_one-content">
                                                <div class="donate-block_one-price chartio-grid-price"><?php echo wp_kses($campaign->get_donation_summary(), true); ?></div>
                                                <h3 class="donate-block_one-heading chartio-grid-title"><a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><?php the_title();?></a></h3>
                                                <div class="donate-block_one-text chartio-grid-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                                                <div class="donate-block_one-button">
                                                    <a href="<?php echo esc_url(get_permalink(get_the_id()));?>" class="theme-btn btn-style-two chartio-grid-btn-title">
                                                        <span class="btn-wrap">
                                                            <span class="text-one">
																<?php if( !empty( $btn_title ) ):?>
                                                                    <?php echo wp_kses( $btn_title, true );?>
                                                                <?php else:?>
                                                                    <?php esc_html_e('donate now', 'chartio');?>
                                                                <?php endif;?>
                                                            </span>
                                                            <span class="text-two">
                                                                <?php if( !empty( $btn_title ) ):?>
                                                                    <?php echo wp_kses( $btn_title, true );?>
                                                                <?php else:?>
                                                                    <?php esc_html_e('donate now', 'chartio');?>
                                                                <?php endif;?>
                                                            </span>
                                                        </span>
                                                    </a>
                                                </div>
                                                <a class="donate-block_one-share" href="<?php echo esc_url(get_permalink(get_the_id()));?>">
                                                    <i class="fas fa-share-alt fa-fw"></i>
                                                </a>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
    					<?php endwhile; ?>
                    </div>
                </div>

            </div>
        </section>
        <!-- End Donate One -->

		<?php elseif($settings['causes_style'] == 3) : ?>

        <!-- Cause Five -->
        <section class="cause-five" <?php if($settings['pattern_image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['pattern_image']['id'])); ?>)"<?php } ?>>
            <div class="auto-container">
                <?php if($settings['title'] || $settings['text']){ ?>
                <!-- Sec Title Two -->
                <div class="sec-title_two centered">
                    <?php if($settings['title']){ ?><div class="sec-title_two-title tx-split-text split-in-up"><?php echo wp_kses($settings['title'], true);?></div><?php } ?>
                    <?php if($settings['text']){ ?><h2 class="sec-title_two-heading tx-split-text split-in-up"><?php echo wp_kses($settings['text'], true);?></h2><?php } ?>
                </div>
                <?php } ?>
                <div class="causes-carousel_three swiper-container" id="yt-causes-slider-v3" <?php $this->print_render_attribute_string( 'slider_settings' ); ?>>
                    <div class="swiper-wrapper">
        				<?php
							while ( $query->have_posts() ) : $query->the_post();
							$campaign = charitable_get_current_campaign();
						?>
                        <!-- Slide -->
                        <div class="swiper-slide">
                            <!-- Cause Block Four -->
                            <div class="cause-block_four">
                                <div class="cause-block_four-inner">
                                    <div class="cause-block_four-image">
                                        <?php the_post_thumbnail('chartio_387x309'); ?>
                                    </div>
                                    <div class="cause-block_four-content">
                                        <div class="cause-block_four-info">
                                            <div class="d-flex justify-content-between align-items-center flex-wrap">
                                                <div class="cause-block_four-location">LOS ANGELES, CA</div>
                                                <div class="cause-block_four-icons">
                                                    <a class="fas fa-camera fa-fw" href="#"></a>
                                                    <a class="fas fa-play-circle fa-fw" href="#"></a>
                                                </div>
                                            </div>
                                        </div>
                                        <h4 class="cause-block_four-heading chartio-grid-title"><a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><?php the_title();?></a></h4>
                                        <div class="cause-block_four-text chartio-grid-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                                        <div class="cause-block_four-donations">
                                            <div class="bar progress-line" data-width="<?php echo esc_attr($campaign->get_percent_donated_raw());?>"><div class="count-box"><span class="count-text" data-speed="2500" data-stop="<?php echo esc_attr($campaign->get_percent_donated_raw());?>">0</span>%</div></div>
                                            <div class="justify-content-between d-flex flex-wrap">
                                                <span><?php echo esc_attr($campaign->get_percent_donated_raw());?>% <i><?php esc_html_e('Raised', 'chartio'); ?></i></span>
                                                <span><?php echo wp_kses($campaign->get_donation_summary(), true); ?> <i><?php esc_html_e('Goals', 'chartio'); ?></i></span>
                                                <i class="cause-block_four-border-bottom"></i>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php endwhile; ?>
                    </div>

                </div>

                <div class="cause-five-one-arrow">
                    <!-- If we need navigation buttons -->
                    <div class="cause-five-button-prev fas fa-arrow-left fa-fw"></div>
                    <div class="cause-five-button-next fas fa-arrow-right fa-fw"></div>
                </div>

            </div>
        </section>
        <!-- End Cause Five -->

		<?php elseif($settings['causes_style'] == 2) : ?>

        <!-- Cause Three -->
        <section class="cause-three chartio-causes-grid">
            <div class="auto-container">
                <?php if($settings['title'] || $settings['text']){ ?>
                <!-- Sec Title -->
                <div class="sec-title centered">
                    <?php if($settings['title']){ ?><div class="sec-title_title tx-split-text split-in-up sec-title__tagline"><?php echo wp_kses($settings['title'], true);?></div><?php } ?>
                    <?php if($settings['text']){ ?><h2 class="sec-title_heading tx-split-text split-in-up sec-title__title"><?php echo wp_kses($settings['text'], true);?></h2><?php } ?>
                </div>
                <?php } ?>
                <div class="inner-container">

                    <div class="causes-carousel_two swiper-container" id="yt-causes-slider-v2" <?php $this->print_render_attribute_string( 'slider_settings' ); ?>>
                        <div class="swiper-wrapper">
                            <?php
								while ( $query->have_posts() ) : $query->the_post();
								$campaign = charitable_get_current_campaign();
							?>
                            <!-- Slide -->
                            <div class="swiper-slide">
                                <!-- Cause Block Three -->
                                <div class="cause-block_three">
                                    <div class="cause-block_three-inner">
                                        <div class="cause-block_three-image_outer">
                                            <div class="cause-block_three-image">
                                                <a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><?php the_post_thumbnail('chartio_610x485'); ?></a>
                                            </div>
                                            <div class="cause-block_three-content">
                                                <div class="cause-block_three-location">
                                                    LOS ANGELES, CA
                                                </div>
                                                <h3 class="cause-block_three-heading chartio-grid-title"><a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><?php the_title();?></a></h3>
                                                <div class="cause-block_three-text chartio-grid-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                                                <div class="cause-block_three-price d-flex justify-content-between align-items-center flex-wrap chartio-grid-price"><span><?php esc_html_e('Goals:  ', 'chartio'); ?><?php echo wp_kses($campaign->get_donation_summary(), true); ?></span> <i><?php esc_html_e('Raised:  ', 'chartio'); ?> <?php echo esc_attr($campaign->get_percent_donated_raw());?>%</i></div>
                                                <div class="cause-block_three-button">
                                                    <a href="<?php echo esc_url(get_permalink(get_the_id()));?>" class="theme-btn btn-style-one chartio-grid-btn-title">
                                                        <span class="btn-wrap">
                                                            <span class="text-one">
																<?php if( !empty( $btn_title ) ):?>
                                                                    <?php echo wp_kses( $btn_title, true );?>
                                                                <?php else:?>
                                                                    <?php esc_html_e('donate now', 'chartio');?>
                                                                <?php endif;?>
                                                            </span>
                                                            <span class="text-two">
                                                                <?php if( !empty( $btn_title ) ):?>
                                                                    <?php echo wp_kses( $btn_title, true );?>
                                                                <?php else:?>
                                                                    <?php esc_html_e('donate now', 'chartio');?>
                                                                <?php endif;?>
                                                            </span>
                                                        </span>
                                                    </a>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <?php endwhile; ?>
                        </div>

                    </div>

                    <div class="cause-three-arrow">
                        <div class="cause-three_prev-image">
                            <img src="<?php echo esc_url(get_template_directory_uri());?>/assets/images/background/cause-10.jpg" alt="<?php esc_attr_e('Awesome Image', 'chartio'); ?>" />
                        </div>
                        <!-- If we need navigation buttons -->
                        <div class="cause-three-button-prev fas fa-arrow-left fa-fw"></div>
                        <div class="cause-three-button-next fas fa-arrow-right fa-fw"></div>
                        <div class="cause-three_next-image">
                            <img src="<?php echo esc_url(get_template_directory_uri());?>/assets/images/background/cause-11.jpg" alt="<?php esc_attr_e('Awesome Image', 'chartio'); ?>" />
                        </div>
                    </div>

                </div>
            </div>
        </section>
        <!-- End Cause Three -->

        <?php else: ?>

        <!-- Cause Two -->
        <section class="cause-two chartio-causes-grid">
            <div class="auto-container">
                <?php if($settings['title'] || $settings['text']){ ?>
                <!-- Sec Title -->
                <div class="sec-title centered">
                    <?php if($settings['title']){ ?><div class="sec-title_title tx-split-text split-in-up sec-title__tagline"><?php echo wp_kses($settings['title'], true);?></div><?php } ?>
                    <?php if($settings['text']){ ?><h2 class="sec-title_heading tx-split-text split-in-up sec-title__title"><?php echo wp_kses($settings['text'], true);?></h2><?php } ?>
                </div>
                <?php } ?>
                <div class="causes-carousel swiper-container">
                    <div class="swiper-wrapper">
        				<?php
							$count = 1;
							while ( $query->have_posts() ) : $query->the_post();
							$campaign = charitable_get_current_campaign();
						?>
                        <!-- Slide -->
                        <div class="swiper-slide">
                            <!-- Cause Block Two -->
                            <div class="cause-block_two <?php if($count == '3') echo 'style-three'; elseif($count == '2') echo 'style-two'; else echo ''; ?>">
                                <div class="cause-block_two-inner">
                                    <div class="cause-block_two-image-outer">
                                        <div class="cause-block_two-image">
                                            <a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><?php the_post_thumbnail('chartio_327x311'); ?></a>
                                            <div class="cause-block_two-location">
                                                LOS ANGELES, CA
                                            </div>
                                        </div>
                                    </div>
                                    <div class="cause-block_two-content">
                                        <h3 class="cause-block_two-heading chartio-grid-title"><a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><?php the_title();?></a></h3>
                                        <div class="cause-block_two-text chartio-grid-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                                        <div class="cause-block_two-price d-flex justify-content-between align-items-center flex-wrap chartio-grid-price"><span><?php esc_html_e('Goals:  ', 'chartio'); ?><?php echo wp_kses($campaign->get_donation_summary(), true); ?></span> <i><?php esc_html_e('Raised:  ', 'chartio'); ?> <?php echo esc_attr($campaign->get_percent_donated_raw());?>%</i></div>
                                        <div class="cause-block_two-lower">
                                            <div class="d-flex justify-content-between flex-wrap align-items-center">
                                                <ul class="cause-block_two-authors">
                                                    <?php
														$users = get_users(); // get array of WP_User objects
													?>
                                                    <?php foreach ( $users as $user ) {?>
                                                    <li><?php echo get_avatar($user->ID, 41); ?></li>
                                                    <?php };?>
                                                </ul>
                                                <div class="cause-block_two-button">
                                                    <a href="<?php echo charitable_get_permalink( 'campaign_donation_page', array( 'campaign_id' => $campaign->ID ) ); ?>" class="theme-btn btn-style-one chartio-grid-btn-title">
                                                        <span class="btn-wrap">
                                                            <span class="text-one">
																<?php if( !empty( $btn_title ) ):?>
                                                                    <?php echo wp_kses( $btn_title, true );?>
                                                                <?php else:?>
                                                                    <?php esc_html_e('donate now', 'chartio');?>
                                                                <?php endif;?>
                                                            </span>
                                                            <span class="text-two">
                                                                <?php if( !empty( $btn_title ) ):?>
                                                                    <?php echo wp_kses( $btn_title, true );?>
                                                                <?php else:?>
                                                                    <?php esc_html_e('donate now', 'chartio');?>
                                                                <?php endif;?>
                                                            </span>
                                                        </span>
                                                    </a>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
    					<?php $count++; endwhile; ?>
                    </div>
                </div>

                <!-- If we need navigation buttons -->
                <div class="cause-two-button-prev fas fa-arrow-left fa-fw"></div>
                <div class="cause-two-button-next fas fa-arrow-right fa-fw"></div>

            </div>
        </section>
        <!-- End Cause Two -->

        <?php endif; ?>
        <?php }
        wp_reset_postdata();
    }
}
