<?php 
namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Text_Stroke;
use \Elementor\Group_Control_Css_Filter;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Causes_Grid extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'chartio_causes_grid';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Chartio Causes Grid', 'chartio' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open town';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'chartio' ];
    }
	
	public function get_script_depends() {
		wp_register_script( 'causes-carousels', YT_URL . 'assets/js/causes-count.js', [ 'elementor-frontend' ], '1.0.0', true );
		return [ 'causes-carousels' ];
	}

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'causes_grid',
            [
                'label' => esc_html__( 'Causes Grid', 'chartio' ),
			]
        );
		
		$this->add_control(
			'causes_style',
			[
				'label'   => esc_html__( 'Choose Causes Style', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'chartio'),
					'2' => esc_html__( 'Style Two', 'chartio' ),
					'3' => esc_html__( 'Style Three', 'chartio' ),
					'4' => esc_html__( 'Style Four', 'chartio' ),
					'5' => esc_html__( 'Style Five', 'chartio' ),
					'6' => esc_html__( 'Style Six', 'chartio' ),
				),
			]
		);
		
		$this->add_control(
			'col_grid',
			[
				'label'   => esc_html__( 'Choose Column', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'default',
				'options' => array(
					'default'  => esc_html__( 'Default', 'chartio' ),
					'one' => esc_html__( 'One Column Grid ', 'chartio'),
					'two'  => esc_html__( 'Two Column Grid', 'chartio' ),
					'three'  => esc_html__( 'Three Column Grid', 'chartio' ),
					'four'  => esc_html__( 'Four Column Grid', 'chartio' ),
					'five'  => esc_html__( 'Six Column Grid', 'chartio' ),
				),
			]
		);
		
		$this->add_control(
			'pattern_image',
			[
				'label' => esc_html__('Choose Pattern Image ', 'chartio'),							
				'type' => Controls_Manager::MEDIA,		
				'condition' => [ 'causes_style' => '1', ],			
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'image',
			[
				'label' => esc_html__('Choose Image ', 'chartio'),							
				'type' => Controls_Manager::MEDIA,	
				'condition' => [ 'causes_style' => '1', ],					
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'condition' => [ 'causes_style' => '5', ],
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub Title Here', 'chartio' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'condition' => [ 'causes_style' => ['1', '5'], ],
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title Here', 'chartio' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Text', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'condition' => [ 'causes_style' => ['1', '5'], ],
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title Here', 'chartio' ),
			]
		);
		$this->add_control(
			'btn_title',
			[
				'label' => esc_html__( 'Button Title', 'elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Enter button title', 'elementor' ),
				'default' => esc_html__( 'Donate Now', 'elementor' ),
			]
		);	
		
		$this->add_control(
            'text_limit',
            [
                'label'   => esc_html__( 'Number of Text', 'chartio' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 10,
                'min'     => 1,
                'max'     => 100,
                'step'    => 1,
            ]
        );
		$this->add_control(
            'query_number',
            [
                'label'   => esc_html__( 'Number of post', 'chartio' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 4,
                'min'     => 1,
                'max'     => 100,
                'step'    => 1,
            ]
        );
        $this->add_control(
            'query_orderby',
            [
                'label'   => esc_html__( 'Order By', 'chartio' ),
				'label_block' => true,
                'type'    => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => array(
                    'date'       => esc_html__( 'Date', 'chartio' ),
                    'title'      => esc_html__( 'Title', 'chartio' ),
                    'menu_order' => esc_html__( 'Menu Order', 'chartio' ),
                    'rand'       => esc_html__( 'Random', 'chartio' ),
                ),
            ]
        );
        $this->add_control(
            'query_order',
            [
                'label'   => esc_html__( 'Order', 'chartio' ),
				'label_block' => true,
                'type'    => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => array(
                    'DESC' => esc_html__( 'DESC', 'chartio' ),
                    'ASC'  => esc_html__( 'ASC', 'chartio' ),
                ),
            ]
        );
        $this->add_control(
            'query_category',
            [
                'type' => Controls_Manager::SELECT,
                'label' => esc_html__('Category', 'chartio'),
				'label_block' => true,
                'options' => get_campaign_categories()
            ]
        );
		
		$this->add_control(
			'btn_titles',
			[
				'label'       => __( 'Button Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'condition' => [ 'causes_style' => ['1', '5'], ],
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title Here', 'chartio' ),
			]
		);
		
		$this->add_control(
            'btn_link',
			[
				'label' => __( 'Button Url', 'chartio' ),
				'type' => Controls_Manager::URL,
				'condition' => [ 'causes_style' => ['1', '5'], ],
				'label_block' => true, 
				'placeholder' => __( 'https://your-link.com', 'chartio' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);
        $this->end_controls_section();
		
		//General Style
		$this->start_controls_section(
			'general_style',
			[
				'label' => esc_html__( 'General Setting', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
            'general_margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .chartio-causes-grid' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'general_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .chartio-causes-grid' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'general_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .chartio-causes-grid',				
			]
		);
		$this->end_controls_section();
		
		//Small Title Style
		$this->start_controls_section(
			'small_title_style',
			[
				'label' => esc_html__( 'Small Title', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [ 'causes_style' => '1', ],
			]
		);
		
		$this->add_responsive_control(
            'small_title__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .sec-title__tagline' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'small_title_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .sec-title__tagline' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'small_title_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .sec-title__tagline',				
			]
		);
		
		$this->add_control(
			'small_title_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sec-title__tagline' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'small_title_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => '{{WRAPPER}} .sec-title__tagline',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Stroke::get_type(),
			[
				'name' => 'small_title_text_stroke',
				'selector' => '{{WRAPPER}} .sec-title__tagline',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'small_title_text_shadow',
				'selector' => '{{WRAPPER}} .sec-title__tagline',
			]
		);

		$this->end_controls_section();
		
		//Title Style
		
		$this->start_controls_section(
			'title_style',
			[
				'label' => esc_html__( 'Title', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [ 'causes_style' => '1', ],
			]
		);
		
		$this->add_responsive_control(
            'title__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .sec-title__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'title_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .sec-title__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'title_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .sec-title__title',				
			]
		);
		
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sec-title__title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => '{{WRAPPER}} .sec-title__title',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Stroke::get_type(),
			[
				'name' => 'title_text_stroke',
				'selector' => '{{WRAPPER}} .sec-title__title',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'title_text_shadow',
				'selector' => '{{WRAPPER}} .sec-title__title',
			]
		);
		$this->end_controls_section();
		
		/**Loop Style**/
		$this->start_controls_section(
			'loop_style',
			[
				'label' => esc_html__('Loop Content Style Setting', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		//Loop Background Color Style
		$this->add_control(
			'show_loop_loop_style',
			[
				'label'       => __( 'ON/OFF  Loop Background Color Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);		
		$this->add_control(
            'loop_loop_bgcolor',
            [
                'label' => __('Loop Background Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .cause-block_one-color_layer' => 'background-color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_loop_style'    => 'yes',
				]
            ]
        );			
		//Title Style
		$this->add_control(
			'show_loop_title_style',
			[
				'label'       => __( 'ON/OFF  Title Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_title_typography',
                'label' => __('Title Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .chartio-grid-title,
								 .chartio-grid-title a',                 
                'separator' => 'before',
				'condition'             => [
					'show_loop_title_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_title_color',
            [
                'label' => __('Title Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-title a' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_title_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_title_hover_color',
            [
                'label' => __('Title Hover Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-title a:hover' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_title_style'    => 'yes',
				]
            ]
        );
		//Content Style
		$this->add_control(
			'show_loop_content_style',
			[
				'label'       => __( 'ON/OFF  Designation Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_content_typography',
                'label' => __('Price Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .chartio-grid-price,
								 .chartio-grid-price span',                 
                'separator' => 'before',
				'condition'             => [
					'show_loop_content_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_content_color',
            [
                'label' => __('Price Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-price' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-price span' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_content_style'    => 'yes',
				]
            ]
        );
		//Button Style
		$this->add_control(
			'show_loop_icon_style',
			[
				'label'       => __( 'ON/OFF Button Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_control(
            'loop_icon_bgcolor',
            [
                'label' => __('Button Background Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-btn-title' => 'background-color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_icon_typography',
                'label' => __('Button Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .chartio-grid-btn-title,
								 .chartio-grid-btn-title .text-one,
								 .chartio-grid-btn-title .text-two',                 
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_icon_color',
            [
                'label' => __('Button Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-btn-title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-btn-title .text-one' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-btn-title .text-two' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_icon_hover_bgcolor',
            [
                'label' => __('Button Hover Background Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-btn-title:hover' => 'background-color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_icon_hover_color',
            [
                'label' => __('Button Hover Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-btn-title:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-btn-title:hover .text-one' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-btn-title:hover .text-two' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );		
		$this->end_controls_section();
		
		/**Button Style**/
		$this->start_controls_section(
			'button_style',
			[
				'label' => esc_html__('Button Style Setting', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition' => [ 'causes_style' => '1', ],
			]
		);
		$this->start_controls_tabs( 'chartio_tabs_btn' );
		
			$this->start_controls_tab(
				'chartio_tab_btn_normal',
				[
					'label' => __( 'Normal', 'chartio' ),
				]
			);
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'btn_bgtype',
						'label' => __( 'Button Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .thm-btn,
							 {{WRAPPER}} .faq-one__link',				
					]
				);
				$this->add_responsive_control(
					'btn_width_size',
					[
						'label' => __( 'Width', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'size_units' => [ 'px', 'em', '%', 'custom' ],
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 500,
							],
							'%' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .thm-btn' => 'width: {{SIZE}}{{UNIT}};',
							'{{WRAPPER}} .faq-one__link' => 'width: {{SIZE}}{{UNIT}};',
						],
					]
				);
				$this->add_responsive_control(
					'btn_height_size',
					[
						'label' => __( 'Height', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'size_units' => [ 'px', 'em', '%', 'custom' ],
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 500,
							],
							'%' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .thm-btn' => 'height: {{SIZE}}{{UNIT}};',
							'{{WRAPPER}} .faq-one__link' => 'height: {{SIZE}}{{UNIT}};',
						],
					]
				);
				$this->add_responsive_control(
					'btn_padding',
					[
						'label'              => __( 'Padding', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .thm-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .faq-one__link' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_group_control(
					Group_Control_Border::get_type(),
					[
						'name' => 'btn_border_type',
						'selector' => 
							'{{WRAPPER}} .thm-btn,
							 {{WRAPPER}} .faq-one__link',				
						'separator' => 'before',
					]
				);
				$this->add_group_control(
					Group_Control_Box_Shadow::get_type(),
					[
						'name' => 'border_box_shadow',
						'selector' => 
							'{{WRAPPER}} .thm-btn,
							 {{WRAPPER}} .faq-one__link',				
						'separator' => 'before',
					]
				);
				$this->add_control(
					'btn_border_radius',
					[
						'label' => esc_html__('Border Radius', 'chartio'),
						'type' => Controls_Manager::DIMENSIONS,
						'separator' => 'before',
						'size_units' => ['px'],
						'selectors' => [
							'{{WRAPPER}} .thm-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .faq-one__link' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);
				$this->add_group_control(
					Group_Control_Typography::get_type(),
					[
						'name' => 'btn_title_typography',
						'label' => __('Button Text Typography', 'chartio'),
						'selector' => 
							'{{WRAPPER}} .thm-btn,
							 {{WRAPPER}} .thm-btn .text-one,				
							 {{WRAPPER}} .thm-btn .text-two',	
						'separator' => 'before',
					]
				);
				$this->add_control(
					'btn_title_color',
					[
						'label' => __('Button Text Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .thm-btn' => 'color: {{VALUE}}',
							'{{WRAPPER}} .thm-btn .text-one' => 'color: {{VALUE}}',
							'{{WRAPPER}} .thm-btn .text-two' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
			$this->end_controls_tab();
			
			$this->start_controls_tab(
				'chartio_tab_btn_hover',
				[
					'label' => __( 'Hover', 'chartio' ),
				]
			);
			
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'btn_hover_bg_bgtype',
						'label' => __( 'Button Hover Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .thm-btn:hover,
							 {{WRAPPER}} .thm-btn:before',				
					]
				);
				$this->add_control(
					'btn_border_hover_color',
					[
						'label' => __('Button Border Hover Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .thm-btn:hover' => 'border-color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
				$this->add_control(
					'btn_title_hover_color',
					[
						'label' => __('Button Text Hover Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .thm-btn:hover' => 'color: {{VALUE}}',
							'{{WRAPPER}} .thm-btn:hover .text-one' => 'color: {{VALUE}}',
							'{{WRAPPER}} .thm-btn:hover .text-two' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
			
			$this->end_controls_tab();
			
		$this->end_controls_tabs();   
		$this->end_controls_section();
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
		$btn_title = $settings[ 'btn_title' ];
		
		$grid_col = $settings[ 'col_grid' ];
		if( $grid_col == 'one' ){
			$classes = 'col-lg-12 col-md-12 col-sm-12';
		}elseif( $grid_col == 'two' ){
			$classes = 'col-lg-6 col-md-6 col-sm-12';
		}elseif( $grid_col == 'three' ){
			$classes = 'col-lg-4 col-md-6 col-sm-12';
		}elseif( $grid_col == 'four' ){
			$classes = 'col-lg-3 col-md-6 col-sm-12';
		}elseif( $grid_col == 'five' ){
			$classes = 'col-lg-2 col-md-6 col-sm-12';
		}else{
			$classes = 'col-lg-4 col-md-6 col-sm-12';
		}

        $paged = get_query_var('paged');
		$paged = chartio_set($_REQUEST, 'paged') ? esc_attr($_REQUEST['paged']) : $paged;

        $this->add_render_attribute( 'wrapper', 'class', 'templatepath-chartio' );
        $args = array(
            'post_type'      => 'campaign',
            'posts_per_page' => chartio_set( $settings, 'query_number' ),
            'orderby'        => chartio_set( $settings, 'query_orderby' ),
            'order'          => chartio_set( $settings, 'query_order' ),
            'paged'         => $paged
        );

        if( chartio_set( $settings, 'query_category' ) ) $args['campaign_category'] = chartio_set( $settings, 'query_category' );
        $query = new \WP_Query( $args );

        if ( $query->have_posts() ) { ?>
        
        <?php if($settings['causes_style'] == 6 ) : ?>
        
        <div class="row clearfix">
			<?php
				while ( $query->have_posts() ) : $query->the_post();
				$term_list = wp_get_post_terms(get_the_id(), 'campaign_category', array("fields" => "names"));
				$campaign = charitable_get_current_campaign(); 
			?>
            <!-- Gallery Block One -->
            <div class="donate-block_two chartio-causes-grid <?php echo esc_attr( $classes );?>">
                <div class="donate-block_two-inner">
                    <div class="donate-block_two-image">
                        <?php the_post_thumbnail('chartio_390x302'); ?>
                        <div class="donate-block_two-overlay">
                            <div class="donate-block_two-overlay_inner">
                                <a href="<?php echo charitable_get_permalink( 'campaign_donation_page', array( 'campaign_id' => $campaign->ID ) ); ?>" class="theme-btn btn-style-three chartio-grid-btn-title">
                                    <span class="btn-wrap">
                                        <span class="text-one">
                                            <?php if( !empty( $btn_title ) ):?>
                                                <?php echo wp_kses( $btn_title, true );?>
                                            <?php else:?>
                                                <?php esc_html_e('Donate Now', 'chartio');?>
                                            <?php endif;?>
                                            <i class="fas fa-arrow-right fa-fw"></i>
                                        </span>
                                        <span class="text-two">
                                            <?php if( !empty( $btn_title ) ):?>
                                                <?php echo wp_kses( $btn_title, true );?>
                                            <?php else:?>
                                                <?php esc_html_e('Donate Now', 'chartio');?>
                                            <?php endif;?>
                                            <i class="fas fa-arrow-right fa-fw"></i>
                                        </span>
                                    </span>
                                </a>
                            </div>
                        </div>
                    </div>
                    <div class="donate-block_two-content">
                        <h3 class="donate-block_two-title chartio-grid-title"><a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><?php the_title();?></a></h3>
                        <div class="donate-block_two-text chartio-grid-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                        <div class="donate-block_two_progress chartio-grid-price">
                            <div class="bar progress-line chartio-grid-price" data-width="<?php echo esc_attr($campaign->get_percent_donated_raw());?>"></div>
                            <div class="count-box chartio-grid-price"><span class="count-text" data-speed="2500" data-stop="<?php echo esc_attr($campaign->get_percent_donated_raw());?>"><?php echo esc_attr($campaign->get_percent_donated_raw());?></span>%</div>
                        </div>
                        <div class="donate-block_two-price">
                            <div class="justify-content-between d-flex flex-wrap">
                                <span><?php echo esc_attr($campaign->get_percent_donated_raw());?>% <i><?php esc_html_e('Raised', 'chartio'); ?></i></span>
                                <span><?php echo wp_kses($campaign->get_donation_summary(), true); ?> <i><?php esc_html_e('Goal', 'chartio'); ?></i></span>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <?php endwhile; ?>
        </div>
        
		<?php elseif($settings['causes_style'] == 5 ) : ?>
        
        <!-- Gallery Three -->
        <section class="gallery-three chartio-causes-grid">
            <div class="outer-container">
                <div class="row clearfix">
                    <!-- Title Column -->
                    <div class="gallery-three_title-column col-lg-6 col-md-12 col-sm-12">
                        <div class="gallery-three_title-inner clearfix">
                            <?php if($settings['subtitle'] || $settings['title'] || $settings['text']){ ?>
                            <!-- Sec Title -->
                            <div class="sec-title_two light">
                                <?php if($settings['subtitle']){ ?><div class="sec-title_two-title"><?php echo wp_kses($settings['subtitle'], true);?></div><?php } ?>
                                <?php if($settings['title']){ ?><h2 class="sec-title_two-heading sec-title__title"><?php echo wp_kses($settings['title'], true);?></h2><?php } ?>
                                <?php if($settings['text']){ ?><div class="sec-title_two-text sec-title__title"><?php echo wp_kses($settings['text'], true);?></div><?php } ?>
                            </div>
                            <?php } ?>
                            <?php if($settings['btn_titles']) { ?>
                            <div class="gallery-three_title_button">
                                <?php         	
                                   $this->add_link_attributes( 'btn_link', $settings['btn_link']);
                                ?>
                                <a <?php echo $this->get_render_attribute_string( 'btn_link' ); ?> class="thm-btn theme-btn btn-style-six">
                                    <span class="btn-wrap">
                                        <span class="text-one"><?php echo wp_kses($settings['btn_titles'], true);?> <i class="fas fa-arrow-circle-right fa-fw"></i></span>
                                        <span class="text-two"><?php echo wp_kses($settings['btn_titles'], true);?> <i class="fas fa-arrow-circle-right fa-fw"></i></span>
                                    </span>
                                </a>
                            </div>
                            <?php }; ?>
                        </div>
                    </div>
                    <?php
						while ( $query->have_posts() ) : $query->the_post();
						$term_list = wp_get_post_terms(get_the_id(), 'campaign_category', array("fields" => "names"));
						$campaign = charitable_get_current_campaign(); 
					?>
                    <?php $chartio_causes_meta = get_post_meta( get_the_ID(), 'chartio_meta_cause', true );?>
                    <!-- Gallery Block Two -->
                    <div class="gallery-block_two <?php if($chartio_causes_meta['dimension'] == 'extra_width') echo 'col-lg-6 col-md-12 col-sm-12'; else echo 'col-lg-3 col-md-6 col-sm-12'?>">
                        <div class="gallery-block_two-inner">
                            <div class="gallery-block_two-image">
                                <?php 
                                    $dimention = $chartio_causes_meta['dimension'];
                                    if($dimention == 'extra_width'){ 
                                        $size = 'chartio_960x510'; 
                                    } else { 
                                        $size = 'chartio_480x510';
                                    } the_post_thumbnail($size);
                                ?>
                                <div class="gallery-block_two-overlay">
                                    <div class="gallery-block_two-title"><?php echo implode( ', ', (array)$term_list );?></div><br>
                                    <h5 class="gallery-block_two-heading chartio-grid-title"><a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><?php the_title();?></a></h5>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php endwhile; ?>                    
                </div>
            </div>
        </section>
        <!-- End Gallery Three -->
        
		<?php elseif($settings['causes_style'] == 4 ) : ?>
        
        <div class="cause-six chartio-causes-grid p-0 m-0">
            <div class="row clearfix">
                <?php
                    while ( $query->have_posts() ) : $query->the_post();
                    $campaign = charitable_get_current_campaign(); 
                ?>
                <!-- Cause Block Four -->
				<div class="cause-block_five <?php echo esc_attr( $classes );?>">
					<div class="cause-block_five-inner">
						<div class="cause-block_five-content">
							<div class="cause-block_five-image">
								<a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><?php the_post_thumbnail('chartio_230x320'); ?></a>
							</div>
							<h4 class="cause-block_five-heading chartio-grid-title"><a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><?php the_title();?></a></h4>
							<div class="cause-block_five-donations">
								<div class="justify-content-between d-flex flex-wrap chartio-grid-price">
									<span><?php echo esc_attr($campaign->get_percent_donated_raw());?>% <i><?php esc_html_e('Raised', 'chartio'); ?></i></span>
									<span><?php echo wp_kses($campaign->get_donation_summary(), true); ?> <i><?php esc_html_e('Goals', 'chartio'); ?></i></span>
								</div>
							</div>
							<div class="cause-block_five-text chartio-grid-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
							<div class="cause-block_five-lower">
								<div class="d-flex justify-content-between flex-wrap align-items-center">
									<ul class="cause-block_five-authors">
										<?php $users = get_users(); foreach ( $users as $user ) {?>
                                        	<li><?php echo get_avatar( $user->ID, 41 ); ?></li>
                                        <?php }?>
									</ul>
									<div class="cause-block_five-button">
										<a href="<?php echo charitable_get_permalink( 'campaign_donation_page', array( 'campaign_id' => $campaign->ID ) ); ?>" class="theme-btn btn-style-four chartio-grid-btn-title">
											<span class="btn-wrap">
												<span class="text-one">
                                                    <?php if( !empty( $btn_title ) ):?>
                                                        <?php echo wp_kses( $btn_title, true );?>
                                                    <?php else:?>
                                                        <?php esc_html_e('Donate Now', 'chartio');?>
                                                    <?php endif;?>
                                                    <i class="fas fa-arrow-right fa-fw"></i>
                                                </span>
                                                <span class="text-two">
                                                    <?php if( !empty( $btn_title ) ):?>
                                                        <?php echo wp_kses( $btn_title, true );?>
                                                    <?php else:?>
                                                        <?php esc_html_e('Donate Now', 'chartio');?>
                                                    <?php endif;?>
                                                    <i class="fas fa-arrow-right fa-fw"></i>
                                                </span>
											</span>
										</a>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
                <?php endwhile; ?>
        	</div>
        </div>
        
        <?php elseif($settings['causes_style'] == 3 ) : ?>
        
        <div class="cause-six chartio-causes-grid p-0 m-0">
            <div class="row clearfix">
                <?php
                    while ( $query->have_posts() ) : $query->the_post();
                    $campaign = charitable_get_current_campaign(); 
                ?>
                <!-- Cause Block Four -->
                <div class="cause-block_four <?php echo esc_attr( $classes );?>">
                    <div class="cause-block_four-inner">
                        <div class="cause-block_four-image">
                            <?php the_post_thumbnail('chartio_387x309'); ?>
                        </div>
                        <div class="cause-block_four-content">
                            <div class="cause-block_four-info">
                                <div class="d-flex justify-content-between align-items-center flex-wrap">
                                    <div class="cause-block_four-location">LOS ANGELES, CA</div>
                                    <div class="cause-block_four-icons">
                                        <a class="fas fa-camera fa-fw" href="#"></a>
                                        <a class="fas fa-play-circle fa-fw" href="#"></a>
                                    </div>
                                </div>
                            </div>
                            <h4 class="cause-block_four-heading chartio-grid-title"><a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><?php the_title();?></a></h4>
                            <div class="cause-block_four-text chartio-grid-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                            <div class="cause-block_four-donations">
                                <div class="bar progress-line" data-width="<?php echo esc_attr($campaign->get_percent_donated_raw());?>"><div class="count-box"><span class="count-text" data-speed="2500" data-stop="<?php echo esc_attr($campaign->get_percent_donated_raw());?>"><?php echo esc_attr($campaign->get_percent_donated_raw());?></span>%</div></div>
                                <div class="justify-content-between d-flex flex-wrap">
                                    <span><?php echo esc_attr($campaign->get_percent_donated_raw());?>% <i><?php esc_html_e('Raised', 'chartio'); ?></i></span>
                                    <span><?php echo wp_kses($campaign->get_donation_summary(), true); ?> <i><?php esc_html_e('Goals', 'chartio'); ?></i></span>
                                    <i class="cause-block_four-border-bottom"></i>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <?php endwhile; ?>
        	</div>
        </div>
        
        <?php elseif($settings['causes_style'] == 2 ) : ?>
        
        <div class="cause-six chartio-causes-grid p-0 m-0">
            <div class="row clearfix">
                <?php
                    while ( $query->have_posts() ) : $query->the_post();
                    $campaign = charitable_get_current_campaign(); 
                ?>        
                <!-- Cause Block Two -->
                <div class="cause-block_two <?php echo esc_attr( $classes );?>">
                    <div class="cause-block_two-inner">
                        <div class="cause-block_two-image-outer">
                            <div class="cause-block_two-image">
                                <a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><?php the_post_thumbnail('chartio_327x311'); ?></a>
                                <div class="cause-block_two-location">
                                    LOS ANGELES, CA
                                </div>
                            </div>
                        </div>
                        <div class="cause-block_two-content">
                            <h3 class="cause-block_two-heading chartio-grid-title"><a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><?php the_title();?></a></h3>
                            <div class="cause-block_two-text chartio-grid-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                            <div class="cause-block_two-price d-flex justify-content-between align-items-center flex-wrap chartio-grid-price"><span><?php esc_html_e('Goals:  ', 'chartio'); ?><?php echo wp_kses($campaign->get_donation_summary(), true); ?></span> <i><?php esc_html_e('Raised:  ', 'chartio'); ?> <?php echo esc_attr($campaign->get_percent_donated_raw());?>%</i></div>
                            <div class="cause-block_two-lower">
                                <div class="d-flex justify-content-between flex-wrap align-items-center">
                                    <ul class="cause-block_two-authors">
                                        <?php $users = get_users(); foreach ( $users as $user ) {?>
                                        	<li><?php echo get_avatar( $user->ID, 41 ); ?></li>
                                        <?php }?>
                                    </ul>                                    
                                    <div class="cause-block_two-button">
                                        <a href="<?php echo charitable_get_permalink( 'campaign_donation_page', array( 'campaign_id' => $campaign->ID ) ); ?>" class="theme-btn btn-style-three chartio-grid-btn-title">
                                            <span class="btn-wrap">
                                                <span class="text-one">
                                                    <?php if( !empty( $btn_title ) ):?>
                                                        <?php echo wp_kses( $btn_title, true );?>
                                                    <?php else:?>
                                                        <?php esc_html_e('donate now', 'chartio');?>
                                                    <?php endif;?>
                                                    <i class="fas fa-arrow-right fa-fw"></i>
                                                </span>
                                                <span class="text-two">
                                                    <?php if( !empty( $btn_title ) ):?>
                                                        <?php echo wp_kses( $btn_title, true );?>
                                                    <?php else:?>
                                                        <?php esc_html_e('donate now', 'chartio');?>
                                                    <?php endif;?>
                                                    <i class="fas fa-arrow-right fa-fw"></i>
                                                </span>
                                            </span>
                                        </a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <?php endwhile; ?>
            </div>
        </div>
        
        <?php else: ?>
        
        <!-- Cause One -->
        <section class="cause-one jarallax chartio-causes-grid">
            <div class="cause-one_pattern-layer" <?php if($settings['pattern_image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['pattern_image']['id'])); ?>)"<?php } ?>></div>
            <?php if($settings['image']['id']){ ?><div class="cause-one_image-layer" style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['image']['id'])); ?>)"></div><?php } ?>
            <div class="auto-container">
                <?php if($settings['title'] || $settings['text']){ ?>
                <!-- Sec Title -->
                <div class="sec-title centered light">
                    <?php if($settings['title']){ ?><div class="sec-title_title tx-split-text split-in-up sec-title__tagline"><?php echo wp_kses($settings['title'], true);?></div><?php } ?>
                    <?php if($settings['text']){ ?><h2 class="sec-title_heading tx-split-text split-in-up sec-title__title"><?php echo wp_kses($settings['text'], true);?></h2><?php } ?>
                </div>
                <?php } ?>
                <div class="row clearfix">
    				<?php
						$count = 1;
						while ( $query->have_posts() ) : $query->the_post();
						$campaign = charitable_get_current_campaign(); 
					?>
                    <!-- Cause Block One -->
                    <div class="cause-block_one">
                        <div class="cause-block_one-inner">
                            <div class="cause-block_one-image-outer">
                                <div class="cause-block_one-color_layer"></div>
                                <div class="cause-block_one-image">
                                    <?php the_post_thumbnail('chartio_214x214'); ?>
                                    <div class="cause-block_one-overlay">
                                        <a href="<?php echo charitable_get_permalink( 'campaign_donation_page', array( 'campaign_id' => $campaign->ID ) ); ?>" class="theme-btn btn-style-one chartio-grid-btn-title">
                                            <span class="btn-wrap">
                                                <span class="text-one">
                                                	<?php if( !empty( $btn_title ) ):?>
														<?php echo wp_kses( $btn_title, true );?>
                                                    <?php else:?>
                                                        <?php esc_html_e('donate now', 'chartio');?>
                                                    <?php endif;?>
                                                </span>
                                                <span class="text-two">
                                                	<?php if( !empty( $btn_title ) ):?>
														<?php echo wp_kses( $btn_title, true );?>
                                                    <?php else:?>
                                                        <?php esc_html_e('donate now', 'chartio');?>
                                                    <?php endif;?>
                                                </span>
                                            </span>
                                        </a>
                                    </div>
                                </div>
                            </div>
                            <div class="cause-block_one-content">
                                <h6 class="cause-block_one-heading chartio-grid-title"><a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><?php the_title();?></a></h6>
                                <?php if ( $campaign->has_goal() ){ ?>
                                <div class="cause-block_one-price chartio-grid-price <?php if($count == 5 ) echo 'color-five'; elseif($count == 4) echo 'color-four'; elseif($count == 3) echo 'color-three'; elseif($count == 2) echo 'color-two'; else echo ''; ?>">
                                	<span><?php echo esc_attr($campaign->get_percent_donated_raw());?>%</span> <?php echo wp_kses($campaign->get_donation_summary(), true); ?><?php esc_html_e(' Goal', 'chartio'); ?>
                                </div>
                            	<?php } ?>
                            </div>
                        </div>
                    </div>
    				<?php $count++; endwhile; ?>
                </div>
    			<?php if($settings['btn_titles']) { ?>
                <div class="cause-one_button centered">
                    <?php         	
					   $this->add_link_attributes( 'btn_link', $settings['btn_link']);
					?>
                    <a <?php echo $this->get_render_attribute_string( 'btn_link' ); ?> class="thm-btn theme-btn btn-style-one">
                        <span class="btn-wrap">
                            <span class="text-one"><?php echo wp_kses($settings['btn_titles'], true);?></span>
                            <span class="text-two"><?php echo wp_kses($settings['btn_titles'], true);?></span>
                        </span>
                    </a>
                </div>
    			<?php }; ?>
            </div>
        </section>
        <!-- End Cause One -->       
        
        <?php endif; ?>
        <?php }
        wp_reset_postdata();
    }
}
