<?php 
namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Text_Stroke;
use \Elementor\Group_Control_Css_Filter;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Causes_Tab extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'chartio_causes_tab';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Chartio Causes Tab', 'chartio' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open town';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'chartio' ];
    }
	
	public function get_script_depends() {
		wp_register_script( 'cause-tabs', YT_URL . 'assets/js/causes-tab.js', [ 'elementor-frontend' ], '1.0.0', true );
		return [ 'cause-tabs' ];
	}

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'causes_tab',
            [
                'label' => esc_html__( 'Causes Tab', 'chartio' ),
			]
        );					
		
		$this->add_control(
			'pattern_image',
			[
				'label' => esc_html__('Choose Pattern Image ', 'chartio'),							
				'type' => Controls_Manager::MEDIA,					
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);		
		//Our Slider		
		$repeater = new Repeater();	
		$repeater->add_control(
			'tab_btn_title',
			[
				'label'       => __( 'Tab Button Title', 'chartio' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Tab Button Title', 'chartio' ),
			]
		);	
		$repeater->add_control(
			'text_limit',
			[
				'label'   => esc_html__( 'Text Limit', 'chartio' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 15,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$repeater->add_control(
			'btn_title',
			[
				'label' => esc_html__( 'Button Title', 'elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Enter button title', 'elementor' ),
				'default' => esc_html__( 'Donate Now', 'elementor' ),
			]
		);	
		$repeater->add_control(
            'query_number',
            [
                'label'   => esc_html__( 'Number of post', 'chartio' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 4,
                'min'     => 1,
                'max'     => 100,
                'step'    => 1,
            ]
        );
        $repeater->add_control(
            'query_orderby',
            [
                'label'   => esc_html__( 'Order By', 'chartio' ),
				'label_block' => true,
                'type'    => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => array(
                    'date'       => esc_html__( 'Date', 'chartio' ),
                    'title'      => esc_html__( 'Title', 'chartio' ),
                    'menu_order' => esc_html__( 'Menu Order', 'chartio' ),
                    'rand'       => esc_html__( 'Random', 'chartio' ),
                ),
            ]
        );
        $repeater->add_control(
            'query_order',
            [
                'label'   => esc_html__( 'Order', 'chartio' ),
				'label_block' => true,
                'type'    => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => array(
                    'DESC' => esc_html__( 'DESC', 'chartio' ),
                    'ASC'  => esc_html__( 'ASC', 'chartio' ),
                ),
            ]
        );
        $repeater->add_control(
            'query_category',
            [
                'type' => Controls_Manager::SELECT,
                'label' => esc_html__('Category', 'chartio'),
				'label_block' => true,
                'options' => get_campaign_categories()
            ]
        );
		$this->add_control(
			'causes_tabs',
			[
				'label'                 => __('Add Causes Item', 'chartio'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
			]
		);		
        $this->end_controls_section();		
		
		//General Style
		$this->start_controls_section(
			'general_style',
			[
				'label' => esc_html__( 'General Setting', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
            'general_margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .chartio-causes-grid' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'general_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .chartio-causes-grid' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'general_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .chartio-causes-grid',				
			]
		);
		$this->end_controls_section();
		
		//Small Title Style
		$this->start_controls_section(
			'small_title_style',
			[
				'label' => esc_html__( 'Small Title', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,				
			]
		);
		
		$this->add_responsive_control(
            'small_title__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .sec-title__tagline' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'small_title_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .sec-title__tagline' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'small_title_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .sec-title__tagline',				
			]
		);
		
		$this->add_control(
			'small_title_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sec-title__tagline' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'small_title_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => '{{WRAPPER}} .sec-title__tagline',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Stroke::get_type(),
			[
				'name' => 'small_title_text_stroke',
				'selector' => '{{WRAPPER}} .sec-title__tagline',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'small_title_text_shadow',
				'selector' => '{{WRAPPER}} .sec-title__tagline',
			]
		);

		$this->end_controls_section();
		
		//Title Style		
		$this->start_controls_section(
			'title_style',
			[
				'label' => esc_html__( 'Title', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
            'title__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .sec-title__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'title_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .sec-title__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'title_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .sec-title__title',				
			]
		);
		
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sec-title__title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => '{{WRAPPER}} .sec-title__title',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Stroke::get_type(),
			[
				'name' => 'title_text_stroke',
				'selector' => '{{WRAPPER}} .sec-title__title',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'title_text_shadow',
				'selector' => '{{WRAPPER}} .sec-title__title',
			]
		);
		$this->end_controls_section();
		
		/**Loop Style**/
		$this->start_controls_section(
			'loop_style',
			[
				'label' => esc_html__('Loop Content Style Setting', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		//Loop Background Color Style
		$this->add_control(
			'show_loop_loop_style',
			[
				'label'       => __( 'ON/OFF  Loop Background Color Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);		
		$this->add_control(
            'loop_loop_bgcolor',
            [
                'label' => __('Loop Background Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .cause-block_one-color_layer' => 'background-color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_loop_style'    => 'yes',
				]
            ]
        );			
		//Title Style
		$this->add_control(
			'show_loop_title_style',
			[
				'label'       => __( 'ON/OFF  Title Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_title_typography',
                'label' => __('Title Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .chartio-grid-title,
								 .chartio-grid-title a',                 
                'separator' => 'before',
				'condition'             => [
					'show_loop_title_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_title_color',
            [
                'label' => __('Title Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-title a' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_title_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_title_hover_color',
            [
                'label' => __('Title Hover Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-title a:hover' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_title_style'    => 'yes',
				]
            ]
        );
		//Content Style
		$this->add_control(
			'show_loop_content_style',
			[
				'label'       => __( 'ON/OFF  Designation Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_content_typography',
                'label' => __('Price Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .chartio-grid-price,
								 .chartio-grid-price span',                 
                'separator' => 'before',
				'condition'             => [
					'show_loop_content_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_content_color',
            [
                'label' => __('Price Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-price' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-price span' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_content_style'    => 'yes',
				]
            ]
        );
		//Button Style
		$this->add_control(
			'show_loop_icon_style',
			[
				'label'       => __( 'ON/OFF Button Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_control(
            'loop_icon_bgcolor',
            [
                'label' => __('Button Background Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-btn-title' => 'background-color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_icon_typography',
                'label' => __('Button Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .chartio-grid-btn-title,
								 .chartio-grid-btn-title .text-one,
								 .chartio-grid-btn-title .text-two',                 
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_icon_color',
            [
                'label' => __('Button Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-btn-title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-btn-title .text-one' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-btn-title .text-two' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_icon_hover_bgcolor',
            [
                'label' => __('Button Hover Background Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-btn-title:hover' => 'background-color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_icon_hover_color',
            [
                'label' => __('Button Hover Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-btn-title:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-btn-title:hover .text-one' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-btn-title:hover .text-two' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );		
		$this->end_controls_section();		
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');				
	?>
		        
        <!-- Homeless One -->
        <section class="homeless-one chartio-causes-grid">
            <div class="auto-container">
                <div class="inner-container">                        
                    <!-- Homeless Info Tabs -->
                    <div class="homeless-info-tabs">
                        <div class="homeless-one_image" <?php if($settings['pattern_image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['pattern_image']['id'])); ?>)"<?php } ?>></div>
                        <!-- Homeless Tabs -->
                        <div class="homeless-tabs tabs-box">                            
                            <!-- Tab Btns -->
                            <ul class="tab-btns tab-buttons clearfix">
                                <?php $count = 1; foreach($settings['causes_tabs'] as $key => $item):?>
                                <li data-tab="#<?php echo esc_attr($count);?>" class="tab-btn <?php if($count == 1) echo 'active-btn';?>"><?php echo wp_kses($item['tab_btn_title'], true);?></li>
                                <?php $count++; endforeach; ?>
                            </ul> 
                            
                            <?php $count = 1; foreach($settings['causes_tabs'] as $keys => $item):
								
								$paged = chartio_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;
								
								$this->add_render_attribute( 'wrapper', 'class', 'templatepath-chartio' );
								$args = array(
									'post_type'      => 'campaign',
									'posts_per_page' => chartio_set( $item, 'query_number' ),
									'orderby'        => chartio_set( $item, 'query_orderby' ),
									'order'          => chartio_set( $item, 'query_order' ),
									'text_limit'     => chartio_set( $item, 'text_limit' ),
									'paged'         => $paged
								);
								
								if( chartio_set( $item, 'query_category' ) ) $args['campaign_category'] = chartio_set( $item, 'query_category' );
								$query = new \WP_Query( $args );
								if ( $query->have_posts()):	
							?>
                                                      
                            <!-- Tabs Container -->
                            <div class="tabs-content">
                                <?php
									while ( $query->have_posts() ) : $query->the_post();
									$term_list = wp_get_post_terms(get_the_id(), 'campaign_category', array("fields" => "names"));
									$campaign = charitable_get_current_campaign(); 
									$btn_title = $item[ 'btn_title' ];
								?>
                                <!-- Tab / Active Tab -->
                                <div class="tab <?php if($count == 1) echo 'active-tab';?>" id="<?php echo esc_attr($count);?>">
                                    <div class="content d-flex">
                                        <div class="left-box">
                                            <div class="homeless-one_pattern" style="background-image:url(<?php echo esc_url(get_template_directory_uri());?>/assets/images/background/pattern-8.jpg)"></div>
                                            <div class="image">
                                                <?php the_post_thumbnail('chartio_402x558'); ?>
                                                <div class="donated_hands">31,120 <br> Raise Your Hand</div>
                                            </div>
                                        </div>    
                                        <!-- Right Box -->
                                        <div class="right-box">
                                            <!-- Sec Title Two -->
                                            <div class="sec-title_two light">
                                                <div class="sec-title_two-title sec-title__tagline"><?php echo implode( ', ', (array)$term_list );?></div>
                                                <h2 class="sec-title_two-heading sec-title__title"><?php the_title();?></h2>
                                            </div>
                                            <div class="homeless-one_grants chartio-grid-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $item['text_limit']), true); ?></div>
                                            <div class="homeless-one_progress-price chartio-grid-price">$4,410 <span><?php esc_html_e('Raised', 'chartio'); ?></span></div>
                                            <div class="homeless-one_progress">
                                                <div class="bar progress-line" data-width="<?php echo esc_attr($campaign->get_percent_donated_raw());?>"><div class="count-box"><span class="count-text" data-speed="2500" data-stop="<?php echo esc_attr($campaign->get_percent_donated_raw());?>">0</span>%</div></div>
                                            </div>
                                            <div class="homeless-one_discount"><?php echo esc_attr($campaign->get_percent_donated_raw());?>% <?php esc_html_e('Donation Collected', 'chartio'); ?></div>
                                            <div class="homeless-one_button">
                                                <a href="<?php echo charitable_get_permalink( 'campaign_donation_page', array( 'campaign_id' => $campaign->ID ) ); ?>" class="theme-btn btn-style-three chartio-grid-btn-title">
                                                    <span class="btn-wrap">
                                                        <span class="text-one">
                                                            <?php if( !empty( $btn_title ) ):?>
                                                                <?php echo wp_kses( $btn_title, true );?>
                                                            <?php else:?>
                                                                <?php esc_html_e('Donate Now', 'chartio');?>
                                                            <?php endif;?>
                                                            <i class="fas fa-arrow-right fa-fw"></i>
                                                        </span>
                                                        <span class="text-two">
                                                            <?php if( !empty( $btn_title ) ):?>
                                                                <?php echo wp_kses( $btn_title, true );?>
                                                            <?php else:?>
                                                                <?php esc_html_e('Donate Now', 'chartio');?>
                                                            <?php endif;?>
                                                            <i class="fas fa-arrow-right fa-fw"></i>
                                                        </span>
                                                    </span>
                                                </a>
                                            </div>
                                        </div>    
                                    </div>
                                </div>
    							<?php endwhile; ?>
                            </div>
                            <?php endif;?>
							<?php $count++; endforeach;?>
                        </div>
                    </div>    
                </div>
            </div>
        </section>
        <!-- End Homeless One -->
        
        <?php 
	}

}
