<?php namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Event_Grid extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'chartio_event_grid';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Chartio Event Grid', 'chartio' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open town';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'chartio' ];
    }

    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'event_grid',
            [
                'label' => esc_html__( 'Towngov Event Grid', 'chartio' ),
			]
        );
		
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'chartio'),
					'2' => esc_html__( 'Style Two ', 'chartio'),
				),
			]
		);
		
		$this->add_control(
			'col_grid',
			[
				'label'   => esc_html__( 'Choose Column', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'default',
				'options' => array(
					'default'  => esc_html__( 'Default', 'chartio' ),
					'one' => esc_html__( 'One Column Grid ', 'chartio'),
					'two'  => esc_html__( 'Two Column Grid', 'chartio' ),
					'three'  => esc_html__( 'Three Column Grid', 'chartio' ),
					'four'  => esc_html__( 'Four Column Grid', 'chartio' )
				),
				'condition' => [
					'layout_control'  => '2'
				],
			]
		);
		$this->add_control(
            'text_limit',
            [
                'label'   => esc_html__( 'Number of Text', 'chartio' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 15,
                'min'     => 1,
                'max'     => 100,
                'step'    => 1,
            ]
        );
		$this->add_control(
			'btn_title',
			[
				'label' => esc_html__( 'Button Title', 'elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Enter button title', 'elementor' ),
				'default' => esc_html__( 'Join Event ', 'elementor' ),
			]
		);
        $this->add_control(
            'query_number',
            [
                'label'   => esc_html__( 'Number of post', 'chartio' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 4,
                'min'     => 1,
                'max'     => 100,
                'step'    => 1,
            ]
        );
        $this->add_control(
            'query_orderby',
            [
                'label'   => esc_html__( 'Order By', 'chartio' ),
				'label_block' => true,
                'type'    => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => array(
                    'date'       => esc_html__( 'Date', 'chartio' ),
                    'title'      => esc_html__( 'Title', 'chartio' ),
                    'menu_order' => esc_html__( 'Menu Order', 'chartio' ),
                    'rand'       => esc_html__( 'Random', 'chartio' ),
                ),
            ]
        );
        $this->add_control(
            'query_order',
            [
                'label'   => esc_html__( 'Order', 'chartio' ),
				'label_block' => true,
                'type'    => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => array(
                    'DESC' => esc_html__( 'DESC', 'chartio' ),
                    'ASC'  => esc_html__( 'ASC', 'chartio' ),
                ),
            ]
        );
        $this->add_control(
            'query_category',
            [
                'type' => Controls_Manager::SELECT,
                'label' => esc_html__('Category', 'chartio'),
				'label_block' => true,
                'options' => get_events_categories()
            ]
        );
        $this->end_controls_section();
    /** Style Tab **/
		$this->register_style_background_controls();
    }
	
	/************************************************************************
								Tab Style Start
	*************************************************************************/
	
	protected function register_style_background_controls()
	{
		
		/**Loop Style**/
		$this->start_controls_section(
			'loop_style',
			[
				'label' => esc_html__('LOOP CONTENT STYLE SETTING', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		//Loop Background Color Style
		$this->add_control(
			'show_loop_loop_style',
			[
				'label'       => __( 'ON/OFF  Loop Background Color Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);		
		$this->add_control(
            'loop_loop_bgcolor',
            [
                'label' => __('Loop Background Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-testi-grid' => 'background-color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_loop_style'    => 'yes',
				]
            ]
        );			
		//Title Style
		$this->add_control(
			'show_loop_title_style',
			[
				'label'       => __( 'ON/OFF  Title Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_title_typography',
                'label' => __('Title Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .chartio-testi-title,
								 .chartio-testi-title a',                 
                'separator' => 'before',
				'condition'             => [
					'show_loop_title_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_title_color',
            [
                'label' => __('Title Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-testi-title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-testi-title a' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_title_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_title_hover_color',
            [
                'label' => __('Title Hover Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-testi-title a:hover' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_title_style'    => 'yes',
				]
            ]
        );
		//Content Style
		$this->add_control(
			'show_loop_content_style',
			[
				'label'       => __( 'ON/OFF  Content Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_content_typography',
                'label' => __('Content Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .chartio-testi-text',                 
                'separator' => 'before',
				'condition'             => [
					'show_loop_content_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_content_color',
            [
                'label' => __('Content Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-testi-text' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_content_style'    => 'yes',
				]
            ]
        );
		//Meta List Style
		$this->add_control(
			'show_loop_meta_style',
			[
				'label'       => __( 'ON/OFF  Meta List Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_meta_typography',
                'label' => __('Meta List Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .chartio-testi-meta,
								 .chartio-testi-meta li',                 
                'separator' => 'before',
				'condition'             => [
					'show_loop_meta_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_meta_color',
            [
                'label' => __('Meta List Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-testi-meta' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-testi-meta li' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_meta_style'    => 'yes',
				]
            ]
        );
		//Icon Style
		$this->add_control(
			'show_loop_icon_style',
			[
				'label'       => __( 'ON/OFF Icon Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_control(
            'loop_icon_bgcolor',
            [
                'label' => __('Icon Background Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-testi-meta li .icon' => 'background-color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_icon_color',
            [
                'label' => __('Icon Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-testi-meta li .icon' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		//Button Style
		$this->add_control(
			'show_loop_btn_style',
			[
				'label'       => __( 'ON/OFF Button Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_control(
            'loop_btn_bgcolor',
            [
                'label' => __('Button Background Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-btn-title' => 'background-color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_btn_style'    => 'yes',
				]
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_btn_typography',
                'label' => __('Button Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .chartio-grid-btn-title,
								 .chartio-grid-btn-title .text-one,
								 .chartio-grid-btn-title .text-two',                 
                'separator' => 'before',
				'condition'             => [
					'show_loop_btn_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_btn_color',
            [
                'label' => __('Button Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-btn-title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-btn-title .text-one' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-btn-title .text-two' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_btn_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_btn_hover_bgcolor',
            [
                'label' => __('Button Hover Background Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-btn-title:hover' => 'background-color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_btn_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_btn_hover_color',
            [
                'label' => __('Button Hover Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-grid-btn-title:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-btn-title:hover .text-one' => 'color: {{VALUE}}',
					'{{WRAPPER}} .chartio-grid-btn-title:hover .text-two' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_btn_style'    => 'yes',
				]
            ]
        );
		$this->end_controls_section();
		
		
	}

   	 /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
		$btn_title = $settings[ 'btn_title' ];
		
		$grid_col = $settings[ 'col_grid' ];
		if( $grid_col == 'one' ){
			$classes = 'col-lg-12 col-md-12 col-sm-12';
		}elseif( $grid_col == 'two' ){
			$classes = 'col-lg-6 col-md-6 col-sm-12';
		}elseif( $grid_col == 'three' ){
			$classes = 'col-lg-4 col-md-6 col-sm-12';
		}elseif( $grid_col == 'four' ){
			$classes = 'col-lg-3 col-md-6 col-sm-12';
		}elseif( $grid_col == 'five' ){
			$classes = 'col-lg-2 col-md-6 col-sm-12';
		}else{
			$classes = 'col-lg-4 col-md-6 col-sm-12';
		}

        $paged = chartio_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;

        $this->add_render_attribute( 'wrapper', 'class', 'templatepath-chartio' );
        $args = array(
            'post_type'      => 'tribe_events',
            'posts_per_page' => chartio_set( $settings, 'query_number' ),
            'orderby'        => chartio_set( $settings, 'query_orderby' ),
            'order'          => chartio_set( $settings, 'query_order' ),
            'paged'         => $paged
        );

        if( chartio_set( $settings, 'query_category' ) ) $args['tribe_events_cat'] = chartio_set( $settings, 'query_category' );
        $query = new \WP_Query( $args );
		
        if ( $query->have_posts() ) { 
	?>
    
    <?php if($settings['layout_control'] == '2') : ?>
    
    <div class="row clearfix">
		<?php 
			while ( $query->have_posts() ) : $query->the_post(); 
			global $post;
			$term_list = wp_get_post_terms(get_the_id(), 'tribe_events_cat', array("fields" => "names"));
			$event_thumbnail_id = get_post_thumbnail_id($post->ID);
			$event_thumbnail_url = wp_get_attachment_url($event_thumbnail_id); 
			$start_date = tribe_get_start_date( $post->ID, true, 'd' );
			$start_month = tribe_get_start_date( $post->ID, true, 'M' );
			$start_year = tribe_get_start_date( $post->ID, true, 'Y' );
			$end_date = tribe_get_start_date( $post->ID, true, 'd' );
			$start_time = tribe_get_start_time ( $post->ID, 'h:i A' );
			$end_time = tribe_get_end_time ( $post->ID, 'h:i A' );
		?>
        <!-- Event Block One -->
        <div class="event-block_two <?php echo esc_attr( $classes );?>">
            <div class="event-block_two-inner wow fadeInUp" data-wow-delay="0ms" data-wow-duration="1500ms">
                <div class="event-block_two-image">
                    <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo (get_the_post_thumbnail($post->ID, 'chartio_595x313')); ?></a>
                    <div class="event-block_two-date">
                        <?php echo wp_kses($start_date, true); ?>
                        <span><?php echo wp_kses($start_month, true); ?></span>
                    </div>
                </div>
                <div class="event-block_two-content chartio-testi-grid">
                    <ul class="event-block_two-meta chartio-testi-meta">
                        <li><span class="icon fas fa-map-marker-alt fa-fw"></span><?php echo tribe_get_venue( $post->ID ); ?></li>
                        <li><span class="icon fas fa-clock fa-fw"></span><?php echo wp_kses($start_time, true); ?> - <?php echo wp_kses($end_time, true); ?></li>
                    </ul>
                    <h3 class="event-block_two-heading chartio-testi-title"><a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php the_title();?></a></h3>
                    <div class="event-block_two-text chartio-testi-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                    <div class="event-block_two-lower">
                        <div class="d-flex justify-content-between align-items-center">
                            <div class="event-block_two-author chartio-testi-meta"><?php esc_html_e('Organized By :', 'chartio');?> <span><?php the_author(); ?></span></div>
                            <a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="theme-btn btn-style-four chartio-grid-btn-title">
                                <span class="btn-wrap">
                                    <span class="text-one">
										<?php if( !empty( $btn_title ) ):?>
                                            <?php echo wp_kses( $btn_title, true );?>
                                        <?php else:?>
                                            <?php esc_html_e('Join Event ', 'chartio');?>
                                        <?php endif;?>
                                        <i class="fas fa-arrow-right fa-fw"></i>
                                    </span>
                                    <span class="text-two">
                                        <?php if( !empty( $btn_title ) ):?>
                                            <?php echo wp_kses( $btn_title, true );?>
                                        <?php else:?>
                                            <?php esc_html_e('Join Event ', 'chartio');?>
                                        <?php endif;?>
                                        <i class="fas fa-arrow-right fa-fw"></i>
                                    </span>
                                </span>
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php endwhile; ?>
    </div>
    
    <?php else: ?>
    
    <?php 
		while ( $query->have_posts() ) : $query->the_post(); 
		global $post;
		$term_list = wp_get_post_terms(get_the_id(), 'tribe_events_cat', array("fields" => "names"));
		$event_thumbnail_id = get_post_thumbnail_id($post->ID);
		$event_thumbnail_url = wp_get_attachment_url($event_thumbnail_id); 
		$start_date = tribe_get_start_date( $post->ID, true, 'd' );
		$start_month = tribe_get_start_date( $post->ID, true, 'M' );
		$start_year = tribe_get_start_date( $post->ID, true, 'Y' );
		$end_date = tribe_get_start_date( $post->ID, true, 'd' );
		$start_time = tribe_get_start_time ( $post->ID, 'h:i A' );
		$end_time = tribe_get_end_time ( $post->ID, 'h:i A' );
	?>
    <!-- Event Block One -->
    <div class="event-block_one">
        <div class="event-block_one-inner wow fadeInUp" data-wow-delay="0ms" data-wow-duration="1500ms">
            <div class="event-block_one-image">
                <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo (get_the_post_thumbnail($post->ID, 'chartio_407x207')); ?></a>
            </div>
            <div class="event-block_one-content chartio-testi-grid">
                <h3 class="event-block_one-heading chartio-testi-title"><a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php the_title();?></a></h3>
                <div class="event-block_one-text chartio-testi-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                <ul class="event-block_one-meta chartio-testi-meta">
                    <li><span class="icon fas fa-map-marker-alt fa-fw"></span><?php echo tribe_get_venue( $post->ID ); ?></li>
                    <li><span class="icon fas fa-clock fa-fw"></span><?php echo wp_kses($start_time, true); ?> - <?php echo wp_kses($end_time, true); ?></li>
                </ul>
            </div>
            <div class="event-block_one-button">
                <a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="theme-btn btn-style-five chartio-grid-btn-title">
                    <span class="btn-wrap">
                        <span class="text-one">
							<?php if( !empty( $btn_title ) ):?>
                                <?php echo wp_kses( $btn_title, true );?>
                            <?php else:?>
                                <?php esc_html_e('Join Event ', 'chartio');?>
                            <?php endif;?>
                            <i class="fas fa-arrow-right fa-fw"></i>
                        </span>
                        <span class="text-two">
                            <?php if( !empty( $btn_title ) ):?>
                                <?php echo wp_kses( $btn_title, true );?>
                            <?php else:?>
                                <?php esc_html_e('Join Event ', 'chartio');?>
                            <?php endif;?>
                            <i class="fas fa-arrow-right fa-fw"></i>
                        </span>
                    </span>
                </a>
            </div>
        </div>
    </div>
    <?php endwhile; ?>   
    
    <?php endif; ?>    
        <?php }

        wp_reset_postdata();
    }
}
