<?php
namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Float_Image extends Widget_Base {
	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'chartio_float_image';
	}
	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Chartio Float Image', 'chartio' );
	}
	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image';
	}
	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'chartio' ];
	}
	
	public function get_script_depends() {
		wp_register_script( 'float-counter', YT_URL . 'assets/js/float-image.js', [ 'elementor-frontend' ], '1.0.0', true );
		return [ 'float-counter' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'float_image',
			[
				'label' => esc_html__( 'Float Image', 'chartio' ),
			]
		);
		
		$this->add_control(
			'image_style',
			[
				'label'   => esc_html__( 'Choose Image Style', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'chartio'),
					'2' => esc_html__( 'Style Two', 'chartio' ),
					'3' => esc_html__( 'Style Three', 'chartio' ),
					'4' => esc_html__( 'Style Four', 'chartio' ),
					'5' => esc_html__( 'Style Five', 'chartio' ),
					'6' => esc_html__( 'Style Six', 'chartio' ),
					'7' => esc_html__( 'Style Seven', 'chartio' ),
					'8' => esc_html__( 'Style Eight', 'chartio' ),
					'9' => esc_html__( 'Style Nine', 'chartio' ),
				),
			]
		);		
		
		$this->add_control(
			'block_img',
			[
				'label' => esc_html__('Choose Image ', 'chartio'),							
				'type' => Controls_Manager::MEDIA,	
				'condition' => [ 'image_style' => ['1', '2', '3', '4', '5', '6', '7', '8', '9'], ],						
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
            'video_link',
			[
				'label' => __( 'Video Url', 'chartio-plugin' ),
				'type' => Controls_Manager::URL,
				'condition' => [ 'image_style' => '6', ],	
				'label_block' => true, 
				'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);
		$this->add_control(
			'block_img2',
			[
				'label' => esc_html__('Choose Image 2', 'chartio'),							
				'type' => Controls_Manager::MEDIA,
				'condition' => [ 'image_style' => ['1', '3', '4'], ],
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'block_img3',
			[
				'label' => esc_html__('Choose Image 3', 'chartio'),							
				'type' => Controls_Manager::MEDIA,
				'condition' => [ 'image_style' => ['1', '3'], ],							
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'block_img4',
			[
				'label' => esc_html__('Choose Image 4', 'chartio'),							
				'type' => Controls_Manager::MEDIA,	
				'condition' => [ 'image_style' => '1', ],						
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'block_img5',
			[
				'label' => esc_html__('Choose Image 5', 'chartio'),							
				'type' => Controls_Manager::MEDIA,	
				'condition' => [ 'image_style' => '1', ],						
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'block_img6',
			[
				'label' => esc_html__('Choose Image 6', 'chartio'),							
				'type' => Controls_Manager::MEDIA,		
				'condition' => [ 'image_style' => '1', ],					
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'block_img7',
			[
				'label' => esc_html__('Choose Image 7', 'chartio'),							
				'type' => Controls_Manager::MEDIA,	
				'condition' => [ 'image_style' => '1', ],						
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'counter_stop',
			[
				'label' => esc_html__('Counter Value', 'chartio'),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Counter Value', 'chartio' ),
			]
		);
		$repeater->add_control(
			'alphabet_letter',
			[
				'label' => esc_html__('Alphabet Letter', 'chartio'),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Alphabet Letter', 'chartio' ),
			]
		);
		$repeater->add_control(
			'block_title',
			[
				'label' => esc_html__('Block Title', 'chartio'),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Block Title', 'chartio' ),
			]
		);
		$this->add_control(
			'counter',
			[
				'label'                 => __('Add Counter Item', 'chartio'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition' => [ 'image_style' => '6', ],
			]
		);
		
		$this->end_controls_section();
    }
	
	
	/**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
	?>
    
	<?php if($settings['image_style'] == 9): ?>
    
    <?php if($settings['block_img']['id']) { ?>
    <!-- Images Column -->
    <div class="images-column">
        <div class="inner-column">
            <!-- Image -->
            <div class="image">
                <img src="<?php echo esc_url(wp_get_attachment_url($settings['block_img']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'chartio');?>" />
            </div>
        </div>
    </div>
    <?php } ?>
	
	<?php elseif($settings['image_style'] == 8): ?>
    
    <!-- Cause Two -->
	<section class="cause-two style-two p-0 m-0">
		<div class="cause-one_pattern-layer" style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['block_img']['id'])); ?>)"></div>
    </section>
    
    <?php elseif($settings['image_style'] == 7): ?>
    
    <!-- Gallery One -->
	<section class="gallery-one p-0 m-0">
		<div class="gallery-one_image-layer" style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['block_img']['id'])); ?>)"></div>
    </section>
    
	<?php elseif($settings['image_style'] == 6): ?>
    
    <!-- Image Column -->
    <div class="help-one_image-column">
        <div class="help-one_image-inner wow fadeInLeft" data-wow-delay="0ms" data-wow-duration="1500ms">
            <?php if($settings['block_img']['id'] || $settings['video_link']['url']) { ?>
            <!-- Video Box -->
            <div class="video-box">
                <figure class="video-image">
                    <?php if($settings['block_img']['id']) { ?><img src="<?php echo esc_url(wp_get_attachment_url($settings['block_img']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image','chartio');?>"><?php } ?>
                    <?php if($settings['video_link']['url']) { ?><a href="<?php echo esc_url($settings['video_link']['url']);?>" class="lightbox-video overlay-box"><span class="fa-solid fa-play fa-fw"><i class="ripple"></i></span></a><?php } ?>
                </figure>
            </div>
			<?php } ?>
            <div class="help-one_counter-outer">
				<?php $i = 1; foreach($settings['counter'] as $key => $item):?>
                <!-- Help One Counter -->
                <div class="help-one_counter">
                    <div class="help-one_counter-inner">
                        <div class="help-one_counter-count"><span class="odometer" data-count="<?php echo esc_attr($item['counter_stop']);?>"></span><?php echo esc_attr($item['alphabet_letter']);?></div>
                        <div class="help-one_counter-text"><?php echo esc_attr($item['block_title']);?></div>
                    </div>
                </div>
				<?php $i++; endforeach;?>
            </div>

        </div>
    </div>
	
    <?php elseif($settings['image_style'] == 5): ?>
    
    <?php if($settings['block_img']['id']) { ?>
    <!-- Image Column -->
    <div class="inspire-one_image-column">
        <div class="inspire-one_image-inner">
            <div class="inspire-one_image wow fadeInLeft" data-wow-delay="0ms" data-wow-duration="1500ms">
                <img src="<?php echo esc_url(wp_get_attachment_url($settings['block_img']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image','chartio');?>" />
            </div>
        </div>
    </div>
    <?php }; ?>
    
    <?php elseif($settings['image_style'] == 4): ?>
    
    <!-- Image Column -->
    <div class="cause-four_image-column">
        <div class="cause-four_image-outer wow fadeInLeft" data-wow-delay="0ms" data-wow-duration="1500ms">
            <?php if($settings['block_img']['id']) { ?>
            <div class="cause-four_image">
                <img src="<?php echo esc_url(wp_get_attachment_url($settings['block_img']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image','chartio');?>" />
            </div>
            <?php }; ?>
            <?php if($settings['block_img2']['id']) { ?>
            <div class="cause-four_image-two" data-parallax='{"y" : 30}'>
                <img src="<?php echo esc_url(wp_get_attachment_url($settings['block_img2']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image','chartio');?>" />
            </div>
            <?php }; ?>
        </div>
    </div>
    
    <?php elseif($settings['image_style'] == 3): ?>
    
    <!-- Image Column -->
    <div class="welcome-two_image-column">
        <div class="welcome-two_image-inner">
           	<?php if($settings['block_img']['id']) { ?>
            <div class="welcome-two_globe" style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['block_img']['id'])); ?>)"></div>
            <?php }; ?>
            <?php if($settings['block_img2']['id']) { ?>
            <div class="welcome-two_image-one">
                <img src="<?php echo esc_url(wp_get_attachment_url($settings['block_img2']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image','chartio');?>" />
            </div>
            <?php }; ?>
            <?php if($settings['block_img3']['id']) { ?>
            <div class="welcome-two_image-two" data-parallax='{"y" : 60}'>
                <img src="<?php echo esc_url(wp_get_attachment_url($settings['block_img3']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image','chartio');?>" />
            </div>
            <?php }; ?>
        </div>
    </div>
    
    <?php elseif($settings['image_style'] == 2): ?>
    
    <?php if($settings['block_img']['id']) { ?>
    <!-- Image Column -->
    <div class="faq-one_image-column">
        <div class="faq-one_image-inner parallax-scene-1">
            <div class="faq-one_image" data-depth="0.20">
                <img src="<?php echo esc_url(wp_get_attachment_url($settings['block_img']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image','chartio');?>" />
            </div>
        </div>
    </div>
    <?php }; ?>
    
    <?php else: ?>
    
    <!-- Images Column -->
    <div class="welcome-one_images-column">
        <div class="welcome-one_images-inner">
            <div class="welcome-one_images-outer animation_image_zoom">
                <span class="welcome-one_color-layer"></span>
                <?php if($settings['block_img']['id']) { ?><img src="<?php echo esc_url(wp_get_attachment_url($settings['block_img']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image','chartio');?>" class="welcome-one__img"><?php } ?>
                <?php if($settings['block_img2']['id']) { ?><img src="<?php echo esc_url(wp_get_attachment_url($settings['block_img2']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image','chartio');?>" class="welcome-one__img-2"><?php } ?>
                <?php if($settings['block_img3']['id']) { ?><img src="<?php echo esc_url(wp_get_attachment_url($settings['block_img3']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image','chartio');?>" class="welcome-one__img-3"><?php } ?>
                <?php if($settings['block_img4']['id']) { ?><img src="<?php echo esc_url(wp_get_attachment_url($settings['block_img4']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image','chartio');?>" class="welcome-one__img-4"><?php } ?>
                <?php if($settings['block_img5']['id']) { ?><img src="<?php echo esc_url(wp_get_attachment_url($settings['block_img5']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image','chartio');?>" class="welcome-one__img-5"><?php } ?>
                <?php if($settings['block_img6']['id']) { ?><img src="<?php echo esc_url(wp_get_attachment_url($settings['block_img6']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image','chartio');?>" class="welcome-one__img-6"><?php } ?>
                <?php if($settings['block_img7']['id']) { ?><img src="<?php echo esc_url(wp_get_attachment_url($settings['block_img7']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image','chartio');?>" class="welcome-one__img-7"><?php } ?>
            </div>
        </div>
    </div>
    
    <?php endif;
	}
}