<?php
namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Funfacts extends Widget_Base {
	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'chartio_funfacts';
	}
	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Chartio Funfacts', 'chartio' );
	}
	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-counter';
	}
	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'chartio' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'funfacts',
			[
				'label' => esc_html__( 'Funfacts', 'chartio' ),
			]
		);
		
		$this->add_control(
			'fact_style',
			[
				'label'   => esc_html__( 'Layout Style', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'chartio'),
					'2' => esc_html__( 'Style Two ', 'chartio'),
				),
			]
		);
		
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'counter_stop',
			[
				'label' => esc_html__('Counter Value', 'chartio'),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Counter Value', 'chartio' ),
			]
		);
		$repeater->add_control(
			'alphabet_letter',
			[
				'label' => esc_html__('Alphabet Letter', 'chartio'),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Alphabet Letter', 'chartio' ),
			]
		);
		$this->add_control(
			'slides',
			[
				'label'                 => __('Add Amount Item', 'chartio'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition' => [ 'fact_style' => '1', ],
			]
		);		
		
		$this->add_control(
			'counter_stop2',
			[
				'label' => esc_html__('Counter Value', 'chartio'),
				'type'        => Controls_Manager::TEXT,
				'condition' => [ 'fact_style' => '2', ],
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Counter Value', 'chartio' ),
			]
		);
		$this->add_control(
			'alphabet_letter2',
			[
				'label' => esc_html__('Alphabet Letter', 'chartio'),
				'type'        => Controls_Manager::TEXT,
				'condition' => [ 'fact_style' => '2', ],
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Alphabet Letter', 'chartio' ),
			]
		);
		$this->add_control(
			'block_title',
			[
				'label' => esc_html__('Block Title', 'chartio'),
				'type'        => Controls_Manager::TEXT,
				'condition' => [ 'fact_style' => '2', ],
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Block Title', 'chartio' ),
			]
		);
		
		$this->end_controls_section();
		
		/** Style Tab **/
		$this->register_style_background_controls();
    }
	
	/************************************************************************
								Tab Style Start
	*************************************************************************/
	
	protected function register_style_background_controls()
	{
		
	}
	/**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
	?>        
	
    <?php if($settings['fact_style'] == 2): ?>
    
    <div class="cause-four_lower">
        <div class="cause-four_donation">
            <div class="cause-four_counter"><span class="odometer" data-count="<?php echo esc_attr($settings['counter_stop2']);?>"></span><?php echo esc_attr($settings['alphabet_letter2']);?></div>
            <div class="cause-four_donation-text"><?php echo esc_attr($settings['block_title']);?></div>
        </div>
    </div>
    
    <?php else: ?>
    
	<?php if( !empty( $settings['slides'] ) ):?>
    <!-- Welcome One -->
    <section class="welcome-one p-0 m-0">
        <div class="select-amount d-flex flex-wrap">
            <?php $i = 1; foreach($settings['slides'] as $key => $item):?>
            <div class="select-box"><input type="radio" name="payment-group" id="radio-<?php echo esc_attr($i);?>" <?php if($i == 1) echo 'checked'; else echo ''; ?>><label for="radio-<?php echo esc_attr($i);?>"><?php echo esc_attr($item['counter_stop']);?> <span><?php echo esc_attr($item['alphabet_letter']);?></span></label></div>
            <?php $i++; endforeach;?>
        </div>
    </section>
    <?php endif;?>
    
    <?php endif;
	
	}
}