<?php 
namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;
/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Icon_Box extends Widget_Base {
    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'chartio_icon_box';
    }
    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Chartio Icon Box', 'chartio' );
    }
    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-icon-box';
    }
    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'chartio' ];
    }
	
	public function get_script_depends() {
		wp_register_script( 'icon-carousel', YT_URL . 'assets/js/icon-counter.js', [ 'elementor-frontend' ], '1.0.0', true );
		return [ 'icon-carousel' ];
	}	
	
    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'icon_box',
            [
                'label' => esc_html__( 'Icon Box', 'chartio' ),
            ]
        );
		
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'chartio'),
					'2' => esc_html__( 'Style Two ', 'chartio'),
					'3' => esc_html__( 'Style Three ', 'chartio'),
					'4' => esc_html__( 'Style Four ', 'chartio'),
					'5' => esc_html__( 'Style Five ', 'chartio'),
				),
			]
		);
		
		$this->add_control(
			'image',
			[
				'label' => esc_html__( 'Choose Image', 'chartio-plugin' ),
				'type' => Controls_Manager::MEDIA,
				'condition'  => [ 'layout_control' => '5', ],
				'dynamic' => [	'active' => true, ],
				'default' => [	'url' => Utils::get_placeholder_image_src(),],
			]
		);
		
		$this->add_control(
			'icon',
			[
				'label' => esc_html__('Enter The icons', 'chartio'),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'solid',
				],
				'condition' => [ 'layout_control' => ['1', '2', '3', '4', '5'], ]
			]
			
		);		
		$this->add_control(
			'title',
			[
				'label' => esc_html__( 'Title', 'chartio' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Enter your title', 'chartio' ),
				'default' => esc_html__( 'Let’s Sponsor an Entire Project', 'chartio' ),
				'condition' => [ 'layout_control' => ['1', '2', '3', '5'], ]
			]
		);
		$this->add_control(
			'counter_stop2',
			[
				'label' => esc_html__( 'Counter Value', 'chartio' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Enter your Counter Value', 'chartio' ),
				'default' => esc_html__( '1.7', 'chartio' ),
				'condition' => [ 'layout_control' => '4', ]
			]
		);
		$this->add_control(
			'alphabet_letter2',
			[
				'label' => esc_html__( 'Alphabet Letter', 'chartio' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Enter your Alphabet Letter', 'chartio' ),
				'default' => esc_html__( 'm', 'chartio' ),
				'condition' => [ 'layout_control' => '4', ]
			]
		);		
		$this->add_control(
			'text',
			[
				'label' => esc_html__( 'Text', 'chartio' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'placeholder' => esc_html__( 'Enter your title', 'chartio' ),
				'default' => esc_html__( 'Help us to donate $3800 to poor childrens', 'chartio' ),
				'condition' => [ 'layout_control' => ['1', '4', '5'], ]
			]
		);
		$this->add_control(
			'btn_title',
			[
				'label' => esc_html__( 'Button Title', 'chartio' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Enter your button title', 'chartio' ),
				'default' => esc_html__( 'Let’s Sponsor an Entire Project', 'chartio' ),
				'condition' => [ 'layout_control' => '5', ]
			]
		);
		$this->add_control(
            'title_link',
			[
				'label' => __( 'External Url', 'chartio' ),
				'type' => Controls_Manager::URL,
				'condition'  => [ 'layout_control' => '5', ],
				'label_block' => true, 
				'placeholder' => __( 'https://your-link.com', 'chartio' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);	
		$this->end_controls_section();
		
		//General Style
		$this->start_controls_section(
			'general_style',
			[
				'label' => esc_html__( 'General Setting', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
            'general_margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .chartio-icon-box' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'general_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .chartio-icon-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'general_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .chartio-icon-box',				
			]
		);
		
		$this->add_control(
			'general_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .chartio-icon-box' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'btn_border_type',
				'selector' => 
					'{{WRAPPER}} .chartio-icon-box',				
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'border_box_shadow',
				'selector' => 
					'{{WRAPPER}} .chartio-icon-box',				
				'separator' => 'before',
			]
		);
		$this->add_control(
			'btn_border_hover_color',
			[
				'label' => __('Border Color', 'chartio'),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .chartio-icon-box' => 'border-color: {{VALUE}}',
				],
				'separator' => 'before',
			]
		);
		$this->add_control(
			'btn_border_radius',
			[
				'label' => esc_html__('Border Radius', 'chartio'),
				'type' => Controls_Manager::DIMENSIONS,
				'separator' => 'before',
				'size_units' => ['px'],
				'selectors' => [
					'{{WRAPPER}} .chartio-icon-box' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'general_text_shadow',
				'selector' => '{{WRAPPER}} .chartio-icon-box',
			]
		);

		$this->end_controls_section();
		
		//Title Style
		
		$this->start_controls_section(
			'title_style',
			[
				'label' => esc_html__( 'Title', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [ 'layout_control' => ['1', '2', '3'], ]
			]
		);
		
		$this->add_responsive_control(
            'title__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .sec-title__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'title_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .sec-title__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'title_bgtype',
				'label' => __( 'Background', 'chartio' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .sec-title__title',				
			]
		);
		
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sec-title__title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => '{{WRAPPER}} .sec-title__title',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Stroke::get_type(),
			[
				'name' => 'title_text_stroke',
				'selector' => '{{WRAPPER}} .sec-title__title',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'title_text_shadow',
				'selector' => '{{WRAPPER}} .sec-title__title',
			]
		);

		$this->end_controls_section();
		
		//Text Style
		
		$this->start_controls_section(
			'text_style',
			[
				'label' => esc_html__( 'Text', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [ 'layout_control' => '1', ]
			]
		);
		
		$this->add_responsive_control(
            'text__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .sec-title__text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'text_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .sec-title__text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_control(
			'text_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sec-title__text' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => '{{WRAPPER}} .sec-title__text',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'text_text_shadow',
				'selector' => '{{WRAPPER}} .sec-title__text',
			]
		);

		$this->end_controls_section();
		
		/**Icon Box Style**/
		$this->start_controls_section(
			'icon_box_style',
			[
				'label' => esc_html__('Icon Setting', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->start_controls_tabs( 'chartio_service_icon_tab' );
		
			$this->start_controls_tab(
				'chartio_service_icon_normal',
				[
					'label' => __( 'Normal', 'chartio' ),
				]
			);
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'icon_box_bgtype',
						'label' => __( 'Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .chartio-service-icon,
							 {{WRAPPER}} .about-four__card__icon,
							 {{WRAPPER}} .service-card-two__icon',				
					]
				);
				$this->add_control(
					'service_icon_color',
					[
						'label' => __('Button Text Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .chartio-service-icon' => 'color: {{VALUE}}',
							'{{WRAPPER}} .about-four__card__icon' => 'color: {{VALUE}}',
							'{{WRAPPER}} .service-card-two__icon' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
				$this->add_control(
					'service_icon_bgcolor',
					[
						'label' => __('Button Text BG Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .chartio-service-icon:before' => 'background-color: {{VALUE}}',
							'{{WRAPPER}} .about-four__card__icon' => 'color: {{VALUE}}',
							'{{WRAPPER}} .service-card-two__icon' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
				$this->add_responsive_control(
					'icon_box_space',
					[
						'label'              => __( 'Space', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .chartio-service-icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .about-four__card__icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-card-two__icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_responsive_control(
					'icon_box_padding',
					[
						'label'              => __( 'Padding', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .chartio-service-icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .about-four__card__icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-card-two__icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_group_control(
					Group_Control_Border::get_type(),
					[
						'name' => 'service_icon_border_type',
						'selector' => 
							'{{WRAPPER}} .chartio-service-icon,
							 {{WRAPPER}} .about-four__card__icon,
							 {{WRAPPER}} .service-card-two__icon',				
						'separator' => 'before',
					]
				);
				$this->add_group_control(
					Group_Control_Box_Shadow::get_type(),
					[
						'name' => 'service_icon_box_shadow',
						'selector' => 
							'{{WRAPPER}} .chartio-service-icon,
							 {{WRAPPER}} .about-four__card__icon,
							 {{WRAPPER}} .service-card-two__icon',				
						'separator' => 'before',
					]
				);
				$this->add_control(
					'service_icon_border_radius',
					[
						'label' => esc_html__('Border Radius', 'chartio'),
						'type' => Controls_Manager::DIMENSIONS,
						'separator' => 'before',
						'size_units' => ['px'],
						'selectors' => [
							'{{WRAPPER}} .chartio-service-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .about-four__card__icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-card-two__icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);
			$this->end_controls_tab();
			
			$this->start_controls_tab(
				'chartio_services_icon_box_hover',
				[
					'label' => __( 'Hover', 'chartio' ),
				]
			);
			
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'service_icon_hover_bg_bgtype',
						'label' => __( 'Hover Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .chartio-service-icon:hover,
							 {{WRAPPER}} .about-four__card__icon:hover,
							 {{WRAPPER}} .service-card-two__icon:hover',				
					]
				);
				
				$this->add_control(
					'icon_hover_color',
					[
						'label' => __('Button Text Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .chartio-service-icon:hover' => 'color: {{VALUE}}',
							'{{WRAPPER}} .about-four__card__icon:hover' => 'color: {{VALUE}}',
							'{{WRAPPER}} .service-card-two__icon:hover' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
				
				$this->add_control(
					'service_icon_hover_transition',
					[
						'label' => esc_html__( 'Transition Duration', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'max' => 3,
								'step' => 0.1,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .chartio-service-icon' => 'transition-duration: {{SIZE}}s',
							'{{WRAPPER}} .about-four__card__icon' => 'transition-duration: {{SIZE}}s',
							'{{WRAPPER}} .service-card-two__icon' => 'transition-duration: {{SIZE}}s',
						],
					]
				);
		
				$this->add_control(
					'icon_hover_animation',
					[
						'label' => esc_html__( 'Hover Animation', 'chartio' ),
						'type' => Controls_Manager::HOVER_ANIMATION,
					]
				);
				
			$this->end_controls_tab();
			
		$this->end_controls_tabs();   
		$this->end_controls_section();
		
	}
	
	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		$icon = $settings[ 'icon' ];
		$layout = $settings[ 'layout_control' ];
		
	?>
    	
		<?php if( $layout == 5 ):?>
		
        <!-- Volunter Block One -->
        <div class="volunter-block_one chartio-icon-box">
            <div class="volunter-block_one-inner wow fadeInLeft" data-wow-delay="300ms" data-wow-duration="1500ms">
                <div class="volunter-block_one-image">                    
                    <?php if($settings['image']['id']) { ?>
                    <img src="<?php echo esc_url(wp_get_attachment_url($settings['image']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'chartio'); ?>" />
                    <?php } ?>
                    <div class="volunter-block_one-overlay">
                        <div class="volunter-block_one-overlay-inner">
                            <div class="volunter-block_one-icon chartio-service-icon">
                                <?php \Elementor\Icons_Manager::render_icon( $icon ); ?>
                            </div>
                            <?php
                            	$this->add_link_attributes( 'title_link', $settings['title_link']);
							 ?>
                            <h3><a <?php echo $this->get_render_attribute_string( 'title_link' ); ?> class="sec-title__title"><?php echo wp_kses($settings['title'], true) ;?></a></h3>
                            <div class="volunter-block_one-text sec-title__text"><?php echo wp_kses( $settings['text'], true ) ;?></div>
                            <a class="theme-btn join-btn" <?php echo $this->get_render_attribute_string( 'title_link' ); ?>><?php echo wp_kses( $settings['btn_title'], true ) ;?></a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
		
		<?php elseif( $layout == 4 ):?>
        
        <!-- Counter Two -->
        <div class="counter-two_column chartio-icon-box">
            <div class="counter-two_inner">
                <div class="counter-two_icon chartio-service-icon">
                    <?php \Elementor\Icons_Manager::render_icon( $icon ); ?>
                </div>
                <div class="counter-two_count sec-title__title"><span class="odometer" data-count="<?php echo esc_attr($settings['counter_stop2']);?>"></span><?php echo esc_attr($settings['alphabet_letter2']);?></div>
                <div class="counter-two_text sec-title__text"><?php echo wp_kses( $settings['text'], true ) ;?></div>
            </div>
        </div>
        
        <?php elseif( $layout == 3 ):?>
        
        <!-- Inspiration Block One -->
        <div class="inspire-block_one chartio-icon-box">
            <div class="inspire-block_one-inner">
                <div class="inspire-block_one-icon chartio-service-icon">
                	<?php \Elementor\Icons_Manager::render_icon( $icon ); ?>
                </div>
                <h5 class="inspire-block_one-title sec-title__title"><?php echo wp_kses($settings['title'], true) ;?></h5>
            </div>
        </div>
            
        <?php elseif( $layout == 2 ):?>
        
        <!-- Feature Block One -->
        <div class="feature-block_one chartio-icon-box">
            <div class="feature-block_one-inner wow fadeInLeft" data-wow-delay="0ms" data-wow-duration="1500ms">
                <div class="feature-block_one-icon chartio-service-icon">
                    <?php \Elementor\Icons_Manager::render_icon( $icon ); ?>
                </div>
                <h5 class="feature-block_one-heading sec-title__title"><?php echo wp_kses($settings['title'], true) ;?></h5>
            </div>
        </div>        
		
		<?php else:?>
        
        <div class="welcome-two_blocks-outer chartio-icon-box">            
            <div class="welcome-two_block">
                <div class="welcome-two_block-inner">
                    <div class="welcome-two_block-icon chartio-service-icon">
                        <?php \Elementor\Icons_Manager::render_icon( $icon ); ?>
                    </div>
                    <strong class="sec-title__title"><?php echo wp_kses($settings['title'], true) ;?></strong>
                    <div class="sec-title__text"><?php echo wp_kses( $settings['text'], true ) ;?></div>
                </div>
            </div>
        </div>
        
    	<?php endif;?>
    <?php
    }
}