<?php
namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Service_Card extends Widget_Base {
	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'chartio_service_card';
	}
	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Chartio Card Service', 'chartio' );
	}
	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-tools';
	}
	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'chartio' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'service_card',
			[
				'label' => esc_html__( 'Card Service', 'chartio' ),
			]
		);
		
		$this->add_control(
			'card_style',
			[
				'label'   => esc_html__( 'Layout Style', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'chartio'),
					'2' => esc_html__( 'Style Two ', 'chartio'),
				),
			]
		);		
					
		$this->add_control(
			'icon',
			[
				'label' => esc_html__('Enter The icons', 'chartio'),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-check',
					'library' => 'solid',
				],
			]
			
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Block Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Block Title', 'chartio' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Block Text', 'chartio' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Block Text', 'chartio' ),
			]
		);	
		$this->add_control(
			'btn_title',
			[
				'label'       => __( 'Button Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'chartio' ),
			]
		);
		$this->add_control(
			'btn_link',
			[
				'label' => __( 'Button Url', 'chartio' ),							
				'type' => Controls_Manager::URL,							
				'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),							
				'show_external' => true,							
				'default' => ['url' => '','is_external' => true,'nofollow' => true,],
			]
		);
		
		$this->add_control(
			'anim_affect',
			[
				'label'   => esc_html__( 'Animation Effect', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'fadeInRight',
				'options' => array(
					'fadeInLeft' => esc_html__( 'Fade In Left', 'chartio'),
					'fadeInRight' => esc_html__( 'Fade In Right', 'chartio'),
					'fadeInUp' => esc_html__( 'Fade In Up', 'chartio'),
					'fadeInDown' => esc_html__( 'Fade In Down', 'chartio'),
				),
			]
		);
		
		$this->add_control(
            'delay',
            [
                'label'   => esc_html__( 'Time Delay', 'chartio' ),
                'type'    => Controls_Manager::NUMBER,
				'default' => 0,
                'min'     => 0,
                'max'     => 10000,
                'step'    => 5,
            ]
        );
		
		$this->add_control(
            'duration',
            [
                'label'   => esc_html__( 'Time Duration', 'chartio' ),
                'type'    => Controls_Manager::NUMBER,
				'default' => 1500,
                'min'     => 0,
                'max'     => 10000,
                'step'    => 5,
            ]
        );
		
		$this->end_controls_section();
		
		/************************************************************************
								Tab Style Start
		*************************************************************************/
		
		/**Service Box Style**/
		$this->start_controls_section(
			'service_box_style',
			[
				'label' => esc_html__('Box Setting', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->start_controls_tabs( 'chartio_service_box_tab' );
		
			$this->start_controls_tab(
				'chartio_service_box_normal',
				[
					'label' => __( 'Normal', 'chartio' ),
				]
			);
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'service_box_bgtype',
						'label' => __( 'Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .chartio-service-card-box .service-block_one-inner::before',				
					]
				);
				$this->add_responsive_control(
					'service_box_space',
					[
						'label'              => __( 'Space', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .chartio-service-card-box .service-block_one-inner::before' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_responsive_control(
					'service_box_padding',
					[
						'label'              => __( 'Padding', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .chartio-service-card-box .service-block_one-inner::before' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_group_control(
					Group_Control_Border::get_type(),
					[
						'name' => 'service_box_border_type',
						'selector' => 
							'{{WRAPPER}} .chartio-service-card-box .service-block_one-inner::before',				
						'separator' => 'before',
					]
				);
				$this->add_group_control(
					Group_Control_Box_Shadow::get_type(),
					[
						'name' => 'service_box_shadow',
						'selector' => 
							'{{WRAPPER}} .chartio-service-card-box .service-block_one-inner::before',				
						'separator' => 'before',
					]
				);
				$this->add_control(
					'service_border_radius',
					[
						'label' => esc_html__('Border Radius', 'chartio'),
						'type' => Controls_Manager::DIMENSIONS,
						'separator' => 'before',
						'size_units' => ['px'],
						'selectors' => [
							'{{WRAPPER}} .chartio-service-card-box .service-block_one-inner::before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);
			$this->end_controls_tab();
			
			$this->start_controls_tab(
				'chartio_services_box_hover',
				[
					'label' => __( 'Hover', 'chartio' ),
				]
			);
			
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'service_hover_bg_bgtype',
						'label' => __( 'Hover Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .chartio-service-card-box .service-block_one-inner::before:hover',				
					]
				);
				
				$this->add_control(
					'service_background_hover_transition',
					[
						'label' => esc_html__( 'Transition Duration', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'max' => 3,
								'step' => 0.1,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .chartio-service-card-box .service-block_one-inner::before' => 'transition-duration: {{SIZE}}s',
						],
					]
				);
		
				$this->add_control(
					'hover_animation',
					[
						'label' => esc_html__( 'Hover Animation', 'chartio' ),
						'type' => Controls_Manager::HOVER_ANIMATION,
					]
				);
				
			$this->end_controls_tab();
			
		$this->end_controls_tabs();   
		$this->end_controls_section();
		
		/**Icon Box Style**/
		$this->start_controls_section(
			'icon_box_style',
			[
				'label' => esc_html__('Icon Setting', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->start_controls_tabs( 'chartio_service_icon_tab' );
		
			$this->start_controls_tab(
				'chartio_service_icon_normal',
				[
					'label' => __( 'Normal', 'chartio' ),
				]
			);
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'icon_box_bgtype',
						'label' => __( 'Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .chartio-service-icon,
							 {{WRAPPER}} .about-four__card__icon,
							 {{WRAPPER}} .service-card-two__icon',				
					]
				);
				$this->add_control(
					'service_icon_color',
					[
						'label' => __('Button Text Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .chartio-service-icon' => 'color: {{VALUE}}',
							'{{WRAPPER}} .about-four__card__icon' => 'color: {{VALUE}}',
							'{{WRAPPER}} .service-card-two__icon' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
				$this->add_responsive_control(
					'icon_box_space',
					[
						'label'              => __( 'Space', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .chartio-service-icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .about-four__card__icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-card-two__icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_responsive_control(
					'icon_box_padding',
					[
						'label'              => __( 'Padding', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .chartio-service-icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .about-four__card__icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-card-two__icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_group_control(
					Group_Control_Border::get_type(),
					[
						'name' => 'service_icon_border_type',
						'selector' => 
							'{{WRAPPER}} .chartio-service-icon,
							 {{WRAPPER}} .about-four__card__icon,
							 {{WRAPPER}} .service-card-two__icon',				
						'separator' => 'before',
					]
				);
				$this->add_group_control(
					Group_Control_Box_Shadow::get_type(),
					[
						'name' => 'service_icon_box_shadow',
						'selector' => 
							'{{WRAPPER}} .chartio-service-icon,
							 {{WRAPPER}} .about-four__card__icon,
							 {{WRAPPER}} .service-card-two__icon',				
						'separator' => 'before',
					]
				);
				$this->add_control(
					'service_icon_border_radius',
					[
						'label' => esc_html__('Border Radius', 'chartio'),
						'type' => Controls_Manager::DIMENSIONS,
						'separator' => 'before',
						'size_units' => ['px'],
						'selectors' => [
							'{{WRAPPER}} .chartio-service-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .about-four__card__icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-card-two__icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);
			$this->end_controls_tab();
			
			$this->start_controls_tab(
				'chartio_services_icon_box_hover',
				[
					'label' => __( 'Hover', 'chartio' ),
				]
			);
			
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'service_icon_hover_bg_bgtype',
						'label' => __( 'Hover Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .chartio-service-icon:hover,
							 {{WRAPPER}} .about-four__card__icon:hover,
							 {{WRAPPER}} .service-card-two__icon:hover',				
					]
				);
				
				$this->add_control(
					'icon_hover_color',
					[
						'label' => __('Button Text Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .chartio-service-icon:hover' => 'color: {{VALUE}}',
							'{{WRAPPER}} .about-four__card__icon:hover' => 'color: {{VALUE}}',
							'{{WRAPPER}} .service-card-two__icon:hover' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
				
				$this->add_control(
					'service_icon_hover_transition',
					[
						'label' => esc_html__( 'Transition Duration', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'max' => 3,
								'step' => 0.1,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .chartio-service-icon' => 'transition-duration: {{SIZE}}s',
							'{{WRAPPER}} .about-four__card__icon' => 'transition-duration: {{SIZE}}s',
							'{{WRAPPER}} .service-card-two__icon' => 'transition-duration: {{SIZE}}s',
						],
					]
				);
		
				$this->add_control(
					'icon_hover_animation',
					[
						'label' => esc_html__( 'Hover Animation', 'chartio' ),
						'type' => Controls_Manager::HOVER_ANIMATION,
					]
				);
				
			$this->end_controls_tab();
			
		$this->end_controls_tabs();   
		$this->end_controls_section();
		
		//Title Style
		$this->start_controls_section(
			'title_style',
			[
				'label' => esc_html__( 'Title Setting', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
            'title__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .chartio-service-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .chartio-service-title a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .service-card-two__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'title_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .chartio-service-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .chartio-service-title a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .service-card-two__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .chartio-service-title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .chartio-service-title a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .service-card-two__title' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'title_hover_color',
			[
				'label' => esc_html__( 'Title Hover Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .chartio-service-title a:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => 
					'{{WRAPPER}} .chartio-service-title,
					 {{WRAPPER}} .chartio-service-title a,
					 {{WRAPPER}} .service-card-two__title',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'title_text_shadow',
				'selector' => 
					'{{WRAPPER}} .chartio-service-title,
					 {{WRAPPER}} .chartio-service-title a,
					 {{WRAPPER}} .service-card-two__title',
			]
		);

		$this->end_controls_section();
		
		//Text Style
		
		$this->start_controls_section(
			'text_style',
			[
				'label' => esc_html__( 'Text', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
            'text__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .chartio-service-text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .about-four__card__text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .service-card-two__text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'text_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .chartio-service-text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .about-four__card__text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .service-card-two__text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_control(
			'text_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .chartio-service-text' => 'color: {{VALUE}};',
					'{{WRAPPER}} .about-four__card__text' => 'color: {{VALUE}};',
					'{{WRAPPER}} .service-card-two__text' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => 
				'{{WRAPPER}} .chartio-service-text,
				 {{WRAPPER}} .about-four__card__text,
				 {{WRAPPER}} .service-card-two__text',
			]
		);

		$this->end_controls_section();
		
		/**Button Style**/
		$this->start_controls_section(
			'button_style',
			[
				'label' => esc_html__('Button Style Setting', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->start_controls_tabs( 'chartio_tabs_btn' );
		
			$this->start_controls_tab(
				'chartio_tab_btn_normal',
				[
					'label' => __( 'Normal', 'chartio' ),
				]
			);
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'btn_bgtype',
						'label' => __( 'Button Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .chartio-service-btn-title',				
					]
				);
				$this->add_responsive_control(
					'btn_width_size',
					[
						'label' => __( 'Width', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'size_units' => [ 'px', 'em', '%', 'custom' ],
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 500,
							],
							'%' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .chartio-service-btn-title' => 'width: {{SIZE}}{{UNIT}};',
						],
					]
				);
				$this->add_responsive_control(
					'btn_height_size',
					[
						'label' => __( 'Height', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'size_units' => [ 'px', 'em', '%', 'custom' ],
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 500,
							],
							'%' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .chartio-service-btn-title' => 'height: {{SIZE}}{{UNIT}};',
						],
					]
				);
				$this->add_responsive_control(
					'btn_padding',
					[
						'label'              => __( 'Padding', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .chartio-service-btn-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_group_control(
					Group_Control_Border::get_type(),
					[
						'name' => 'btn_border_type',
						'selector' => 
							'{{WRAPPER}} .chartio-service-btn-title',				
						'separator' => 'before',
					]
				);
				$this->add_group_control(
					Group_Control_Box_Shadow::get_type(),
					[
						'name' => 'border_box_shadow',
						'selector' => 
							'{{WRAPPER}} .chartio-service-btn-title',				
						'separator' => 'before',
					]
				);
				$this->add_control(
					'btn_border_radius',
					[
						'label' => esc_html__('Border Radius', 'chartio'),
						'type' => Controls_Manager::DIMENSIONS,
						'separator' => 'before',
						'size_units' => ['px'],
						'selectors' => [
							'{{WRAPPER}} .chartio-service-btn-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);
				$this->add_group_control(
					Group_Control_Typography::get_type(),
					[
						'name' => 'btn_title_typography',
						'label' => __('Button Text Typography', 'chartio'),
						'selector' => 
							'{{WRAPPER}} .chartio-service-btn-title',				
						'separator' => 'before',
					]
				);
				$this->add_control(
					'btn_title_color',
					[
						'label' => __('Button Text Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .chartio-service-btn-title' => 'color: {{VALUE}}',
							'{{WRAPPER}} .chartio-service-btn-title .text-one' => 'color: {{VALUE}}',
							'{{WRAPPER}} .chartio-service-btn-title .text-two' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
			$this->end_controls_tab();
			
			$this->start_controls_tab(
				'chartio_tab_btn_hover',
				[
					'label' => __( 'Hover', 'chartio' ),
				]
			);
			
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'btn_hover_bg_bgtype',
						'label' => __( 'Button Hover Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .chartio-service-btn-title:before:hover,
							 {{WRAPPER}} .chartio-service-btn-title:hover',				
					]
				);
				$this->add_control(
					'btn_border_hover_color',
					[
						'label' => __('Button Border Hover Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .chartio-service-btn-title:hover' => 'border-color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
				$this->add_control(
					'btn_title_hover_color',
					[
						'label' => __('Button Text Hover Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .chartio-service-btn-title:hover' => 'color: {{VALUE}}',
							'{{WRAPPER}} .chartio-service-btn-title:hover .text-one' => 'color: {{VALUE}}',
							'{{WRAPPER}} .chartio-service-btn-title:hover .text-two' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
			
			$this->end_controls_tab();
			
		$this->end_controls_tabs();   
		$this->end_controls_section();
	}
	
	/**
	* Render button widget output on the frontend.
	* Written in PHP and used to generate the final HTML.
	*
	* @since  1.0.0
	* @access protected
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');	
	?>
    
    <?php if($settings['card_style'] == '2') :
		$animation = $settings[ 'anim_affect' ];
		$delay = $settings[ 'delay' ];
		$duration = $settings[ 'duration' ];
	?>
    
    <!-- Service Block One / Style Two -->
    <div class="service-block_one style-two chartio-service-card-box">
        <div class="service-block_one-inner wow <?php echo esc_attr( $animation );?>" data-wow-delay="<?php echo esc_attr( $delay );?>ms" data-wow-duration="<?php echo esc_attr( $duration );?>ms">
            <div class="service-block_one-icon chartio-service-icon">
                <?php \Elementor\Icons_Manager::render_icon( $settings[ 'icon' ] ); ?>
            </div>
            <h3 class="service-block_one-heading chartio-service-title"><a href="<?php echo esc_url($settings['btn_link']['url']);?>"><?php echo wp_kses($settings['title'], true) ;?></a></h3>
            <div class="service-block_one-text chartio-service-text"><?php echo wp_kses($settings['text'], true) ;?></div>
            <div class="service-block_one-button">
                <a href="<?php echo esc_url($settings['btn_link']['url']);?>" class="theme-btn btn-style-two chartio-service-btn-title">
                    <span class="btn-wrap">
                        <span class="text-one"><?php echo wp_kses($settings['btn_title'], true);?></span>
                        <span class="text-two"><?php echo wp_kses($settings['btn_title'], true);?></span>
                    </span>
                </a>
            </div>
        </div>
    </div>
    
    <?php else: 
		$animation = $settings[ 'anim_affect' ];
		$delay = $settings[ 'delay' ];
		$duration = $settings[ 'duration' ];
	?>	
        
    <!-- Service Block One -->
    <div class="service-block_one chartio-service-card-box">
        <div class="service-block_one-inner wow <?php echo esc_attr( $animation );?>" data-wow-delay="<?php echo esc_attr( $delay );?>ms" data-wow-duration="<?php echo esc_attr( $duration );?>ms">
            <div class="service-block_one-icon chartio-service-icon">
                <?php \Elementor\Icons_Manager::render_icon( $settings[ 'icon' ] ); ?>
            </div>
            <h3 class="service-block_one-heading chartio-service-title"><a href="<?php echo esc_url($settings['btn_link']['url']);?>"><?php echo wp_kses($settings['title'], true) ;?></a></h3>
            <div class="service-block_one-text chartio-service-text"><?php echo wp_kses($settings['text'], true) ;?></div>
            <div class="service-block_one-button">
                <a href="<?php echo esc_url($settings['btn_link']['url']);?>" class="theme-btn btn-style-two chartio-service-btn-title">
                    <span class="btn-wrap">
                        <span class="text-one"><?php echo wp_kses($settings['btn_title'], true);?></span>
                        <span class="text-two"><?php echo wp_kses($settings['btn_title'], true);?></span>
                    </span>
                </a>
            </div>
        </div>
    </div>
                
     <?php endif;
	}
}