<?php

namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Services_Grid extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'chartio_services_grid';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Chartio Services Grid', 'chartio' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-tools';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'chartio' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'services_grid',
			[
				'label' => esc_html__( 'Services Grid', 'chartio' ),
			]
		);
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'chartio'),
					'2' => esc_html__( 'Style Two ', 'chartio'),
				),
			]
		);
		$this->add_control(
			'col_grid',
			[
				'label'   => esc_html__( 'Choose Column', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'default',
				'options' => array(
					'default'  => esc_html__( 'Default', 'chartio' ),
					'one' => esc_html__( 'One Column Grid ', 'chartio'),
					'two'  => esc_html__( 'Two Column Grid', 'chartio' ),
					'three'  => esc_html__( 'Three Column Grid', 'chartio' ),
					'four'  => esc_html__( 'Four Column Grid', 'chartio' ),
					'five'  => esc_html__( 'Six Column Grid', 'chartio' ),
				),
			]
		);
		$this->add_control(
            'text_limit',
            [
                'label'   => esc_html__( 'Text Limit', 'chartio' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 10,
                'min'     => 1,
                'max'     => 100,
                'step'    => 1,
            ]
        );
        $this->add_control(
            'query_number',
            [
                'label'   => esc_html__( 'Number of post', 'chartio' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 6,
                'min'     => 1,
                'max'     => 100,
                'step'    => 1,
            ]
        );
        $this->add_control(
            'query_orderby',
            [
                'label'   => esc_html__( 'Order By', 'chartio' ),
				'label_block' => true,
                'type'    => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => array(
                    'date'       => esc_html__( 'Date', 'chartio' ),
                    'title'      => esc_html__( 'Title', 'chartio' ),
                    'menu_order' => esc_html__( 'Menu Order', 'chartio' ),
                    'rand'       => esc_html__( 'Random', 'chartio' ),
                ),
            ]
        );
        $this->add_control(
            'query_order',
            [
                'label'   => esc_html__( 'Order', 'chartio' ),
				'label_block' => true,
                'type'    => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => array(
                    'DESC' => esc_html__( 'DESC', 'chartio' ),
                    'ASC'  => esc_html__( 'ASC', 'chartio' ),
                ),
            ]
        );
        $this->add_control(
            'query_category',
            [
                'type' => Controls_Manager::SELECT,
                'label' => esc_html__('Category', 'chartio'),
				'label_block' => true,
                'options' => get_service_categories(),
            ]
        );
		$this->add_control(
			'button_label',
			[
				'label'       => __( 'Button Label', 'chartio' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'default'  => __('Read More', 'chartio'),
				'placeholder' => __( 'Enter your title', 'chartio' ),
				
			]
		);
		$this->end_controls_section();
		
		/************************************************************************
								Tab Style Start
		*************************************************************************/
		
		/**Service Box Style**/
		$this->start_controls_section(
			'service_box_style',
			[
				'label' => esc_html__('Box Setting', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->start_controls_tabs( 'chartio_service_box_tab' );
		
			$this->start_controls_tab(
				'chartio_service_box_normal',
				[
					'label' => __( 'Normal', 'chartio' ),
				]
			);
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'service_box_bgtype',
						'label' => __( 'Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .service-card-four,
							 {{WRAPPER}} .about-four__card,
							 {{WRAPPER}} .service-card-two',				
					]
				);
				$this->add_responsive_control(
					'service_box_space',
					[
						'label'              => __( 'Space', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .service-card-four' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .about-four__card' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-card-two' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-four__list__item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_responsive_control(
					'service_box_padding',
					[
						'label'              => __( 'Padding', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .service-card-four' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .about-four__card' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-card-two' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-four__list__item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_group_control(
					Group_Control_Border::get_type(),
					[
						'name' => 'service_box_border_type',
						'selector' => 
							'{{WRAPPER}} .service-card-four,
							 {{WRAPPER}} .about-four__card,
							 {{WRAPPER}} .service-card-two,
							 {{WRAPPER}} .service-four__list__item',				
						'separator' => 'before',
					]
				);
				$this->add_group_control(
					Group_Control_Box_Shadow::get_type(),
					[
						'name' => 'service_box_shadow',
						'selector' => 
							'{{WRAPPER}} .service-card-four,
							 {{WRAPPER}} .about-four__card,
							 {{WRAPPER}} .service-card-two,
							 {{WRAPPER}} .service-four__list__item',				
						'separator' => 'before',
					]
				);
				$this->add_control(
					'service_border_radius',
					[
						'label' => esc_html__('Border Radius', 'chartio'),
						'type' => Controls_Manager::DIMENSIONS,
						'separator' => 'before',
						'size_units' => ['px'],
						'selectors' => [
							'{{WRAPPER}} .service-card-four' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .about-four__card' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-card-two' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-four__list__item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
						],
					]
				);
			$this->end_controls_tab();
			
			$this->start_controls_tab(
				'chartio_services_box_hover',
				[
					'label' => __( 'Hover', 'chartio' ),
				]
			);
			
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'service_hover_bg_bgtype',
						'label' => __( 'Hover Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .service-card-four:hover,
							 {{WRAPPER}} .about-four__card:hover,
							 {{WRAPPER}} .service-card-two:hover,
							 {{WRAPPER}} .service-four__list__item:hover',				
					]
				);
				
				$this->add_control(
					'service_background_hover_transition',
					[
						'label' => esc_html__( 'Transition Duration', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'max' => 3,
								'step' => 0.1,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .service-card-four' => 'transition-duration: {{SIZE}}s',
							'{{WRAPPER}} .about-four__card' => 'transition-duration: {{SIZE}}s',
							'{{WRAPPER}} .service-card-two' => 'transition-duration: {{SIZE}}s',
							'{{WRAPPER}} .service-four__list__item' => 'transition-duration: {{SIZE}}s',
						],
					]
				);
		
				$this->add_control(
					'hover_animation',
					[
						'label' => esc_html__( 'Hover Animation', 'chartio' ),
						'type' => Controls_Manager::HOVER_ANIMATION,
					]
				);
				
			$this->end_controls_tab();
			
		$this->end_controls_tabs();   
		$this->end_controls_section();
		
		/**Icon Box Style**/
		$this->start_controls_section(
			'icon_box_style',
			[
				'label' => esc_html__('Icon Setting', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->start_controls_tabs( 'chartio_service_icon_tab' );
		
			$this->start_controls_tab(
				'chartio_service_icon_normal',
				[
					'label' => __( 'Normal', 'chartio' ),
				]
			);
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'icon_box_bgtype',
						'label' => __( 'Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .service-card-four__icon,
							 {{WRAPPER}} .about-four__card__icon,
							 {{WRAPPER}} .service-card-two__icon,
							 {{WRAPPER}} .service-card-three__icon',				
					]
				);
				$this->add_control(
					'service_icon_color',
					[
						'label' => __('Button Text Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .service-card-four__icon' => 'color: {{VALUE}}',
							'{{WRAPPER}} .about-four__card__icon' => 'color: {{VALUE}}',
							'{{WRAPPER}} .service-card-two__icon' => 'color: {{VALUE}}',
							'{{WRAPPER}} .service-card-three__icon' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
				$this->add_responsive_control(
					'icon_box_space',
					[
						'label'              => __( 'Space', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .service-card-four__icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .about-four__card__icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-card-two__icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-card-three__icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_responsive_control(
					'icon_box_padding',
					[
						'label'              => __( 'Padding', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .service-card-four__icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .about-four__card__icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-card-two__icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-card-three__icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_group_control(
					Group_Control_Border::get_type(),
					[
						'name' => 'service_icon_border_type',
						'selector' => 
							'{{WRAPPER}} .service-card-four__icon,
							 {{WRAPPER}} .about-four__card__icon,
							 {{WRAPPER}} .service-card-two__icon,
							 {{WRAPPER}} .service-card-three__icon',				
						'separator' => 'before',
					]
				);
				$this->add_group_control(
					Group_Control_Box_Shadow::get_type(),
					[
						'name' => 'service_icon_box_shadow',
						'selector' => 
							'{{WRAPPER}} .service-card-four__icon,
							 {{WRAPPER}} .about-four__card__icon,
							 {{WRAPPER}} .service-card-two__icon,
							 {{WRAPPER}} .service-card-three__icon',				
						'separator' => 'before',
					]
				);
				$this->add_control(
					'service_icon_border_radius',
					[
						'label' => esc_html__('Border Radius', 'chartio'),
						'type' => Controls_Manager::DIMENSIONS,
						'separator' => 'before',
						'size_units' => ['px'],
						'selectors' => [
							'{{WRAPPER}} .service-card-four__icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .about-four__card__icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-card-two__icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-card-three__icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);
			$this->end_controls_tab();
			
			$this->start_controls_tab(
				'chartio_services_icon_box_hover',
				[
					'label' => __( 'Hover', 'chartio' ),
				]
			);
			
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'service_icon_hover_bg_bgtype',
						'label' => __( 'Hover Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .service-card-four__icon:hover,
							 {{WRAPPER}} .about-four__card__icon:hover,
							 {{WRAPPER}} .service-card-two__icon:hover,
							 {{WRAPPER}} .service-card-three__icon:hover',				
					]
				);
				
				$this->add_control(
					'icon_hover_color',
					[
						'label' => __('Button Text Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .service-card-four__icon:hover' => 'color: {{VALUE}}',
							'{{WRAPPER}} .about-four__card__icon:hover' => 'color: {{VALUE}}',
							'{{WRAPPER}} .service-card-two__icon:hover' => 'color: {{VALUE}}',
							'{{WRAPPER}} .service-card-three__icon:hover' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
				
				$this->add_control(
					'service_icon_hover_transition',
					[
						'label' => esc_html__( 'Transition Duration', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'max' => 3,
								'step' => 0.1,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .service-card-four__icon' => 'transition-duration: {{SIZE}}s',
							'{{WRAPPER}} .about-four__card__icon' => 'transition-duration: {{SIZE}}s',
							'{{WRAPPER}} .service-card-two__icon' => 'transition-duration: {{SIZE}}s',
							'{{WRAPPER}} .service-card-three__icon' => 'transition-duration: {{SIZE}}s',
						],
					]
				);
		
				$this->add_control(
					'icon_hover_animation',
					[
						'label' => esc_html__( 'Hover Animation', 'chartio' ),
						'type' => Controls_Manager::HOVER_ANIMATION,
					]
				);
				
			$this->end_controls_tab();
			
		$this->end_controls_tabs();   
		$this->end_controls_section();
		
		//Circle Style
		$this->start_controls_section(
			'service_circle_style',
			[
				'label' => esc_html__( 'Pattern Style Setting', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->start_controls_tabs( 'chartio_circle_tabs' );
			$this->start_controls_tab(
				'chartio_tab_circle_normal',
				[
					'label' => __( 'Normal', 'chartio' ),
				]
			);
				$this->add_control(
					'circle_position',
					[
						'label' => esc_html__( 'Position', 'chartio' ),
						'type' => Controls_Manager::SELECT,
						'default' => '',
						'options' => [
							'' => esc_html__( 'Default', 'chartio' ),
							'absolute' => esc_html__( 'Absolute', 'chartio' ),
							'fixed' => esc_html__( 'Fixed', 'chartio' ),
						],
						'selectors' => [
							'{{WRAPPER}} .service-card-four__circle' => 'position: {{VALUE}};',
						],
						'separator' => 'before',
					]
				);
		
				$this->add_control(
					'circle_offset_orientation_h',
					[
						'label' => esc_html__( 'Horizontal Orientation', 'chartio' ),
						'type' => Controls_Manager::CHOOSE,
						'toggle' => false,
						'default' => 'start',
						'options' => [
							'start' => [
								'title' => 'left',
								'icon' => 'eicon-h-align-left',
							],
							'end' => [
								'title' => 'right',
								'icon' => 'eicon-h-align-right',
							],
						],
						'classes' => 'chartio-control-start-end',
						'render_type' => 'ui',
						'condition' => [
							'circle_position!' => '',
						],
					]
				);
				
				$this->add_responsive_control(
					'circle_offset_x',
					[
						'label' => esc_html__( 'Offset', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'min' => -1000,
								'max' => 1000,
								'step' => 1,
							],
							'%' => [
								'min' => -200,
								'max' => 200,
							],
							'vw' => [
								'min' => -200,
								'max' => 200,
							],
							'vh' => [
								'min' => -200,
								'max' => 200,
							],
						],
						'default' => [
							'size' => '0',
						],
						'size_units' => [ 'px', '%', 'vw', 'vh', 'custom' ],
						'selectors' => [
							'{{WRAPPER}} .service-card-four__circle' => 'left: {{SIZE}}{{UNIT}}',
						],
						'condition' => [
							'circle_offset_orientation_h!' => 'end',
							'circle_position!' => '',
						],
					]
				);
				
				$this->add_responsive_control(
					'circle_offset_x_end',
					[
						'label' => esc_html__( 'Offset', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'min' => -1000,
								'max' => 1000,
								'step' => 0.1,
							],
							'%' => [
								'min' => -200,
								'max' => 200,
							],
							'vw' => [
								'min' => -200,
								'max' => 200,
							],
							'vh' => [
								'min' => -200,
								'max' => 200,
							],
						],
						'default' => [
							'size' => '0',
						],
						'size_units' => [ 'px', '%', 'vw', 'vh', 'custom' ],
						'selectors' => [
							'{{WRAPPER}} .service-card-four__circle' => 'right: {{SIZE}}{{UNIT}}',
						],
						'condition' => [
							'circle_offset_orientation_h' => 'end',
							'circle_position!' => '',
						],
					]
				);
				
				$this->add_control(
					'circle_offset_orientation_v',
					[
						'label' => esc_html__( 'Vertical Orientation', 'chartio' ),
						'type' => Controls_Manager::CHOOSE,
						'toggle' => false,
						'default' => 'start',
						'options' => [
							'start' => [
								'title' => esc_html__( 'Top', 'chartio' ),
								'icon' => 'eicon-v-align-top',
							],
							'end' => [
								'title' => esc_html__( 'Bottom', 'chartio' ),
								'icon' => 'eicon-v-align-bottom',
							],
						],
						'render_type' => 'ui',
						'condition' => [
							'circle_position!' => '',
						],
					]
				);
		
				$this->add_responsive_control(
					'circle_offset_y',
					[
						'label' => esc_html__( 'Offset', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'min' => -1000,
								'max' => 1000,
								'step' => 1,
							],
							'%' => [
								'min' => -200,
								'max' => 200,
							],
							'vh' => [
								'min' => -200,
								'max' => 200,
							],
							'vw' => [
								'min' => -200,
								'max' => 200,
							],
						],
						'size_units' => [ 'px', '%', 'vh', 'vw', 'custom' ],
						'default' => [
							'size' => '0',
						],
						'selectors' => [
							'{{WRAPPER}} .service-card-four__circle' => 'top: {{SIZE}}{{UNIT}}',
						],
						'condition' => [
							'circle_offset_orientation_v!' => 'end',
							'circle_position!' => '',
						],
					]
				);
		
				$this->add_responsive_control(
					'circle_offset_y_end',
					[
						'label' => esc_html__( 'Offset', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'min' => -1000,
								'max' => 1000,
								'step' => 1,
							],
							'%' => [
								'min' => -200,
								'max' => 200,
							],
							'vh' => [
								'min' => -200,
								'max' => 200,
							],
							'vw' => [
								'min' => -200,
								'max' => 200,
							],
						],
						'size_units' => [ 'px', '%', 'vh', 'vw', 'custom' ],
						'default' => [
							'size' => '0',
						],
						'selectors' => [
							'{{WRAPPER}} .service-card-four__circle' => 'bottom: {{SIZE}}{{UNIT}}',
						],
						'condition' => [
							'circle_offset_orientation_v' => 'end',
							'circle_position!' => '',
						],
					]
				);
				
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'circle_bgtype',
						'label' => __( 'Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .service-card-four__circle',				
					]
				);
				
				$this->add_responsive_control(
					'circle_width',
					[
						'label' => esc_html__( 'Width', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'default' => [
							'unit' => '%',
						],
						'tablet_default' => [
							'unit' => '%',
						],
						'mobile_default' => [
							'unit' => '%',
						],
						'size_units' => [ '%', 'px', 'vw' ],
						'range' => [
							'%' => [
								'min' => 1,
								'max' => 100,
							],
							'px' => [
								'min' => 1,
								'max' => 1000,
							],
							'vw' => [
								'min' => 1,
								'max' => 100,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .service-card-four__circle' => 'width: {{SIZE}}{{UNIT}};',
						],
					]
				);
		
				$this->add_responsive_control(
					'circle_height',
					[
						'label' => esc_html__( 'Height', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'default' => [
							'unit' => 'px',
						],
						'tablet_default' => [
							'unit' => 'px',
						],
						'mobile_default' => [
							'unit' => 'px',
						],
						'size_units' => [ 'px', 'vh' ],
						'range' => [
							'px' => [
								'min' => 1,
								'max' => 500,
							],
							'vh' => [
								'min' => 1,
								'max' => 100,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .service-card-four__circle' => 'height: {{SIZE}}{{UNIT}};',
						],
					]
				);
				
				$this->add_group_control(
					Group_Control_Border::get_type(),
					[
						'name' => 'circle_border',
						'selector' => '{{WRAPPER}} .service-card-four__circle',
						'separator' => 'before',
					]
				);
		
				$this->add_responsive_control(
					'circle_border_radius',
					[
						'label' => esc_html__( 'Border Radius', 'chartio' ),
						'type' => Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', '%', 'em' ],
						'selectors' => [
							'{{WRAPPER}} .service-card-four__circle' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);
		
				$this->add_group_control(
					Group_Control_Box_Shadow::get_type(),
					[
						'name' => 'circle_box_shadow',
						'exclude' => [
							'box_shadow_position',
						],
						'selector' => '{{WRAPPER}} .service-card-four__circle',
					]
				);
				
				$this->add_control(
					'circle_opacity',
					[
						'label' => esc_html__( 'Opacity', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'max' => 1,
								'min' => 0.10,
								'step' => 0.01,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .service-card-four__circle' => 'opacity: {{SIZE}};',
						],
					]
				);
				
			$this->end_controls_tab();
			
			$this->start_controls_tab(
				'chartio_tab_circle_hover',
				[
					'label' => __( 'Hover', 'chartio' ),
				]
			);
			
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'circle_hover_bgtype',
						'label' => __( 'Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .service-card-four:hover .service-card-four__circle',				
					]
				);
				
				$this->add_control(
					'opacity',
					[
						'label' => esc_html__( 'Opacity', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'max' => 1,
								'min' => 0.10,
								'step' => 0.01,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .service-card-four:hover .service-card-four__circle' => 'opacity: {{SIZE}};',
						],
					]
				);
				
				$this->add_control(
					'background_hover_transition',
					[
						'label' => esc_html__( 'Transition Duration', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'max' => 3,
								'step' => 0.1,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .service-card-four:hover .service-card-four__circle' => 'transition-duration: {{SIZE}}s',
						],
					]
				);
			
			$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_responsive_control(
			'_z_index',
			[
				'label' => esc_html__( 'Z-Index', 'chartio' ),
				'type' => Controls_Manager::NUMBER,
				'selectors' => [
					'{{WRAPPER}} .about-one__video' => 'z-index: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();
		
		//Title Style
		$this->start_controls_section(
			'title_style',
			[
				'label' => esc_html__( 'Title Setting', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
            'title__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .service-card-four__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .about-four__card__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'title_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .service-card-four__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .about-four__card__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .service-card-four__title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .service-card-four__title a' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => 
					'{{WRAPPER}} .service-card-four__title,
					 {{WRAPPER}} .about-four__card__title,
					 {{WRAPPER}} .service-card-two__title,
					 {{WRAPPER}} .service-card-three__title',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Stroke::get_type(),
			[
				'name' => 'title_text_stroke',
				'selector' => 
					'{{WRAPPER}} .service-card-four__title,
					 {{WRAPPER}} .about-four__card__title,
					 {{WRAPPER}} .service-card-two__title,
					 {{WRAPPER}} .service-card-three__title',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'title_text_shadow',
				'selector' => 
					'{{WRAPPER}} .service-card-four__title,
					 {{WRAPPER}} .about-four__card__title,
					 {{WRAPPER}} .service-card-two__title,
					 {{WRAPPER}} .service-card-three__title',
			]
		);

		$this->end_controls_section();
		
		//Text Style
		
		$this->start_controls_section(
			'text_style',
			[
				'label' => esc_html__( 'Text', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
            'text__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .service-card-four__text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .about-four__card__text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .service-card-two__text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .service-card-three__text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'text_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .service-card-four__text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .about-four__card__text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .service-card-two__text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .service-card-three__text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_control(
			'text_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .service-card-four__text' => 'color: {{VALUE}};',
					'{{WRAPPER}} .about-four__card__text' => 'color: {{VALUE}};',
					'{{WRAPPER}} .service-card-two__text' => 'color: {{VALUE}};',
					'{{WRAPPER}} .service-card-three__text' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => 
				'{{WRAPPER}} .service-card-four__text,
				 {{WRAPPER}} .about-four__card__text,
				 {{WRAPPER}} .service-card-two__text,
				 {{WRAPPER}} .service-card-three__text',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'text_text_shadow',
				'selector' => 
					'{{WRAPPER}} .service-card-four__text,
					 {{WRAPPER}} .about-four__card__text,
					 {{WRAPPER}} .service-card-two__text,
					 {{WRAPPER}} .service-card-three__text',
			]
		);

		$this->end_controls_section();
		
		/**Button Style**/
		$this->start_controls_section(
			'button_style',
			[
				'label' => esc_html__('Button Style Setting', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->start_controls_tabs( 'chartio_tabs_btn' );
		
			$this->start_controls_tab(
				'chartio_tab_btn_normal',
				[
					'label' => __( 'Normal', 'chartio' ),
				]
			);
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'btn_bgtype',
						'label' => __( 'Button Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .service-card-four__link,
							 {{WRAPPER}} .service-card-two__link',				
					]
				);
				$this->add_responsive_control(
					'btn_width_size',
					[
						'label' => __( 'Width', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'size_units' => [ 'px', 'em', '%', 'custom' ],
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 500,
							],
							'%' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .service-card-four__link' => 'width: {{SIZE}}{{UNIT}};',
							'{{WRAPPER}} .service-card-two__link' => 'width: {{SIZE}}{{UNIT}};'
						],
					]
				);
				$this->add_responsive_control(
					'btn_height_size',
					[
						'label' => __( 'Height', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'size_units' => [ 'px', 'em', '%', 'custom' ],
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 500,
							],
							'%' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .service-card-four__link' => 'height: {{SIZE}}{{UNIT}};',
							'{{WRAPPER}} .service-card-two__link' => 'height: {{SIZE}}{{UNIT}};',
						],
					]
				);
				$this->add_responsive_control(
					'btn_padding',
					[
						'label'              => __( 'Padding', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .service-card-four__link' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-card-two__link' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_group_control(
					Group_Control_Border::get_type(),
					[
						'name' => 'btn_border_type',
						'selector' => 
							'{{WRAPPER}} .service-card-four__link,
							 {{WRAPPER}} .service-card-two__link',				
						'separator' => 'before',
					]
				);
				$this->add_group_control(
					Group_Control_Box_Shadow::get_type(),
					[
						'name' => 'border_box_shadow',
						'selector' => 
							'{{WRAPPER}} .service-card-four__link,
							 {{WRAPPER}} .service-card-two__link',				
						'separator' => 'before',
					]
				);
				$this->add_control(
					'btn_border_radius',
					[
						'label' => esc_html__('Border Radius', 'chartio'),
						'type' => Controls_Manager::DIMENSIONS,
						'separator' => 'before',
						'size_units' => ['px'],
						'selectors' => [
							'{{WRAPPER}} .service-card-four__link' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .service-card-two__link' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);
				$this->add_group_control(
					Group_Control_Typography::get_type(),
					[
						'name' => 'btn_title_typography',
						'label' => __('Button Text Typography', 'chartio'),
						'selector' => 
							'{{WRAPPER}} .service-card-four__link,
							 {{WRAPPER}} .service-card-two__link,
							 {{WRAPPER}} .service-card-four__link .text-one,
							 {{WRAPPER}} .service-card-four__link .text-two',				
						'separator' => 'before',
					]
				);
				$this->add_control(
					'btn_title_color',
					[
						'label' => __('Button Text Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .service-card-four__link' => 'color: {{VALUE}}',
							'{{WRAPPER}} .service-card-two__link' => 'color: {{VALUE}}',
							'{{WRAPPER}} .service-card-four__link .text-one' => 'color: {{VALUE}}',
							'{{WRAPPER}} .service-card-four__link .text-two' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
			$this->end_controls_tab();
			
			$this->start_controls_tab(
				'chartio_tab_btn_hover',
				[
					'label' => __( 'Hover', 'chartio' ),
				]
			);
			
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'btn_hover_bg_bgtype',
						'label' => __( 'Button Hover Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .service-card-four__link:hover,
							 {{WRAPPER}} .service-card-two__link:hover',				
					]
				);
				$this->add_control(
					'btn_border_hover_color',
					[
						'label' => __('Button Border Hover Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .service-card-four__link:hover' => 'border-color: {{VALUE}}',
							'{{WRAPPER}} .service-card-two__link:hover' => 'border-color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
				$this->add_control(
					'btn_title_hover_color',
					[
						'label' => __('Button Text Hover Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .service-card-four__link:hover' => 'color: {{VALUE}}',
							'{{WRAPPER}} .service-card-two__link:hover' => 'color: {{VALUE}}',
							'{{WRAPPER}} .service-card-four__link:hover .text-one' => 'color: {{VALUE}}',
							'{{WRAPPER}} .service-card-four__link:hover .text-two' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
			
			$this->end_controls_tab();
			
		$this->end_controls_tabs();   
		$this->end_controls_section();
		
	}
	

	/**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
		$layout = $settings[ 'layout_control' ];
		
		$grid_col = $settings[ 'col_grid' ];
		if( $grid_col == 'one' ){
			$classes = 'col-lg-12 col-md-12 col-sm-12';
		}elseif( $grid_col == 'two' ){
			$classes = 'col-lg-6 col-md-6 col-sm-12';
		}elseif( $grid_col == 'three' ){
			$classes = 'col-lg-4 col-md-6 col-sm-12';
		}elseif( $grid_col == 'four' ){
			$classes = 'col-lg-3 col-md-6 col-sm-12';
		}elseif( $grid_col == 'five' ){
			$classes = 'col-lg-2 col-md-6 col-sm-12';
		}else{
			$classes = 'col-lg-4 col-md-6 col-sm-12';
		}

        $paged = chartio_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;
        $this->add_render_attribute( 'wrapper', 'class', 'templatepath-chartio' );
		
        $args = array(
            'post_type'      => 'service',
            'posts_per_page' => chartio_set( $settings, 'query_number' ),
            'orderby'        => chartio_set( $settings, 'query_orderby' ),
            'order'          => chartio_set( $settings, 'query_order' ),
            'paged'         => $paged
        );

        if( chartio_set( $settings, 'query_category' ) ) $args['service_cat'] = chartio_set( $settings, 'query_category' );
        $query = new \WP_Query( $args );		
        if ( $query->have_posts() ) { 
	?>
	
    
        <?php if( $layout == 2 ):?>
		        
        <div class="row clearfix">
			<?php 
				global $post;
				while ( $query->have_posts() ) : $query->the_post(); 
				$post_thumbnail_id = get_post_thumbnail_id($post->ID);
				$post_thumbnail_url = wp_get_attachment_url($post_thumbnail_id); 
			?>
            <?php $chartio_service_meta = get_post_meta( get_the_ID(), 'chartio_meta_service', true );?>	
            <!-- Service Block Two -->
            <div class="service-block_three <?php echo esc_attr( $classes );?>">
                <div class="service-block_three-inner service-card-four">
                    <div class="service-block_three-image" style="background-image:url('<?php echo esc_url( $post_thumbnail_url );?>')"></div>
                    <div class="service-block_three-content">
                        <div class="service-block_three-icon service-card-four__icon mb-20">
                            <i class="<?php echo $chartio_service_meta['service_icon']; ?>"></i>
                        </div>
                        <h4 class="service-block_three-title service-card-four__title"><a href="<?php echo esc_url($chartio_service_meta['ext_url']); ?>"><?php the_title();?></a></h4>
                        <div class="service-block_three-text service-card-four__text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                    </div>
                    <div class="service-block_three-overlay">
                        <div class="service-block_three-overlay-inner">
                            <div class="service-block_three-upper">
                                <div class="service-block_three-icon_two service-card-four__icon">
                                    <i class="<?php echo $chartio_service_meta['service_icon']; ?>"></i>
                                </div>
                                <h4 class="service-block_three-title service-card-four__title"><a href="<?php echo esc_url($chartio_service_meta['ext_url']); ?>"><?php the_title();?></a></h4>
                            </div>
                            <div class="service-block_two-text-two service-card-four__text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                            <div class="service-block_three_button text-right">
                                <a href="<?php echo esc_url($chartio_service_meta['ext_url']); ?>" class="theme-btn btn-style-three service-card-four__link">
                                    <span class="btn-wrap">
                                        <span class="text-one">
                                        	<?php echo wp_kses( $settings[ 'button_label' ], true ); ?>
                                            <i class="fas fa-arrow-right fa-fw"></i>
                                        </span>
                                        <span class="text-two">
                                        	<?php echo wp_kses( $settings[ 'button_label' ], true ); ?>
                                            <i class="fas fa-arrow-right fa-fw"></i>
                                        </span>
                                    </span>
                                </a>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <?php endwhile; ?>
        </div>
        
		<?php else:?>
        
        <div class="row clearfix">
            <?php while ( $query->have_posts() ) : $query->the_post(); ?>
            <?php $chartio_service_meta = get_post_meta( get_the_ID(), 'chartio_meta_service', true );?>
            <!-- Service Block Two -->
            <div class="service-block_two <?php echo esc_attr( $classes );?>">
                <div class="service-block_two-inner service-card-four">
                    <div class="service-block_two-image">
                        <a href="<?php echo esc_url($chartio_service_meta['ext_url']); ?>"><?php the_post_thumbnail('chartio_350x245'); ?></a>
                        <div class="service-block_two-icon service-card-four__icon <?php echo $chartio_service_meta['service_icon']; ?>"></div>
                    </div>
                    <div class="service-block_two-content">
                        <h4 class="service-block_two-title service-card-four__title"><a href="<?php echo esc_url($chartio_service_meta['ext_url']); ?>"><?php the_title();?></a></h4>
                        <div class="service-block_two-text service-card-four__text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                        <?php
						if(!empty($chartio_service_meta['ext_url']))
        				{
       					?>
                        <div class="lower-box">
                            <div class="d-flex justify-content-between">
                                <a class="service-block_two-more service-card-four__link" href="<?php echo esc_url($chartio_service_meta['ext_url']); ?>"><?php echo wp_kses( $settings[ 'button_label' ], true ); ?></a>
                                <a class="service-block_two-arrow service-card-four__link" href="<?php echo esc_url($chartio_service_meta['ext_url']); ?>">
                                    <i class="fas fa-arrow-right fa-fw"></i>
                                </a>
                            </div>
                        </div>
                        <?php } ?>
                    </div>
                </div>
            </div>
            <?php endwhile; ?>
        </div>
        
        <?php endif;?>
        
		<?php }

		wp_reset_postdata();
	}
}