<?php namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use Elementor\Plugin;
/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Slider extends Widget_Base {
    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'chartio_slider';
    }
    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Chartio Slider', 'chartio-plugin' );
    }
    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-library-open';
    }
    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'chartio-plugin' ];
    }
	
	
	
    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'slider',
            [
                'label' => esc_html__( 'Slider', 'chartio-plugin' ),
            ]
        );
		$this->add_control(
			'layout_control',
			[
				'label'       => __( 'Template Layout', 'chartio-plugin' ),
				'type'        => 'elementor-layout-control',
				'default' => '1',
				'options' => [
					'1' => [
						'label' => esc_html__('Layout 1', 'chartio-plugin' ),
						'image' => get_template_directory_uri() . '/assets/images/redux/layout/banner/banner1.png'
					],
					'2' => [
						'label' => esc_html__('Layout 2', 'chartio-plugin' ),
						'image' => get_template_directory_uri() . '/assets/images/redux/layout/banner/banner22.png'
					],
					'3' => [
						'label' => esc_html__('Layout 3', 'chartio-plugin' ),
						'image' => get_template_directory_uri() . '/assets/images/redux/layout/banner/banner3.png'
					],
				],
			]
		);
		$this->add_control(
			'bg_image',
			[
			  	'label' => __( 'BG Image', 'chartio-plugin' ),
			  	'type' => Controls_Manager::MEDIA,
				'condition' => [ 'layout_control' => ['1', '2', '3'], ],
			  	'label_block' => true,
			  	'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
	    );
		$this->add_control(
			'pattern_image',
			[
			  	'label' => __( 'Pattern Image', 'chartio-plugin' ),
			  	'type' => Controls_Manager::MEDIA,
				'condition' => [ 'layout_control' => '2', ],
			  	'label_block' => true,
			  	'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
	    );
		
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'block_bg_img',
			[
				'label' => esc_html__('Slide BG Image ', 'chartio'),							
				'type' => Controls_Manager::MEDIA,							
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$repeater->add_control(
			'block_img',
			[
				'label' => esc_html__('Slide Image ', 'chartio'),							
				'type' => Controls_Manager::MEDIA,							
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$repeater->add_control(
			'block_sub_title',
			[
				'label'       => __( 'Sub Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub Title', 'chartio' ),
			]
		);
		$repeater->add_control(
			'block_title',
			[
				'label'       => __( 'Title', 'chartio' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'chartio' ),
			]
		);
		$repeater->add_control(
			'block_text',
			[
				'label'       => __( 'Text', 'chartio' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text', 'chartio' ),
			]
		);
		$repeater->add_control(
			'btn_title',
			[
				'label'       => __( 'Button Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'chartio' ),
			]
		);
		$repeater->add_control(
			'btn_link',
			[
				'label' => __( 'Button Url', 'chartio' ),							
				'type' => Controls_Manager::URL,							
				'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),							
				'show_external' => true,							
				'default' => ['url' => '','is_external' => true,'nofollow' => true,],
			]
		);
		$repeater->add_control(
			'block_text2',
			[
				'label'       => __( 'Text', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text', 'chartio' ),
			]
		);
		$repeater->add_control(
			'btn_title2',
			[
				'label'       => __( 'Button Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'chartio' ),
			]
		);
		$repeater->add_control(
			'btn_link2',
			[
				'label' => __( 'Button Url', 'chartio' ),							
				'type' => Controls_Manager::URL,							
				'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),							
				'show_external' => true,							
				'default' => ['url' => '','is_external' => true,'nofollow' => true,],
			]
		);
		$repeater->add_control(
			'btn_title3',
			[
				'label'       => __( 'Button Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'chartio' ),
			]
		);
		$repeater->add_control(
			'btn_link3',
			[
				'label' => __( 'Button Url', 'chartio' ),							
				'type' => Controls_Manager::URL,							
				'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),							
				'show_external' => true,							
				'default' => ['url' => '','is_external' => true,'nofollow' => true,],
			]
		);
		$repeater->add_control(
			'btn_title4',
			[
				'label'       => __( 'Button Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'chartio' ),
			]
		);
		$repeater->add_control(
			'btn_link4',
			[
				'label' => __( 'Button Url', 'chartio' ),							
				'type' => Controls_Manager::URL,							
				'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),							
				'show_external' => true,							
				'default' => ['url' => '','is_external' => true,'nofollow' => true,],
			]
		);
		$this->add_control(
			'slides',
			[
				'label'                 => __('Add Slider Item', 'chartio'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition' => [ 'layout_control' => '1', ],
			]
		);
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'block_img2',
			[
				'label' => esc_html__('Slide Image ', 'chartio'),							
				'type' => Controls_Manager::MEDIA,							
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$repeater->add_control(
			'block_sub_title2',
			[
				'label'       => __( 'Sub Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub Title', 'chartio' ),
			]
		);
		$repeater->add_control(
			'block_title2',
			[
				'label'       => __( 'Title', 'chartio' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'chartio' ),
			]
		);
		$repeater->add_control(
			'block_text2',
			[
				'label'       => __( 'Text', 'chartio' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text', 'chartio' ),
			]
		);
		$repeater->add_control(
			'btn_title2',
			[
				'label'       => __( 'Button Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'chartio' ),
			]
		);
		$repeater->add_control(
			'btn_link2',
			[
				'label' => __( 'Button Url', 'chartio' ),							
				'type' => Controls_Manager::URL,							
				'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),							
				'show_external' => true,							
				'default' => ['url' => '','is_external' => true,'nofollow' => true,],
			]
		);
		$repeater->add_control(
			'block_img3',
			[
				'label' => esc_html__('Slide Image ', 'chartio'),							
				'type' => Controls_Manager::MEDIA,							
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'slides22',
			[
				'label'                 => __('Add Slider Item', 'chartio'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition' => [ 'layout_control' => ['2', '3'], ],
			]
		);		
		$this->end_controls_section();
		
		/** Style Tab **/
		$this->register_style_background_controls();
    }
	
	/************************************************************************
								Tab Style Start
	*************************************************************************/
	
	protected function register_style_background_controls()
	{
		
		/**Sub Title Style**/
		$this->start_controls_section(
			'subtitle_style',
			[
				'label' => esc_html__('SUBTITLE STYLE SETTING', 'chartio-plugin'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'show_subtitle_style',
			[
				'label'       => __( 'ON/OFF Sub Title Style', 'chartio-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio-plugin' ),
				'label_off' => esc_html__( 'Hide', 'chartio-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle_typography',
                'label' => __('Sub Title Typography', 'chartio-plugin'),
                'selector' => 
                    '{{WRAPPER}} .chartio-subtitle',                 
                'separator' => 'before',
				'condition'             => [
					'show_subtitle_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'subtitle_color',
            [
                'label' => __('Sub Title Color', 'chartio-plugin'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-subtitle' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_subtitle_style'    => 'yes',
				]
            ]
        );
		$this->end_controls_section();
		
		/**Title Style**/
		$this->start_controls_section(
			'title_style',
			[
				'label' => esc_html__('TITLE STYLE SETTING', 'chartio-plugin'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'show_title_style',
			[
				'label'       => __( 'ON/OFF  Title Style', 'chartio-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio-plugin' ),
				'label_off' => esc_html__( 'Hide', 'chartio-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => __('Title Typography', 'chartio-plugin'),
                'selector' => 
                    '{{WRAPPER}} .chartio-title',                 
                'separator' => 'before',
				'condition'             => [
					'show_title_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'title_color',
            [
                'label' => __('Title Color', 'chartio-plugin'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-title' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_title_style'    => 'yes',
				]
            ]
        );
		$this->end_controls_section();
		
		/**Content Style**/
		$this->start_controls_section(
			'content_style',
			[
				'label' => esc_html__('CONTENT STYLE SETTING', 'chartio-plugin'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'show_content_style',
			[
				'label'       => __( 'ON/OFF  Content Style', 'chartio-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio-plugin' ),
				'label_off' => esc_html__( 'Hide', 'chartio-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'label' => __('Content Typography', 'chartio-plugin'),
                'selector' => 
                    '{{WRAPPER}} .chartio-text',               
                'separator' => 'before',
				'condition'             => [
					'show_content_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'content_color',
            [
                'label' => __('Content Color', 'chartio-plugin'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-text' => 'color: {{VALUE}}!important',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_content_style'    => 'yes',
				]
            ]
        );
		$this->end_controls_section();
		
		/**Button Style One**/
		$this->start_controls_section(
			'button_style',
			[
				'label' => esc_html__('DONATE NOW BUTTON STYLE SETTING', 'chartio-plugin'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'show_btn_style',
			[
				'label'       => __( 'ON/OFF Button Style', 'chartio-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio-plugin' ),
				'label_off' => esc_html__( 'Hide', 'chartio-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_control(
			'yt_btn_background',
			[
				'label'                 => __( 'Button Background', 'chartio-plugin' ),
				'type'                  => Controls_Manager::HEADING,
				'separator'             => 'before',
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'btn_bgtype',
				'label' => __( 'Button Background', 'chartio-plugin' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => 
					'{{WRAPPER}} .chartio-btn-title',				
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_control(
			'hover_background',
			[
				'label'                 => __( 'Button Hover Background', 'chartio-plugin' ),
				'type'                  => Controls_Manager::HEADING,
				'separator'             => 'before',
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'btn_hover_bg_bgtype',
				'label' => __( 'Button Hover Background', 'chartio-plugin' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => 
					'{{WRAPPER}} .chartio-btn-title:hover:before',				
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_control(
			'show_border_radius',
			[
				'label'       => __( 'ON/OFF Button Radius Style', 'chartio-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio-plugin' ),
				'label_off' => esc_html__( 'Hide', 'chartio-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_control(
            'btn_border_radius',
            [
                'label' => esc_html__('Border Radius', 'chartio-plugin'),
                'type' => Controls_Manager::DIMENSIONS,
                'separator' => 'before',
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .chartio-btn-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
				'condition'             => [
					'show_border_radius'    => 'yes',
				]
            ]
        );
		$this->add_control(
			'show_border_type',
			[
				'label'       => __( 'ON/OFF Border Style', 'chartio-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio-plugin' ),
				'label_off' => esc_html__( 'Hide', 'chartio-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'btn_border_type',
                'selector' => 
					'{{WRAPPER}} .chartio-btn-title',				
				'separator' => 'before',
				'condition'             => [
					'show_border_type'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'btn_border_hover_color',
            [
                'label' => __('Button Border Hover Color', 'chartio-plugin'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-btn-title:hover' => 'border-color: {{VALUE}}!important',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_border_type'    => 'yes',
				]
            ]
        );
		$this->add_control(
			'show_box_shadow',
			[
				'label'       => __( 'ON/OFF Box Shadow Style', 'chartio-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio-plugin' ),
				'label_off' => esc_html__( 'Hide', 'chartio-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'border_box_shadow',
                'selector' => 
					'{{WRAPPER}} .chartio-btn-title',				
				'separator' => 'before',
				'condition'             => [
					'show_box_shadow'    => 'yes',
				]
            ]
        );
		$this->add_control(
			'show_btn_padding',
			[
				'label'       => __( 'ON/OFF Padding Style', 'chartio-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio-plugin' ),
				'label_off' => esc_html__( 'Hide', 'chartio-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_responsive_control(
            'btn_padding',
            [
                'label'              => __( 'Padding', 'chartio-plugin' ),
                'type'               => Controls_Manager::DIMENSIONS,
                'size_units'         => [ 'px', 'em', '%' ],
                'selectors'          => [
                    '{{WRAPPER}} .chartio-btn-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
				
                'frontend_available' => true,
				'condition'             => [
					'show_btn_padding'    => 'yes',
				]
            ]
        );
		$this->add_control(
			'show_typo_color',
			[
				'label'       => __( 'ON/OFF Typography and Color Style', 'chartio-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio-plugin' ),
				'label_off' => esc_html__( 'Hide', 'chartio-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_title_typography',
                'label' => __('Button Text Typography', 'chartio-plugin'),
                'selector' => 
					'{{WRAPPER}} .chartio-btn-title,
								 .chartio-btn-title .text-one,
								 .chartio-btn-title .text-two',				
                'separator' => 'before',
				'condition'             => [
					'show_typo_color'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'btn_title_color',
            [
                'label' => __('Button Text Color', 'chartio-plugin'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-btn-title' => 'color: {{VALUE}}!important;',
					'{{WRAPPER}} .chartio-btn-title .text-one' => 'color: {{VALUE}}!important;',
					'{{WRAPPER}} .chartio-btn-title .text-two' => 'color: {{VALUE}}!important;',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_typo_color'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'btn_title_hover_color',
            [
                'label' => __('Button Text Hover Color', 'chartio-plugin'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-btn-title:hover' => 'color: {{VALUE}}!important;',
					'{{WRAPPER}} .chartio-btn-title:hover .text-one' => 'color: {{VALUE}}!important;',
					'{{WRAPPER}} .chartio-btn-title:hover .text-two' => 'color: {{VALUE}}!important;',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_typo_color'    => 'yes',
				]
            ]
        );
		$this->end_controls_section();
		
		/**Button Style Two**/
		$this->start_controls_section(
			'button_style2',
			[
				'label' => esc_html__('BUTTONS STYLE SETTING', 'chartio-plugin'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'show_btn_style2',
			[
				'label'       => __( 'ON/OFF Button Style', 'chartio-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio-plugin' ),
				'label_off' => esc_html__( 'Hide', 'chartio-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_control(
			'yt_btn_background2',
			[
				'label'                 => __( 'Button Background', 'chartio-plugin' ),
				'type'                  => Controls_Manager::HEADING,
				'separator'             => 'before',
				'condition'             => [
					'show_btn_style2'    => 'yes',
				]
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'btn_bgtype2',
				'label' => __( 'Button Background', 'chartio-plugin' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => 
					'{{WRAPPER}} .chartio-btn-title-two',				
				'condition'             => [
					'show_btn_style2'    => 'yes',
				]
			]
		);
		$this->add_control(
			'hover_background2',
			[
				'label'                 => __( 'Button Hover Background', 'chartio-plugin' ),
				'type'                  => Controls_Manager::HEADING,
				'separator'             => 'before',
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'btn_hover_bg_bgtype2',
				'label' => __( 'Button Hover Background', 'chartio-plugin' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => 
					'{{WRAPPER}} .chartio-btn-title-two:hover',				
				'condition'             => [
					'show_btn_style2'    => 'yes',
				]
			]
		);
		$this->add_control(
			'show_border_radius2',
			[
				'label'       => __( 'ON/OFF Button Radius Style', 'chartio-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio-plugin' ),
				'label_off' => esc_html__( 'Hide', 'chartio-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style2'    => 'yes',
				]
			]
		);
		$this->add_control(
            'btn_border_radius2',
            [
                'label' => esc_html__('Border Radius', 'chartio-plugin'),
                'type' => Controls_Manager::DIMENSIONS,
                'separator' => 'before',
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .chartio-btn-title-two' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
				'condition'             => [
					'show_border_radius2'    => 'yes',
				]
            ]
        );
		$this->add_control(
			'show_border_type2',
			[
				'label'       => __( 'ON/OFF Border Style', 'chartio-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio-plugin' ),
				'label_off' => esc_html__( 'Hide', 'chartio-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style2'    => 'yes',
				]
			]
		);
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'btn_border_type2',
                'selector' => 
					'{{WRAPPER}} .chartio-btn-title-two',				
				'separator' => 'before',
				'condition'             => [
					'show_border_type2'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'btn_border_hover_color2',
            [
                'label' => __('Button Border Hover Color', 'chartio-plugin'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-btn-title-two:hover' => 'border-color: {{VALUE}}!important',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_border_type2'    => 'yes',
				]
            ]
        );
		$this->add_control(
			'show_box_shadow2',
			[
				'label'       => __( 'ON/OFF Box Shadow Style', 'chartio-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio-plugin' ),
				'label_off' => esc_html__( 'Hide', 'chartio-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style2'    => 'yes',
				]
			]
		);
		$this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'border_box_shadow2',
                'selector' => 
					'{{WRAPPER}} .chartio-btn-title-two',				
				'separator' => 'before',
				'condition'             => [
					'show_box_shadow2'    => 'yes',
				]
            ]
        );
		$this->add_control(
			'show_btn_padding2',
			[
				'label'       => __( 'ON/OFF Padding Style', 'chartio-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio-plugin' ),
				'label_off' => esc_html__( 'Hide', 'chartio-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style2'    => 'yes',
				]
			]
		);
		$this->add_responsive_control(
            'btn_padding2',
            [
                'label'              => __( 'Padding', 'chartio-plugin' ),
                'type'               => Controls_Manager::DIMENSIONS,
                'size_units'         => [ 'px', 'em', '%' ],
                'selectors'          => [
                    '{{WRAPPER}} .chartio-btn-title-two' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
				
                'frontend_available' => true,
				'condition'             => [
					'show_btn_padding2'    => 'yes',
				]
            ]
        );
		$this->add_control(
			'show_typo_color2',
			[
				'label'       => __( 'ON/OFF Typography and Color Style', 'chartio-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio-plugin' ),
				'label_off' => esc_html__( 'Hide', 'chartio-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style2'    => 'yes',
				]
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_title_typography2',
                'label' => __('Button Text Typography', 'chartio-plugin'),
                'selector' => 
					'{{WRAPPER}} .chartio-btn-title-two',				
                'separator' => 'before',
				'condition'             => [
					'show_typo_color2'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'btn_title_color2',
            [
                'label' => __('Button Text Color', 'chartio-plugin'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-btn-title-two' => 'color: {{VALUE}}!important',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_typo_color2'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'btn_title_hover_color2',
            [
                'label' => __('Button Text Hover Color', 'chartio-plugin'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-btn-title-two:hover' => 'color: {{VALUE}}!important',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_typo_color2'  => 'yes',
				]
            ]
        );
		$this->end_controls_section();
	}
	
	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');		
	?>
    
    <?php if($settings['layout_control'] == 3): ?>
    
    <!-- Slider Three -->
	<section class="slider-three">
		<div class="slider-three_pattern" <?php if($settings['bg_image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['bg_image']['id'])); ?>)"<?php } ?>></div>
		<div class="main-slider_three swiper-container">
			<div class="swiper-wrapper">
				<?php foreach($settings['slides22'] as $key => $item):?>
				<!-- Slide -->
				<div class="swiper-slide">
					<div class="slider-three_color-layer"></div>
					<div class="slider-three_image-layer" <?php if($item['block_img3']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($item['block_img3']['id'])); ?>)"<?php } ?>></div>
					<div class="auto-container">
						<div class="row clearfix">
							<!-- Content Column -->
							<div class="slider-three_content col-lg-7 col-md-12 col-sm-12">
								<div class="slider-three_content-inner">
									<div class="slider-three_title chartio-subtitle"><?php echo wp_kses($item['block_sub_title2'], true) ;?></div>
									<h1 class="slider-three_heading chartio-title"><?php echo wp_kses($item['block_title2'], true) ;?></h1>
									<div class="slider-three_text chartio-text"><?php echo wp_kses($item['block_text2'], true) ;?></div>
									<div class="d-flex align-items-center flex-wrap">
										<div class="slider-three_buttons">
											<a href="<?php echo esc_url($item['btn_link2']['url']);?>" class="theme-btn btn-style-six chartio-btn-title">
                                                <span class="btn-wrap">
                                                    <span class="text-one"><?php echo wp_kses($item['btn_title2'], true);?> <i class="fas fa-arrow-circle-right fa-fw"></i></span>
                                                    <span class="text-two"><?php echo wp_kses($item['btn_title2'], true);?> <i class="fas fa-arrow-circle-right fa-fw"></i></span>
                                                </span>
                                            </a>
										</div>
									</div>
								</div>
							</div>
                            <?php if($item['block_img2']['id']){ ?>
							<!-- Image Column -->
							<div class="slider-three_image-column col-lg-5 col-md-12 col-sm-12">
								<div class="slider-three_image">
									<img src="<?php echo esc_url(wp_get_attachment_url($item['block_img2']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'chartio');?>" />
								</div>
							</div>
							<?php } ?>
						</div>
						
					</div>
				</div>
                <?php endforeach;?>
			</div>
            
            <div class="main-slider_three-pagination"></div>
        	
			<div class="slider-two-arrow">
				<!-- If we need navigation buttons -->
				<div class="slider-two-button-prev fas fa-arrow-up fa-fw"></div>
				<div class="slider-two-button-next fas fa-arrow-down fa-fw"></div>
			</div>           
		</div>
	</section>
	<!-- End Main Slider Section -->
    
    <?php elseif($settings['layout_control'] == 2): ?>
    
    <!-- Slider Two -->
	<section class="slider-two" <?php if($settings['bg_image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['bg_image']['id'])); ?>)"<?php } ?>>
		<div class="slider-two_curve" <?php if($settings['pattern_image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['pattern_image']['id'])); ?>)"<?php } ?>></div>
		<div class="main-slider_two swiper-container">
			<div class="swiper-wrapper">
				<?php foreach($settings['slides22'] as $key => $item):?>
				<!-- Slide -->
				<div class="swiper-slide">
					<div class="auto-container">
						<div class="row clearfix">
							<!-- Content Column -->
							<div class="slider-two_content col-lg-7 col-md-12 col-sm-12">
								<div class="slider-two_content-inner">
									<div class="slider-two_title chartio-subtitle"><?php echo wp_kses($item['block_sub_title2'], true) ;?></div>
									<h1 class="slider-two_heading chartio-title"><?php echo wp_kses($item['block_title2'], true) ;?></h1>
									<div class="slider-two_text chartio-text"><?php echo wp_kses($item['block_text2'], true) ;?></div>
									<div class="slider-two_button">
										<a href="<?php echo esc_url($item['btn_link2']['url']);?>" class="theme-btn btn-style-three chartio-btn-title">
											<span class="btn-wrap">
												<span class="text-one"><?php echo wp_kses($item['btn_title2'], true);?> <i class="fas fa-arrow-right fa-fw"></i></span>
												<span class="text-two"><?php echo wp_kses($item['btn_title2'], true);?> <i class="fas fa-arrow-right fa-fw"></i></span>
											</span>
										</a>
									</div>
								</div>
							</div>
                            <?php if($item['block_img2']['id']){ ?>
							<!-- Image Column -->
							<div class="slider-two_image-column col-lg-5 col-md-12 col-sm-12">
								<div class="slider-two_image">
									<img src="<?php echo esc_url(wp_get_attachment_url($item['block_img2']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'chartio');?>" />
								</div>
								<div class="slider-two_image-shadow"></div>
							</div>
							<?php } ?>
						</div>
						
					</div>
				</div>
				<?php endforeach;?>
			</div>
            
            
			<div class="slider-two-arrow">
				<!-- If we need navigation buttons -->
				<div class="slider-two-button-prev fas fa-arrow-up fa-fw"></div>
				<div class="slider-two-button-next fas fa-arrow-down fa-fw"></div>
			</div>
            			
		</div>
	</section>
	<!-- End Main Slider Section -->
    
    <?php else: ?>
    
    <!-- Slider One -->
	<section class="slider-one">
		<div class="slider-one_pattern-layer" <?php if($settings['bg_image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['bg_image']['id'])); ?>)"<?php } ?>></div>
		<div class="main-slider swiper-container">
			<div class="swiper-wrapper">
				<?php foreach($settings['slides'] as $key => $item):?>
				<!-- Slide -->
				<div class="swiper-slide">
					<div class="slider-one_image-layer" style="background-image:url('<?php echo esc_url(wp_get_attachment_url($item['block_bg_img']['id'])); ?>')"></div>
					<div class="auto-container">
						<?php if($item['block_img']['id']){ ?>
                        <div class="slider-one_image">
							<img src="<?php echo esc_url(wp_get_attachment_url($item['block_img']['id'])); ?>" alt="<?php esc_attr_e('Awesome Image', 'chartio');?>">
						</div>
                        <?php } ?>
						<div class="row clearfix">
							<!-- Content Column -->
							<div class="slider-one_content col-lg-8 col-md-12 col-sm-12">
								<div class="slider-one_content-inner">
									<div class="slider-one_title chartio-subtitle"><?php echo wp_kses($item['block_sub_title'], true) ;?></div>
									<h1 class="slider-one_heading chartio-title"><?php echo wp_kses($item['block_title'], true) ;?></h1>
									<div class="slider-one_text chartio-text"><?php echo wp_kses($item['block_text'], true) ;?></div>
									<div class="d-flex align-items-center flex-wrap tx-content-wrap">
										<div class="slider-one_buttons">
											<a href="<?php echo esc_url($item['btn_link']['url']);?>" class="theme-btn btn-style-two chartio-btn-title">
												<span class="btn-wrap">
													<span class="text-one"><?php echo wp_kses($item['btn_title'], true);?></span>
													<span class="text-two"><?php echo wp_kses($item['btn_title'], true);?></span>
												</span>
											</a>
										</div>
										<div class="slider-one_childrens chartio-text-two"><?php echo wp_kses($item['block_text2'], true) ;?></div>
									</div>
								</div>
							</div>
							<!-- Info Column -->
							<div class="info-column col-lg-4 col-md-12 col-sm-12">
								<ul class="slider-one_list">
									<li><a href="<?php echo esc_url($item['btn_link2']['url']);?>" class="chartio-btn-title-two"><?php echo wp_kses($item['btn_title2'], true);?></a></li>
									<li><a href="<?php echo esc_url($item['btn_link3']['url']);?>" class="chartio-btn-title-two"><?php echo wp_kses($item['btn_title3'], true);?></a></li>
									<li><a href="<?php echo esc_url($item['btn_link4']['url']);?>" class="chartio-btn-title-two"><?php echo wp_kses($item['btn_title4'], true);?></a></li>
								</ul>
							</div>

						</div>
						
					</div>
				</div>
				<?php endforeach;?>
			</div>
            
			<div class="slider-one-arrow">
				<!-- If we need navigation buttons -->
				<div class="main-slider-prev fas fa-arrow-left fa-fw"></div>
				<div class="main-slider-next fas fa-arrow-right fa-fw"></div>
			</div>
            
		</div>
	</section>
	<!-- End Main Slider Section -->
    
      <?php endif;
    }
}