<?php

namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Team_Grid extends Widget_Base {
	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'chartio_team_grid';
	}
	
	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Chartio Team Grid', 'chartio' );
	}
	
	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-parallax';
	}
	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'chartio' ];
	}	
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'team_grid',
			[
				'label' => esc_html__( 'Team Grid', 'chartio' ),
			]
		);
		
		$this->add_control(
			'team_style',
			[
				'label'   => esc_html__( 'Choose Layout Style', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1'   => esc_html__( 'Style One ', 'chartio' ),
					'2'   => esc_html__( 'Style Two ', 'chartio'),
				),
			]
		);
		
		$this->add_control(
			'col_grid',
			[
				'label'   => esc_html__( 'Choose Column', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'default',
				'options' => array(
					'default'  => esc_html__( 'Default', 'chartio' ),
					'one' => esc_html__( 'One Column Grid ', 'chartio'),
					'two'  => esc_html__( 'Two Column Grid', 'chartio' ),
					'three'  => esc_html__( 'Three Column Grid', 'chartio' ),
					'four'  => esc_html__( 'Four Column Grid', 'chartio' ),
					'five'  => esc_html__( 'Six Column Grid', 'chartio' ),
				),
			]
		);
		
		$this->add_control(
            'query_number',
            [
                'label'   => esc_html__( 'Number of post', 'greenture' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 6,
                'min'     => 1,
                'max'     => 100,
                'step'    => 1,
            ]
        );
        $this->add_control(
            'query_orderby',
            [
                'label'   => esc_html__( 'Order By', 'greenture' ),
				'label_block' => true,
                'type'    => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => array(
                    'date'       => esc_html__( 'Date', 'greenture' ),
                    'title'      => esc_html__( 'Title', 'greenture' ),
                    'menu_order' => esc_html__( 'Menu Order', 'greenture' ),
                    'rand'       => esc_html__( 'Random', 'greenture' ),
                ),
            ]
        );
        $this->add_control(
            'query_order',
            [
                'label'   => esc_html__( 'Order', 'greenture' ),
				'label_block' => true,
                'type'    => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => array(
                    'DESC' => esc_html__( 'DESC', 'greenture' ),
                    'ASC'  => esc_html__( 'ASC', 'greenture' ),
                ),
            ]
        );
		$this->add_control(
            'query_category', 
			[
			  'type' => Controls_Manager::SELECT,
			  'label_block' => true,
			  'label' => esc_html__('Category', 'chartio'),
			  'options' => get_team_categories()
			]
		);
		$this->end_controls_section();
		
		/************************************************************************
								Tab Style Start
		*************************************************************************/
		
		/**Team Box Style**/
		$this->start_controls_section(
			'team_box_style',
			[
				'label' => esc_html__('Box Setting', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->start_controls_tabs( 'chartio_team_box_tab' );
		
			$this->start_controls_tab(
				'chartio_team_box_normal',
				[
					'label' => __( 'Normal', 'chartio' ),
				]
			);
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'team_box_bgtype',
						'label' => __( 'Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .team-card__content,
							 {{WRAPPER}} .team-block_one-inner',				
					]
				);
				$this->add_responsive_control(
					'team_box_space',
					[
						'label'              => __( 'Space', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .team-card' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_responsive_control(
					'team_box_padding',
					[
						'label'              => __( 'Padding', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .team-card__content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .team-block_one-inner' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_group_control(
					Group_Control_Border::get_type(),
					[
						'name' => 'team_box_border_type',
						'selector' => 
							'{{WRAPPER}} .team-card__content,
							 {{WRAPPER}} .team-block_one-inner',				
						'separator' => 'before',
					]
				);
				$this->add_group_control(
					Group_Control_Box_Shadow::get_type(),
					[
						'name' => 'team_box_shadow',
						'selector' => 
							'{{WRAPPER}} .team-card__content,
							 {{WRAPPER}} .team-block_one-inner',				
						'separator' => 'before',
					]
				);
				$this->add_control(
					'team_border_radius',
					[
						'label' => esc_html__('Border Radius', 'chartio'),
						'type' => Controls_Manager::DIMENSIONS,
						'separator' => 'before',
						'size_units' => ['px'],
						'selectors' => [
							'{{WRAPPER}} .team-card__content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .team-block_one-inner' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);
			$this->end_controls_tab();
			
			$this->start_controls_tab(
				'chartio_teams_box_hover',
				[
					'label' => __( 'Hover', 'chartio' ),
				]
			);
			
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'team_hover_bg_bgtype',
						'label' => __( 'Hover Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .team-block_one-inner:hover',				
					]
				);
				
				$this->add_control(
					'team_background_hover_transition',
					[
						'label' => esc_html__( 'Transition Duration', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'max' => 3,
								'step' => 0.1,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .team-block_one-inner:hover' => 'transition-duration: {{SIZE}}s',
						],
					]
				);
		
				$this->add_control(
					'hover_animation',
					[
						'label' => esc_html__( 'Hover Animation', 'chartio' ),
						'type' => Controls_Manager::HOVER_ANIMATION,
					]
				);
				
			$this->end_controls_tab();
			
		$this->end_controls_tabs();   
		$this->end_controls_section();
		
		//Title Style
		$this->start_controls_section(
			'title_style',
			[
				'label' => esc_html__( 'Title Setting', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
            'title__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .team-card__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'title_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .team-card__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-card__title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .team-card__title a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_hover_color',
			[
				'label' => esc_html__( 'Text Hover Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-card__title a:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => 
					'{{WRAPPER}} .team-card__title',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Stroke::get_type(),
			[
				'name' => 'title_text_stroke',
				'selector' => 
					'{{WRAPPER}} .team-card__title',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'title_text_shadow',
				'selector' => 
					'{{WRAPPER}} .team-card__title',
			]
		);

		$this->end_controls_section();
		
		//Text Style
		$this->start_controls_section(
			'text_style',
			[
				'label' => esc_html__( 'Designation Setting', 'chartio' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
            'text__margin',
            [
                'label'      => esc_html__( 'Margin', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .team-card__designation' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
        $this->add_responsive_control(
            'text_padding',
            [
                'label'      => esc_html__( 'Padding', 'pyloncore' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .team-card__designation' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );
		
		$this->add_control(
			'text_color',
			[
				'label' => esc_html__( 'Text Color', 'chartio' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-card__designation' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'label' => __('Typography', 'chartio'),
				'selector' => 
				'{{WRAPPER}} .team-card__designation',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'text_text_shadow',
				'selector' => 
					'{{WRAPPER}} .team-card__designation',
			]
		);

		$this->end_controls_section();
		
		/**Icon Box Style**/
		$this->start_controls_section(
			'icon_box_style',
			[
				'label' => esc_html__('Social Icon Setting', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->start_controls_tabs( 'chartio_social_icon_tab' );
		
			$this->start_controls_tab(
				'chartio_social_icon_normal',
				[
					'label' => __( 'Normal', 'chartio' ),
				]
			);
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'icon_box_bgtype',
						'label' => __( 'Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .team-card__social,
										 .team-card__social a'				
					]
				);
				$this->add_control(
					'social_icon_color',
					[
						'label' => __('Button Text Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .team-card__social' => 'color: {{VALUE}}',
							'{{WRAPPER}} .team-card__social a' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
				$this->add_responsive_control(
					'icon_box_space',
					[
						'label'              => __( 'Space', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .team-card__social' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .team-card__social a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_responsive_control(
					'icon_box_padding',
					[
						'label'              => __( 'Padding', 'chartio' ),
						'type'               => Controls_Manager::DIMENSIONS,
						'size_units'         => [ 'px', 'em', '%' ],
						'selectors'          => [
							'{{WRAPPER}} .team-card__social' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .team-card__social a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
						],
						
						'frontend_available' => true,
					]
				);
				$this->add_group_control(
					Group_Control_Border::get_type(),
					[
						'name' => 'social_icon_border_type',
						'selector' => 
							'{{WRAPPER}} .team-card__social,
										 .team-card__social a',				
						'separator' => 'before',
					]
				);
				$this->add_group_control(
					Group_Control_Box_Shadow::get_type(),
					[
						'name' => 'social_icon_box_shadow',
						'selector' => 
							'{{WRAPPER}} .team-card__social,
										 .team-card__social a',				
						'separator' => 'before',
					]
				);
				$this->add_control(
					'social_icon_border_radius',
					[
						'label' => esc_html__('Border Radius', 'chartio'),
						'type' => Controls_Manager::DIMENSIONS,
						'separator' => 'before',
						'size_units' => ['px'],
						'selectors' => [
							'{{WRAPPER}} .team-card__social' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							'{{WRAPPER}} .team-card__social a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);
			$this->end_controls_tab();
			
			$this->start_controls_tab(
				'chartio_socials_icon_box_hover',
				[
					'label' => __( 'Hover', 'chartio' ),
				]
			);
			
				$this->add_group_control(
					Group_Control_Background::get_type(),
					[
						'name' => 'social_icon_hover_bg_bgtype',
						'label' => __( 'Hover Background', 'chartio' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => 
							'{{WRAPPER}} .team-card__social li:hover,
										 .team-card__social a:hover,
										 .team-card__social:hover',				
					]
				);
				
				$this->add_control(
					'icon_hover_color',
					[
						'label' => __('Button Text Color', 'chartio'),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .team-card__social li:hover' => 'color: {{VALUE}}',
							'{{WRAPPER}} .team-card__social a:hover' => 'color: {{VALUE}}',
						],
						'separator' => 'before',
					]
				);
				
				$this->add_control(
					'social_icon_hover_transition',
					[
						'label' => esc_html__( 'Transition Duration', 'chartio' ),
						'type' => Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'max' => 3,
								'step' => 0.1,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .team-card__social li:hover' => 'transition-duration: {{SIZE}}s',
							'{{WRAPPER}} .team-card__social a:hover' => 'transition-duration: {{SIZE}}s',
						],
					]
				);
		
				$this->add_control(
					'social_icon_hover_animation',
					[
						'label' => esc_html__( 'Hover Animation', 'chartio' ),
						'type' => Controls_Manager::HOVER_ANIMATION,
					]
				);
				
			$this->end_controls_tab();
			
		$this->end_controls_tabs();   
		$this->end_controls_section();
    }
	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
		
		$grid_col = $settings[ 'col_grid' ];
		if( $grid_col == 'one' ){
			$classes = 'col-lg-12 col-md-12 col-sm-12';
		}elseif( $grid_col == 'two' ){
			$classes = 'col-lg-6 col-md-6 col-sm-12';
		}elseif( $grid_col == 'three' ){
			$classes = 'col-lg-4 col-md-6 col-sm-12';
		}elseif( $grid_col == 'four' ){
			$classes = 'col-lg-3 col-md-6 col-sm-12';
		}elseif( $grid_col == 'five' ){
			$classes = 'col-lg-2 col-md-6 col-sm-12';
		}else{
			$classes = 'col-lg-4 col-md-6 col-sm-12';
		}
		
        $paged = chartio_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;
		$this->add_render_attribute( 'wrapper', 'class', 'templatepath-chartio' );
		$args = array(
			'post_type'      =>  'team',
			'posts_per_page' => chartio_set( $settings, 'query_number' ),
			'orderby'        => chartio_set( $settings, 'query_orderby' ),
			'order'          => chartio_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
				
		if( chartio_set( $settings, 'query_category' ) ) $args['team_cat'] = chartio_set( $settings, 'query_category' );
		$query = new \WP_Query( $args );
		if ( $query->have_posts() ) 
		{ 
	?>
    
    <?php if($settings['team_style'] == 2 ) : ?>
    
    <div class="row clearfix">
		<?php while ( $query->have_posts() ) : $query->the_post(); ?>
        <?php $chartio_team_meta = get_post_meta( get_the_ID(), 'chartio_meta_team', true );?>
        <!-- Team Block One -->
        <div class="volunter-block_one <?php echo esc_attr( $classes );?>">
            <div class="volunter-block_one-inner team-card__content wow fadeInLeft" data-wow-delay="0ms" data-wow-duration="1500ms">
                <div class="volunter-block_one-image">
                    <?php the_post_thumbnail('chartio_307x417'); ?>
					<div class="volunter-block_one-content">
                    	<h4 class="volunter-block_one-title team-card__title"><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h4>
						<?php
                            $icons = $chartio_team_meta['social_profile'];
                            if ( ! empty( $icons ) ) :								
                        ?>
                        <!-- Socials Box -->
                        <div class="volunter-block_one-social team-card__social">
                            <?php foreach ( $icons as $h_icon ) {
                
                                $icon_class = explode( '-', chartio_set( $h_icon, 'icon' ) ); 
                            ?>
                            <a href="<?php echo esc_url(chartio_set( $h_icon, 'url' )); ?>" <?php if( chartio_set( $h_icon, 'background' ) || chartio_set( $h_icon, 'color' ) ):?>style="background-color:<?php echo esc_attr(chartio_set( $h_icon, 'background' )); ?>; color: <?php echo esc_attr(chartio_set( $h_icon, 'color' )); ?>"<?php endif;?>><i class="fab <?php echo esc_attr( chartio_set( $h_icon, 'icon' ) ); ?>"></i></a>
                            <?php } ?>
                        </div>
                        <?php endif; ?>
                	</div>
            	</div>
        	</div>
        </div>    
        <?php endwhile; ?>
    </div>
	
    <?php else: ?>
    
    <div class="row clearfix">
		<?php while ( $query->have_posts() ) : $query->the_post(); ?>
        <?php $chartio_team_meta = get_post_meta( get_the_ID(), 'chartio_meta_team', true );?>
        <!-- Team Block One -->
        <div class="team-block_one <?php echo esc_attr( $classes );?>">
            <div class="team-block_one-inner">
                <div class="team-block_one-image">
                    <?php the_post_thumbnail('chartio_371x418'); ?>
                    <?php
						$icons = $chartio_team_meta['social_profile'];
						if ( ! empty( $icons ) ) :								
					?>
                    <!-- Socials Box -->
                    <div class="team-block_one-social team-card__social">
                        <?php foreach ( $icons as $h_icon ) {
            
							$icon_class = explode( '-', chartio_set( $h_icon, 'icon' ) ); 
						?>
                        <a href="<?php echo esc_url(chartio_set( $h_icon, 'url' )); ?>" <?php if( chartio_set( $h_icon, 'background' ) || chartio_set( $h_icon, 'color' ) ):?>style="background-color:<?php echo esc_attr(chartio_set( $h_icon, 'background' )); ?>; color: <?php echo esc_attr(chartio_set( $h_icon, 'color' )); ?>"<?php endif;?>><i class="fab <?php echo esc_attr( chartio_set( $h_icon, 'icon' ) ); ?>"></i></a>
                        <?php } ?>
                    </div>
                    <?php endif; ?>
                </div>
                <div class="team-block_one-content">
                    <h3 class="team-block_one-title team-card__title"><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h3>
                    <div class="team-block_one-designation team-card__designation"><?php echo wp_kses($chartio_team_meta['designation'], true ); ?></div>
                </div>
            </div>
        </div>
        <?php endwhile; ?>
    </div>
	
    <?php endif; ?>
      <?php }
		wp_reset_postdata();
	}
}