<?php
namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Testimonials extends Widget_Base {
	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	 
	public function get_name() {
		return 'chartio_testimonials';
	}
	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Chartio Testimonials ', 'chartio' );
	}
	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-testimonial';
	}
	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'chartio' ];
	}
	
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'testimonials',
			[
				'label' => esc_html__( 'Testimonials ', 'chartio' ),
			]
		);
		
		$this->add_control(
			'testimonials_style',
			[
				'label'   => esc_html__( 'Layout Style', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'chartio'),
					'2' => esc_html__( 'Style Two ', 'chartio'),
					'3' => esc_html__( 'Style Three ', 'chartio'),
					'4' => esc_html__( 'Style Four ', 'chartio'),
				),
			]
		);
		
		$this->add_control(
			'image',
			[
				'label' => esc_html__('Choose Image ', 'chartio'),							
				'type' => Controls_Manager::MEDIA,
				'condition' => [ 'testimonials_style' => ['1', '3'], ],
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		
		$this->add_control(
			'title',
			[
				'label'       => __( 'Sub Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'condition' => [ 'testimonials_style' => ['1', '3'], ],
				'placeholder' => __( 'Enter your Sub Title Here', 'chartio' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'condition' => [ 'testimonials_style' => ['1', '3'], ],
				'placeholder' => __( 'Enter your Title Here', 'chartio' ),
			]
		);
		
		$this->add_control(
            'text_limit',
            [
                'label'   => esc_html__( 'Text Limit', 'chartio' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 25,
                'min'     => 1,
                'max'     => 100,
                'step'    => 1,
            ]
        );
		$this->add_control(
			'query_number',
			[
				'label'   => esc_html__( 'Number of post', 'chartio' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 4,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'chartio' ),
					'title'      => esc_html__( 'Title', 'chartio' ),
					'menu_order' => esc_html__( 'Menu Order', 'chartio' ),
					'rand'       => esc_html__( 'Random', 'chartio' ),
				),
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESC' => esc_html__( 'DESC', 'chartio' ),
					'ASC'  => esc_html__( 'ASC', 'chartio' ),
				),
			]
		);
		$this->add_control(
            'query_category', 
			[
			  'type' => Controls_Manager::SELECT,
			  'label' => esc_html__('Category', 'chartio'),
			  'label_block' => true,
			  'options' => get_testimonials_categories()
			]
		);
		
		$this->add_control(
			'pattern_image',
			[
				'label' => esc_html__('Choose Pattern Image ', 'chartio'),							
				'type' => Controls_Manager::MEDIA,
				'condition' => [ 'testimonials_style' => ['1', '3'], ],			
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'block_title',
			[
				'label' => esc_html__('Block Title', 'chartio'),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Block Title', 'chartio' ),
			]
		);
		$repeater->add_control(
			'counter_stop2',
			[
				'label' => esc_html__('Counter Value', 'chartio'),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Counter Value', 'chartio' ),
			]
		);
		$repeater->add_control(
			'alphabet_letter2',
			[
				'label' => esc_html__('Alphabet Letter', 'chartio'),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Alphabet Letter', 'chartio' ),
			]
		);
		$this->add_control(
			'funfact',
			[
				'label'                 => __('Add Funfact Item', 'chartio'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition' => [ 'testimonials_style' => ['1', '3'], ],
			]
		);
		
		$this->end_controls_section();
		
		
		/** Style Tab **/
		$this->register_style_background_controls();
    }
	
	/************************************************************************
								Tab Style Start
	*************************************************************************/
	
	protected function register_style_background_controls()
	{
		
		/**Loop Style**/
		$this->start_controls_section(
			'loop_style',
			[
				'label' => esc_html__('LOOP CONTENT STYLE SETTING', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		//Loop Background Color Style
		$this->add_control(
			'show_loop_loop_style',
			[
				'label'       => __( 'ON/OFF  Loop Background Color Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);		
		$this->add_control(
            'loop_loop_bgcolor',
            [
                'label' => __('Loop Background Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-testi-grid' => 'background-color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_loop_style'    => 'yes',
				]
            ]
        );			
		//Title Style
		$this->add_control(
			'show_loop_title_style',
			[
				'label'       => __( 'ON/OFF  Title Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_title_typography',
                'label' => __('Title Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .chartio-testi-title',                 
                'separator' => 'before',
				'condition'             => [
					'show_loop_title_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_title_color',
            [
                'label' => __('Title Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-testi-title' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_title_style'    => 'yes',
				]
            ]
        );
		//Content Style
		$this->add_control(
			'show_loop_content_style',
			[
				'label'       => __( 'ON/OFF  Content Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_content_typography',
                'label' => __('Content Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .chartio-testi-text',                 
                'separator' => 'before',
				'condition'             => [
					'show_loop_content_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_content_color',
            [
                'label' => __('Content Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-testi-text' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_content_style'    => 'yes',
				]
            ]
        );
		//Author Name
		$this->add_control(
			'show_loop_author_style',
			[
				'label'       => __( 'ON/OFF  Author Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_author_typography',
                'label' => __('Author Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .chartio-testi-author',                 
                'separator' => 'before',
				'condition'             => [
					'show_loop_author_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_author_color',
            [
                'label' => __('Author Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-testi-author' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_author_style'    => 'yes',
				]
            ]
        );
		//Designation
		$this->add_control(
			'show_loop_designation_style',
			[
				'label'       => __( 'ON/OFF  Designation Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_designation_typography',
                'label' => __('Designation Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .chartio-testi-designation',                 
                'separator' => 'before',
				'condition'             => [
					'show_loop_designation_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_designation_color',
            [
                'label' => __('Designation Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-testi-designation' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_designation_style'    => 'yes',
				]
            ]
        );		
		//Icon Style
		$this->add_control(
			'show_loop_icon_style',
			[
				'label'       => __( 'ON/OFF Icon Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_control(
            'loop_icon_bgcolor',
            [
                'label' => __('Icon Background Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .testimonial-block_two-quote' => 'background-color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_icon_color',
            [
                'label' => __('Icon Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .testimonial-block_two-quote' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		$this->end_controls_section();
		
	}
	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');	
			
        $paged = chartio_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;
		$this->add_render_attribute( 'wrapper', 'class', 'templatepath-chartio' );
		
		$args = array(
			'post_type'      => 'testimonials',
			'posts_per_page' => chartio_set( $settings, 'query_number' ),
			'orderby'        => chartio_set( $settings, 'query_orderby' ),
			'order'          => chartio_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		if( chartio_set( $settings, 'query_category' ) ) $args['testimonials_cat'] = chartio_set( $settings, 'query_category' );
		$query = new \WP_Query( $args );
		if ( $query->have_posts() ) 
		{ 
	?>
  	
    <?php if($settings['testimonials_style'] == 4 ): ?>
    
    <!-- Testimonial Three -->
	<section class="testimonial-three p-0 m-0">        
        <!-- Carousel Column -->
        <div class="carousel-column">
            <div class="inner-column">
                <div class="testimonial-carousel_two swiper-container">
                    <div class="swiper-wrapper">
                        <?php 
							while ( $query->have_posts() ) : $query->the_post();
						?>
						<?php $chartio_testimonials_meta = get_post_meta( get_the_ID(), 'chartio_meta_testimonials', true );?>
                        <!-- Slide -->
                        <div class="swiper-slide">
                            <!-- Testimonial Block Three -->
                            <div class="testimonial-block_three">
                                <div class="testimonial-block_three-inner">
                                    <div class="testimonial-block_three-quote">
                                        <i class="fas fa-quote-left fa-fw"></i>
                                    </div>
                                    <div class="testimonial-block_three-text chartio-testi-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                                    <div class="testimonial-block_three-author_outer">
                                        <div class="testimonial-block_three-author">
                                            <span class="author-image">
                                                <?php the_post_thumbnail('chartio_84x84'); ?>
                                            </span>
                                            <strong class="chartio-testi-author"><?php echo wp_kses($chartio_testimonials_meta['testi_author_name'], true ); ?></strong>
                                            <div class="chartio-testi-designation"><?php echo wp_kses($chartio_testimonials_meta['test_designation'], true ); ?></div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php endwhile; ?>
                    </div>
                    
                    <div class="testimonial-three_pagination"></div>                                
                    
                </div>
            </div>
        </div>
	</section>
	<!-- End Testimonial Three -->
	
	<?php elseif($settings['testimonials_style'] == 3 ): ?>
    
    <!-- Testimonial One -->
	<section class="testimonial-one style-two chartio-testi-section">
		<div class="testimonial-one-image" <?php if($settings['image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['image']['id'])); ?>)"<?php } ?>></div>
		<div class="auto-container">
			<?php if($settings['title'] || $settings['text']){ ?>
            <!-- Sec Title -->
            <div class="sec-title_two light centered">
                <?php if($settings['title']){ ?><div class="sec-title_two-title tx-split-text split-in-up sec-title__tagline"><?php echo wp_kses($settings['title'], true);?></div><?php } ?>
                <?php if($settings['text']){ ?><h2 class="sec-title_two-heading tx-split-text split-in-up sec-title__title"><?php echo wp_kses($settings['text'], true);?></h2><?php } ?>
            </div>
            <?php } ?>
			<div class="inner-container">
				<div class="row clearfix">
					<!-- Column -->
					<div class="column col-lg-7 col-md-12 col-sm-12">
						<div class="testimonial__slider-wrap pos-rel chartio-testi-grid">
							<div class="testimonial__active swiper-container">
								<div class="swiper-wrapper">
									<?php 
										while ( $query->have_posts() ) : $query->the_post();
									?>
                                    <?php $chartio_testimonials_meta = get_post_meta( get_the_ID(), 'chartio_meta_testimonials', true );?>
                                    <div class="testimonial__single swiper-slide">
										<div class="testimonial__single-inner">
											<h2 class="chartio-testi-title"><?php the_title(); ?></h2>
											<p class="chartio-testi-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></p>
											<div class="info">
												<h5 class="chartio-testi-author"><?php echo wp_kses($chartio_testimonials_meta['testi_author_name'], true ); ?></h5>
												<span class="chartio-testi-designation"><?php echo wp_kses($chartio_testimonials_meta['test_designation'], true ); ?></span>
											</div>
										</div>                                        
									</div>
                                    <?php endwhile; ?>
								</div>
                                                                                                
                                <div class="tx-pagination swiper-pagination"></div>                                
								
							</div>
							<div class="testimonial__nav swiper-container">
								<div class="swiper-wrapper">
									<?php 
										while ( $query->have_posts() ) : $query->the_post();
									?>
                                    <div class="testimonial__nav-thumb swiper-slide">
										<?php the_post_thumbnail('chartio_157x155'); ?>
									</div>
                                    <?php endwhile; ?>
								</div>
								
							</div>
						</div>
					</div>
					<!-- Column -->
					<div class="column col-lg-5 col-md-12 col-sm-12">
						<div class="testimonial-one_counter">
							<div class="testimonial-one_counter-inner" style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['pattern_image']['id'])); ?>)">
								<?php foreach($settings['funfact'] as $key => $item):?>
								<!-- Counter Column -->
								<div class="testimonial-one_counter-content">
									<div class="testimonial-one_counter-number"><span class="odometer" data-count="<?php echo esc_attr($item['counter_stop2']);?>"></span><?php echo esc_attr($item['alphabet_letter2']);?></div>
									<div class="testimonial-one_text"><?php echo wp_kses($item['block_title'], true);?></div>
								</div>
								<?php endforeach;?>
							</div>
						</div>
					</div>
				</div>
				
			</div>
		</div>
	</section>
	<!-- End Testimonial One -->
    
    <?php elseif($settings['testimonials_style'] == 2 ): ?>
    
    <div class="testimonial-two">
        <div class="testimonial-carousel swiper-container">
            <div class="swiper-wrapper">
                <?php 
					while ( $query->have_posts() ) : $query->the_post();
				?>
                <?php $chartio_testimonials_meta = get_post_meta( get_the_ID(), 'chartio_meta_testimonials', true );?>
                <!-- Slide -->
                <div class="swiper-slide">
                    <!-- Testimonial Block One -->
                    <div class="testimonial-block_one">
                        <div class="testimonial-block_one-inner">
                            <div class="testimonial-block_one-pattern" style="background-image:url(<?php echo esc_url(get_template_directory_uri());?>/assets/images/background/pattern-6.png)"></div>
                            <div class="testimonial-block_one-pattern_two" style="background-image:url(<?php echo esc_url(get_template_directory_uri());?>/assets/images/background/pattern-7.png)"></div>
                            <div class="testimonial-block_one-content">
                                <div class="testimonial-block_one-author">
                                    <?php the_post_thumbnail('chartio_168x168'); ?>
                                </div>
                                <h5 class="testimonial-block_one-title chartio-testi-author"><?php echo wp_kses($chartio_testimonials_meta['testi_author_name'], true ); ?></h5>
                                <div class="testimonial-block_one-text chartio-testi-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?> </div>
                                <?php
									$icons = $chartio_testimonials_meta['testi_social_profile'];
									if ( ! empty( $icons ) ) :								
								?>
								<!-- Socials Box -->
                                <div class="testimonial-block_one-social chartio-icon-box">
									<?php foreach ( $icons as $h_icon ) {
					
										$icon_class = explode( '-', chartio_set( $h_icon, 'icon' ) ); 
									?>
									<a href="<?php echo esc_url(chartio_set( $h_icon, 'url' )); ?>" <?php if( chartio_set( $h_icon, 'background' ) || chartio_set( $h_icon, 'color' ) ):?>style="background-color:<?php echo esc_attr(chartio_set( $h_icon, 'background' )); ?>; color: <?php echo esc_attr(chartio_set( $h_icon, 'color' )); ?>"<?php endif;?>><i class="fab <?php echo esc_attr( chartio_set( $h_icon, 'icon' ) ); ?>"></i></a>
									<?php } ?>
								 </div>
								 <?php endif; ?>                                
                            </div>
                        </div>
                    </div>
                </div>
                <?php endwhile; ?>
    		</div>
        </div>
       
        <div class="testimonial-two-arrow">
            <!-- If we need navigation buttons -->
            <div class="testimonial-two-button-prev fas fa-arrow-left fa-fw"></div>
            <div class="testimonial-two-button-next fas fa-arrow-right fa-fw"></div>
        </div>
        
        
    </div>
    
    <?php else: ?>
    
    <!-- Testimonial One -->
	<section class="testimonial-one chartio-testi-section">
		<div class="testimonial-one-image" <?php if($settings['image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['image']['id'])); ?>)"<?php } ?>></div>
		<div class="auto-container">
			<?php if($settings['title'] || $settings['text']){ ?>
            <!-- Sec Title -->
            <div class="sec-title centered light">
                <?php if($settings['title']){ ?><div class="sec-title_title tx-split-text split-in-up sec-title__tagline"><?php echo wp_kses($settings['title'], true);?></div><?php } ?>
                <?php if($settings['text']){ ?><h2 class="sec-title_heading tx-split-text split-in-up sec-title__title"><?php echo wp_kses($settings['text'], true);?></h2><?php } ?>
            </div>
            <?php } ?>
			<div class="inner-container">
				<div class="row clearfix">
					<!-- Column -->
					<div class="column col-lg-7 col-md-12 col-sm-12">
						<div class="testimonial__slider-wrap pos-rel chartio-testi-grid">
							<div class="testimonial__active swiper-container">
								<div class="swiper-wrapper">
									<?php 
										while ( $query->have_posts() ) : $query->the_post();
									?>
                                    <?php $chartio_testimonials_meta = get_post_meta( get_the_ID(), 'chartio_meta_testimonials', true );?>
                                    <div class="testimonial__single swiper-slide">
										<div class="testimonial__single-inner">
											<h2 class="chartio-testi-title"><?php the_title(); ?></h2>
											<p class="chartio-testi-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></p>
											<div class="info">
												<h5 class="chartio-testi-author"><?php echo wp_kses($chartio_testimonials_meta['testi_author_name'], true ); ?></h5>
												<span class="chartio-testi-designation"><?php echo wp_kses($chartio_testimonials_meta['test_designation'], true ); ?></span>
											</div>
										</div>                                        
									</div>
                                    <?php endwhile; ?>
								</div>
								                                                 
                                <div class="tx-pagination swiper-pagination"></div>                                
                                
							</div>
							<div class="testimonial__nav swiper-container">
								<div class="swiper-wrapper">
									<?php 
										while ( $query->have_posts() ) : $query->the_post();
									?>
                                    <div class="testimonial__nav-thumb swiper-slide">
										<?php the_post_thumbnail('chartio_157x155'); ?>
									</div>
                                    <?php endwhile; ?>
								</div>
								
							</div>
						</div>
					</div>
					<!-- Column -->
					<div class="column col-lg-5 col-md-12 col-sm-12">
						<div class="testimonial-one_counter">
							<div class="testimonial-one_counter-inner" style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['pattern_image']['id'])); ?>)">
								<?php foreach($settings['funfact'] as $key => $item):?>
								<!-- Counter Column -->
								<div class="testimonial-one_counter-content">
									<div class="testimonial-one_counter-number"><span class="odometer" data-count="<?php echo esc_attr($item['counter_stop2']);?>"></span><?php echo esc_attr($item['alphabet_letter2']);?></div>
									<div class="testimonial-one_text"><?php echo wp_kses($item['block_title'], true);?></div>
								</div>
								<?php endforeach;?>
							</div>
						</div>
					</div>
				</div>
				
			</div>
		</div>
	</section>
	<!-- End Testimonial One -->
      
      <?php endif; ?>  
      <?php }
		wp_reset_postdata();
	}
}