<?php
namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Testimonials_Grid extends Widget_Base {
	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	 
	public function get_name() {
		return 'chartio_testimonials_grid';
	}
	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Chartio Testimonials Grid', 'chartio' );
	}
	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-testimonial';
	}
	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'chartio' ];
	}	
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'testimonials_grid',
			[
				'label' => esc_html__( 'Testimonials Grid', 'chartio' ),
			]
		);
		
		$this->add_control(
			'testimonials_style',
			[
				'label'   => esc_html__( 'Layout Style', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'chartio'),
					'2' => esc_html__( 'Style Two ', 'chartio'),
				),
			]
		);
		
		$this->add_control(
			'col_grid',
			[
				'label'   => esc_html__( 'Choose Column', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'default',
				'options' => array(
					'default'  => esc_html__( 'Default', 'chartio' ),
					'one' => esc_html__( 'One Column Grid ', 'chartio'),
					'two'  => esc_html__( 'Two Column Grid', 'chartio' ),
					'three'  => esc_html__( 'Three Column Grid', 'chartio' ),
					'four'  => esc_html__( 'Four Column Grid', 'chartio' ),
					'five'  => esc_html__( 'Six Column Grid', 'chartio' ),
				),
			]
		);	
			
		$this->add_control(
            'text_limit',
            [
                'label'   => esc_html__( 'Text Limit', 'chartio' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 25,
                'min'     => 1,
                'max'     => 100,
                'step'    => 1,
            ]
        );
		$this->add_control(
			'query_number',
			[
				'label'   => esc_html__( 'Number of post', 'chartio' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 4,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'chartio' ),
					'title'      => esc_html__( 'Title', 'chartio' ),
					'menu_order' => esc_html__( 'Menu Order', 'chartio' ),
					'rand'       => esc_html__( 'Random', 'chartio' ),
				),
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESC' => esc_html__( 'DESC', 'chartio' ),
					'ASC'  => esc_html__( 'ASC', 'chartio' ),
				),
			]
		);
		$this->add_control(
            'query_category', 
			[
			  'type' => Controls_Manager::SELECT,
			  'label' => esc_html__('Category', 'chartio'),
			  'label_block' => true,
			  'options' => get_testimonials_categories()
			]
		);		
		$this->end_controls_section();
		
		/** Style Tab **/
		$this->register_style_background_controls();
    }
	
	/************************************************************************
								Tab Style Start
	*************************************************************************/
	
	protected function register_style_background_controls()
	{
		
		/**Loop Style**/
		$this->start_controls_section(
			'loop_style',
			[
				'label' => esc_html__('LOOP CONTENT STYLE SETTING', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		//Loop Background Color Style
		$this->add_control(
			'show_loop_loop_style',
			[
				'label'       => __( 'ON/OFF  Loop Background Color Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);		
		$this->add_control(
            'loop_loop_bgcolor',
            [
                'label' => __('Loop Background Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-testi-grid' => 'background-color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_loop_style'    => 'yes',
				]
            ]
        );
		//Content Style
		$this->add_control(
			'show_loop_content_style',
			[
				'label'       => __( 'ON/OFF  Content Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_content_typography',
                'label' => __('Content Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .chartio-testi-text',                 
                'separator' => 'before',
				'condition'             => [
					'show_loop_content_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_content_color',
            [
                'label' => __('Content Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-testi-text' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_content_style'    => 'yes',
				]
            ]
        );
		//Author Name
		$this->add_control(
			'show_loop_author_style',
			[
				'label'       => __( 'ON/OFF  Author Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_author_typography',
                'label' => __('Author Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .chartio-testi-author',                 
                'separator' => 'before',
				'condition'             => [
					'show_loop_author_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_author_color',
            [
                'label' => __('Author Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-testi-author' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_author_style'    => 'yes',
				]
            ]
        );
		//Designation
		$this->add_control(
			'show_loop_designation_style',
			[
				'label'       => __( 'ON/OFF  Designation Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'loop_designation_typography',
                'label' => __('Designation Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .chartio-testi-designation',                 
                'separator' => 'before',
				'condition'             => [
					'show_loop_designation_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_designation_color',
            [
                'label' => __('Designation Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .chartio-testi-designation' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_designation_style'    => 'yes',
				]
            ]
        );		
		//Icon Style
		$this->add_control(
			'show_loop_icon_style',
			[
				'label'       => __( 'ON/OFF Icon Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_control(
            'loop_icon_bgcolor',
            [
                'label' => __('Icon Background Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .testimonial-block_two-quote' => 'background-color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'loop_icon_color',
            [
                'label' => __('Icon Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .testimonial-block_two-quote' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_loop_icon_style'    => 'yes',
				]
            ]
        );
		$this->end_controls_section();
		
	}
	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
		
		$grid_col = $settings[ 'col_grid' ];
		if( $grid_col == 'one' ){
			$classes = 'col-lg-12 col-md-12 col-sm-12';
		}elseif( $grid_col == 'two' ){
			$classes = 'col-lg-6 col-md-12 col-sm-12';
		}elseif( $grid_col == 'three' ){
			$classes = 'col-lg-4 col-md-6 col-sm-12';
		}elseif( $grid_col == 'four' ){
			$classes = 'col-lg-3 col-md-6 col-sm-12';
		}elseif( $grid_col == 'five' ){
			$classes = 'col-lg-2 col-md-6 col-sm-12';
		}else{
			$classes = 'col-lg-4 col-md-6 col-sm-12';
		}
		
        $paged = chartio_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;
		$this->add_render_attribute( 'wrapper', 'class', 'templatepath-chartio' );
		
		$args = array(
			'post_type'      => 'testimonials',
			'posts_per_page' => chartio_set( $settings, 'query_number' ),
			'orderby'        => chartio_set( $settings, 'query_orderby' ),
			'order'          => chartio_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		if( chartio_set( $settings, 'query_category' ) ) $args['testimonials_cat'] = chartio_set( $settings, 'query_category' );
		$query = new \WP_Query( $args );
		if ( $query->have_posts() ) 
		{ 
	?>
    
  	<?php if($settings['testimonials_style'] == 2 ): ?>
    <div class="volunter-one chartio-testi-section p-0 m-0">
        <div class="row clearfix">
            <?php 
                while ( $query->have_posts() ) : $query->the_post();
            ?>
            <?php $chartio_testimonials_meta = get_post_meta( get_the_ID(), 'chartio_meta_testimonials', true );?>
            <!-- Testimonial Block One -->
            <div class="testimonial-block_one <?php echo esc_attr( $classes );?>">
                <div class="testimonial-block_one-inner">
                    <div class="testimonial-block_one-pattern" style="background-image:url(<?php echo esc_url(get_template_directory_uri());?>/assets/images/background/pattern-6.png)"></div>
                    <div class="testimonial-block_one-pattern_two" style="background-image:url(<?php echo esc_url(get_template_directory_uri());?>/assets/images/background/pattern-7.png)"></div>
                    <div class="testimonial-block_one-content">
                        <div class="testimonial-block_one-author">
                            <?php the_post_thumbnail('chartio_168x168'); ?>
                        </div>
                        <h5 class="testimonial-block_one-title chartio-testi-author"><?php echo wp_kses($chartio_testimonials_meta['testi_author_name'], true ); ?></h5>
                        <div class="testimonial-block_one-text chartio-testi-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?> </div>
                        <?php
                            $icons = $chartio_testimonials_meta['testi_social_profile'];
                            if ( ! empty( $icons ) ) :								
                        ?>
                        <!-- Socials Box -->
                        <div class="testimonial-block_one-social chartio-icon-box">
                            <?php foreach ( $icons as $h_icon ) {
            
                                $icon_class = explode( '-', chartio_set( $h_icon, 'icon' ) ); 
                            ?>
                            <a href="<?php echo esc_url(chartio_set( $h_icon, 'url' )); ?>" <?php if( chartio_set( $h_icon, 'background' ) || chartio_set( $h_icon, 'color' ) ):?>style="background-color:<?php echo esc_attr(chartio_set( $h_icon, 'background' )); ?>; color: <?php echo esc_attr(chartio_set( $h_icon, 'color' )); ?>"<?php endif;?>><i class="fab <?php echo esc_attr( chartio_set( $h_icon, 'icon' ) ); ?>"></i></a>
                            <?php } ?>
                         </div>
                         <?php endif; ?>
                    </div>
                </div>
            </div>
            <?php endwhile; ?>
        </div>
    </div>
    
    <?php else: ?>  
      
    <!-- Testimonial One -->
	<div class="chartio-testi-section">
    	<div class="row clearfix">
			<?php 
                while ( $query->have_posts() ) : $query->the_post();
            ?>
            <?php $chartio_testimonials_meta = get_post_meta( get_the_ID(), 'chartio_meta_testimonials', true );?>
            <!-- Testimonial Block Two -->
            <div class="testimonial-block_two <?php echo esc_attr( $classes );?>">
                <div class="testimonial-block_two-inner chartio-testi-grid">
                    <div class="testimonial-block_two-quote">
                        <i class="fas fa-quote-right fa-fw"></i>
                    </div>
                    <div class="testimonial-block_two-text chartio-testi-text"><?php echo wp_kses(wp_trim_words(get_the_content(), $settings['text_limit']), true); ?></div>
                    <h5 class="testimonial-block_two-title class="chartio-testi-author">
                        <?php echo wp_kses($chartio_testimonials_meta['testi_author_name'], true ); ?>
                        <span class="chartio-testi-designation"><?php echo wp_kses($chartio_testimonials_meta['test_designation'], true ); ?></span>
                    </h5>
                </div>
            </div>
            <?php endwhile; ?>
    	</div>
    </div>
    
    <?php endif; ?>      
      <?php }
		wp_reset_postdata();
	}
}