<?php
namespace CHARTIOPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Who_We_Are extends Widget_Base {
	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'chartio_who_we_are';
	}
	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Chartio Who We Are', 'chartio' );
	}
	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-library-open';
	}
	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'chartio' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'who_we_are',
			[
				'label' => esc_html__( 'Who We Are', 'chartio' ),
			]
		);
		
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'chartio' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'chartio'),
					'2' => esc_html__( 'Style Two ', 'chartio'),
					'3' => esc_html__( 'Style Three ', 'chartio'),
					'4' => esc_html__( 'Style Four ', 'chartio'),
					'5' => esc_html__( 'Style Five ', 'chartio'),
				),
			]
		);
		
		$this->add_control(
			'bg_image',
			[
			  	'label' => __( 'BG Image', 'chartio' ),
			  	'type' => Controls_Manager::MEDIA,
			  	'label_block' => true,
			  	'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
	    );
		$this->add_control(
			'pattern_image',
			[
			  	'label' => __( 'Pattern Image', 'chartio' ),
			  	'type' => Controls_Manager::MEDIA,
			  	'label_block' => true,
				'condition' => [ 'layout_control' => ['1', '2', '4', '5'], ],
			  	'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
	    );
		$this->add_control(
			'pattern_image2',
			[
			  	'label' => __( 'Pattern Image Two', 'chartio' ),
			  	'type' => Controls_Manager::MEDIA,
			  	'label_block' => true,
				'condition' => [ 'layout_control' => ['1', '4'], ],
			  	'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
	    );
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Small Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Small Title Here', 'chartio' ),
			]
		);
		$this->add_control(		
			 'title',
			[
				'label'       => __( 'Title', 'chartio' ),				
                'type'        => Controls_Manager::TEXTAREA,				
				'dynamic'     => [				
					'active' => true,
				],				
				'placeholder' => __( 'Enter your title', 'chartio' ),
			]
		);
		$this->add_control(		
			 'text',
			[
				'label'       => __( 'Description', 'chartio' ),				
                'type'        => Controls_Manager::TEXTAREA,				
				'dynamic'     => [				
					'active' => true,
				],				
				'placeholder' => __( 'Enter your text', 'chartio' ),
			]
		);
		$this->add_control(		
			 'no_text',
			[
				'label'       => __( 'No. of Homeless Children', 'chartio' ),				
                'type'        => Controls_Manager::TEXT,
				'label_block' => true,				
				'dynamic'     => [				
					'active' => true,
				],				
				'placeholder' => __( 'Enter No. of Homeless Children', 'chartio' ),
			]
		);
		$this->add_control(
			'btn_title',
			[
				'label'       => __( 'Button Title', 'chartio' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title Here', 'chartio' ),
			]
		);
		$this->add_control(
            'btn_link',
			[
				'label' => __( 'Button Url', 'chartio' ),
				'type' => Controls_Manager::URL,
				'label_block' => true, 
				'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);
		
		$this->add_control(		
			 'right_title',
			[
				'label'       => __( 'Right Title', 'chartio' ),				
                'type'        => Controls_Manager::TEXT,	
				'label_block' => true, 			
				'dynamic'     => [				
					'active' => true,
				],				
				'placeholder' => __( 'Enter your right title', 'chartio' ),
			]
		);
		$this->add_control(		
			 'right_text',
			[
				'label'       => __( 'Right Text', 'chartio' ),				
                'type'        => Controls_Manager::TEXTAREA,
				'label_block' => true, 
				'dynamic'     => [				
					'active' => true,
				],				
				'placeholder' => __( 'Enter your text', 'chartio' ),
			]
		);
		
		$this->add_control(		
			 'donation',
			[
				'label'       => __( 'Donation Title', 'chartio' ),				
                'type'        => Controls_Manager::TEXT,
				'label_block' => true,			
				'dynamic'     => [				
					'active' => true,
				],				
				'placeholder' => __( 'Enter your Donation title', 'chartio' ),
			]
		);
		//Our Slider		
		$repeater = new Repeater();		
		$repeater->add_control(
			'counter_stop',
			[
				'label' => esc_html__('Counter Value', 'chartio'),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Counter Value', 'chartio' ),
			]
		);
		$this->add_control(
			'slides',
			[
				'label'                 => __('Add Amount Item', 'chartio'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
			]
		);
		
		$this->add_control(		
			 'form_title',
			[
				'label'       => __( 'Donation Form Title', 'chartio' ),				
                'type'        => Controls_Manager::TEXT,
				'label_block' => true,			
				'dynamic'     => [				
					'active' => true,
				],				
				'placeholder' => __( 'Enter your Donation Form Title', 'chartio' ),
			]
		);	
		
		$this->add_control(
            'cf7_shortocde',
            [
                'label' => esc_html__('Select Contact Form 7', 'chartio'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' => get_contact_form_7_list(),
            ]
        );
		
		$this->end_controls_section();
		
		
		
		/** Style Tab **/
		$this->register_style_background_controls();
    }
	
	/************************************************************************
								Tab Style Start
	*************************************************************************/
	
	protected function register_style_background_controls()
	{	
		
		/**Sub Title Style**/
		$this->start_controls_section(
			'sub_title_style',
			[
				'label' => esc_html__('SUB TITLE STYLE SETTING', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'show_sub_title_style',
			[
				'label'       => __( 'ON/OFF Sub Title Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'sub_title_typography',
                'label' => __('Sub Title Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .sec-title__tagline',                 
                'separator' => 'before',
				'condition'             => [
					'show_sub_title_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'sub_title_color',
            [
                'label' => __('Sub Title Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .sec-title__tagline' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_sub_title_style'    => 'yes',
				]
            ]
        );
		$this->end_controls_section();
		
		/**Title Style**/
		$this->start_controls_section(
			'title_style',
			[
				'label' => esc_html__('TITLE STYLE SETTING', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'show_title_style',
			[
				'label'       => __( 'ON/OFF  Title Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => __('Title Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .sec-title__title',                 
                'separator' => 'before',
				'condition'             => [
					'show_title_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'title_color',
            [
                'label' => __('Title Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .sec-title__title' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_title_style'    => 'yes',
				]
            ]
        );
		$this->end_controls_section();
		
		/**Content Style**/
		$this->start_controls_section(
			'content_style',
			[
				'label' => esc_html__('CONTENT STYLE SETTING', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'show_content_style',
			[
				'label'       => __( 'ON/OFF  Content Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'label' => __('Content Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .sec-title_two-text',                 
                'separator' => 'before',
				'condition'             => [
					'show_content_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'content_color',
            [
                'label' => __('Content Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .sec-title_two-text' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_content_style'    => 'yes',
				]
            ]
        );
		$this->end_controls_section();
		
		/**Author Style**/
		$this->start_controls_section(
			'author_style',
			[
				'label' => esc_html__('AUTHOR SECTION STYLE SETTING', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'show_author_style',
			[
				'label'       => __( 'ON/OFF  Author Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$this->add_control(
            'border_color',
            [
                'label' => __('Border Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .about-five__author' => 'border-color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_author_style'    => 'yes',
				]
            ]
        );
		//Author Name
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'author_name_typography',
                'label' => __('Author Name Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .about-five__author__name',                 
                'separator' => 'before',
				'condition'             => [
					'show_author_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'author_name_color',
            [
                'label' => __('Author Name Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .about-five__author__name' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_author_style'    => 'yes',
				]
            ]
        );
		//Author Designation
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'author_designaion_typography',
                'label' => __('Author Designation Typography', 'chartio'),
                'selector' => 
                    '{{WRAPPER}} .about-five__author__designation',                 
                'separator' => 'before',
				'condition'             => [
					'show_author_style'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'author_designaion_color',
            [
                'label' => __('Author Designation Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .about-five__author__designation' => 'color: {{VALUE}}'
                ],
                'separator' => 'before',
				'condition'             => [
					'show_author_style'    => 'yes',
				]
            ]
        );
		$this->end_controls_section();
		
		/**Button Style One**/
		$this->start_controls_section(
			'button_style',
			[
				'label' => esc_html__('LEARN MORE BUTTON STYLE SETTING', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'show_btn_style',
			[
				'label'       => __( 'ON/OFF Button Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_control(
			'yt_btn_background',
			[
				'label'                 => __( 'Button Background', 'chartio' ),
				'type'                  => Controls_Manager::HEADING,
				'separator'             => 'before',
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'btn_bgtype',
				'label' => __( 'Button Background', 'chartio' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => 
					'{{WRAPPER}} .thm-btn--three',				
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_control(
			'hover_background',
			[
				'label'                 => __( 'Button Hover Background', 'chartio' ),
				'type'                  => Controls_Manager::HEADING,
				'separator'             => 'before',
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'btn_hover_bg_bgtype',
				'label' => __( 'Button Hover Background', 'chartio' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => 
					'{{WRAPPER}} .thm-btn.thm-btn--three:hover:before',				
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_control(
			'show_border_radius',
			[
				'label'       => __( 'ON/OFF Button Radius Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_control(
            'btn_border_radius',
            [
                'label' => esc_html__('Border Radius', 'chartio'),
                'type' => Controls_Manager::DIMENSIONS,
                'separator' => 'before',
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .thm-btn.thm-btn--three' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
				'condition'             => [
					'show_border_radius'    => 'yes',
				]
            ]
        );
		$this->add_control(
			'show_border_type',
			[
				'label'       => __( 'ON/OFF Border Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'btn_border_type',
                'selector' => 
					'{{WRAPPER}} .thm-btn.thm-btn--three',				
				'separator' => 'before',
				'condition'             => [
					'show_border_type'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'btn_border_hover_color',
            [
                'label' => __('Button Border Hover Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .thm-btn.thm-btn--three:hover' => 'border-color: {{VALUE}}!important',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_border_type'    => 'yes',
				]
            ]
        );
		$this->add_control(
			'show_box_shadow',
			[
				'label'       => __( 'ON/OFF Box Shadow Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'border_box_shadow',
                'selector' => 
					'{{WRAPPER}} .thm-btn.thm-btn--three',				
				'separator' => 'before',
				'condition'             => [
					'show_box_shadow'    => 'yes',
				]
            ]
        );
		$this->add_control(
			'show_btn_padding',
			[
				'label'       => __( 'ON/OFF Padding Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_responsive_control(
            'btn_padding',
            [
                'label'              => __( 'Padding', 'chartio' ),
                'type'               => Controls_Manager::DIMENSIONS,
                'size_units'         => [ 'px', 'em', '%' ],
                'selectors'          => [
                    '{{WRAPPER}} .thm-btn.thm-btn--three' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
				
                'frontend_available' => true,
				'condition'             => [
					'show_btn_padding'    => 'yes',
				]
            ]
        );
		$this->add_control(
			'show_typo_color',
			[
				'label'       => __( 'ON/OFF Typography and Color Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_title_typography',
                'label' => __('Button Text Typography', 'chartio'),
                'selector' => 
					'{{WRAPPER}} .thm-btn.thm-btn--three',				
                'separator' => 'before',
				'condition'             => [
					'show_typo_color'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'btn_title_color',
            [
                'label' => __('Button Text Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .thm-btn.thm-btn--three' => 'color: {{VALUE}}!important',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_typo_color'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'btn_title_hover_color',
            [
                'label' => __('Button Text Hover Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .thm-btn.thm-btn--three:hover' => 'color: {{VALUE}}!important',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_typo_color'    => 'yes',
				]
            ]
        );
		$this->end_controls_section();
		
		/**Button Style Two**/
		$this->start_controls_section(
			'button_style2',
			[
				'label' => esc_html__('OUR SERVICES BUTTON STYLE SETTING', 'chartio'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]

		);
		$this->add_control(
			'show_btn_style2',
			[
				'label'       => __( 'ON/OFF Button Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);	
		$this->add_control(
			'yt_btn_background2',
			[
				'label'                 => __( 'Button Background', 'chartio' ),
				'type'                  => Controls_Manager::HEADING,
				'separator'             => 'before',
				'condition'             => [
					'show_btn_style2'    => 'yes',
				]
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'btn_bgtype2',
				'label' => __( 'Button Background', 'chartio' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => 
					'{{WRAPPER}} .thm-btn--two',				
				'condition'             => [
					'show_btn_style2'    => 'yes',
				]
			]
		);
		$this->add_control(
			'hover_background2',
			[
				'label'                 => __( 'Button Hover Background', 'chartio' ),
				'type'                  => Controls_Manager::HEADING,
				'separator'             => 'before',
				'condition'             => [
					'show_btn_style'    => 'yes',
				]
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'btn_hover_bg_bgtype2',
				'label' => __( 'Button Hover Background', 'chartio' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => 
					'{{WRAPPER}} .thm-btn--two:hover',				
				'condition'             => [
					'show_btn_style2'    => 'yes',
				]
			]
		);
		$this->add_control(
			'show_border_radius2',
			[
				'label'       => __( 'ON/OFF Button Radius Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style2'    => 'yes',
				]
			]
		);
		$this->add_control(
            'btn_border_radius2',
            [
                'label' => esc_html__('Border Radius', 'chartio'),
                'type' => Controls_Manager::DIMENSIONS,
                'separator' => 'before',
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .thm-btn.thm-btn--two' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
				'condition'             => [
					'show_border_radius2'    => 'yes',
				]
            ]
        );
		$this->add_control(
			'show_border_type2',
			[
				'label'       => __( 'ON/OFF Border Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style2'    => 'yes',
				]
			]
		);
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'btn_border_type2',
                'selector' => 
					'{{WRAPPER}} .thm-btn.thm-btn--two',				
				'separator' => 'before',
				'condition'             => [
					'show_border_type2'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'btn_border_hover_color2',
            [
                'label' => __('Button Border Hover Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .thm-btn.thm-btn--two:hover' => 'border-color: {{VALUE}}!important',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_border_type2'    => 'yes',
				]
            ]
        );
		$this->add_control(
			'show_box_shadow2',
			[
				'label'       => __( 'ON/OFF Box Shadow Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style2'    => 'yes',
				]
			]
		);
		$this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'border_box_shadow2',
                'selector' => 
					'{{WRAPPER}} .thm-btn.thm-btn--two',				
				'separator' => 'before',
				'condition'             => [
					'show_box_shadow2'    => 'yes',
				]
            ]
        );
		$this->add_control(
			'show_btn_padding2',
			[
				'label'       => __( 'ON/OFF Padding Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style2'    => 'yes',
				]
			]
		);
		$this->add_responsive_control(
            'btn_padding2',
            [
                'label'              => __( 'Padding', 'chartio' ),
                'type'               => Controls_Manager::DIMENSIONS,
                'size_units'         => [ 'px', 'em', '%' ],
                'selectors'          => [
                    '{{WRAPPER}} .thm-btn.thm-btn--two' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
				
                'frontend_available' => true,
				'condition'             => [
					'show_btn_padding2'    => 'yes',
				]
            ]
        );
		$this->add_control(
			'show_typo_color2',
			[
				'label'       => __( 'ON/OFF Typography and Color Style', 'chartio' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'chartio' ),
				'label_off' => esc_html__( 'Hide', 'chartio' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'             => [
					'show_btn_style2'    => 'yes',
				]
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_title_typography2',
                'label' => __('Button Text Typography', 'chartio'),
                'selector' => 
					'{{WRAPPER}} .thm-btn.thm-btn--two',				
                'separator' => 'before',
				'condition'             => [
					'show_typo_color2'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'btn_title_color2',
            [
                'label' => __('Button Text Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .thm-btn.thm-btn--two' => 'color: {{VALUE}}!important',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_typo_color2'    => 'yes',
				]
            ]
        );
		$this->add_control(
            'btn_title_hover_color2',
            [
                'label' => __('Button Text Hover Color', 'chartio'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .thm-btn.thm-btn--two:hover' => 'color: {{VALUE}}!important',
                ],
                'separator' => 'before',
				'condition'             => [
					'show_typo_color2'  => 'yes',
				]
            ]
        );
		$this->end_controls_section();
	}
	/**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post'); 
	?>
	
    <?php if($settings['layout_control'] == 5): ?>
    
    <!-- Mission One -->
	<section class="mission-one style-three" <?php if($settings['bg_image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['bg_image']['id'])); ?>)"<?php } ?>>
		<div class="auto-container">
			<div class="row clearfix">
				<!-- Image Column -->
				<div class="mission-one_title-column col-lg-6 col-md-12 col-sm-12">
					<div class="mission-one_title-inner">
						<?php if($settings['subtitle'] || $settings['title'] || $settings['text']){ ?>
                        <!-- Sec Title Two / Light -->
						<div class="sec-title_two light">
							<?php if($settings['subtitle']){ ?><div class="sec-title__tagline sec-title_two-title"><?php echo wp_kses($settings['subtitle'], true); ?></div><?php } ?>
							<?php if($settings['title']){ ?><h2 class="sec-title__title sec-title_two-heading"><?php echo wp_kses($settings['title'], true); ?></h2><?php } ?>
							<?php if($settings['text']){ ?><div class="sec-title_two-text"><?php echo wp_kses($settings['text'], true); ?></div><?php } ?>
						</div>
                        <?php } ?>
						<?php if($settings['no_text']){ ?><div class="mission-one_homeless"><?php echo wp_kses($settings['no_text'], true); ?></div><?php } ?>
						<?php if($settings['btn_title']){ ?>
                        <div class="mission-one_button">
							<a href="<?php echo esc_url($settings['btn_link']['url']);?>" class="thm-btn thm-btn--three theme-btn btn-style-three">
								<span class="btn-wrap">
                                	<span class="text-one"><?php echo wp_kses($settings['btn_title'], true);?> <i class="fas fa-arrow-right fa-fw"></i></span>
                    				<span class="text-two"><?php echo wp_kses($settings['btn_title'], true);?> <i class="fas fa-arrow-right fa-fw"></i></span>
								</span>
							</a>
						</div>
                        <?php } ?>
					</div>
				</div>
				<!-- Content Column -->
				<div class="mission-one_donate-column col-lg-6 col-md-12 col-sm-12">
					<div class="mission-one_circle" <?php if($settings['pattern_image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['pattern_image']['id'])); ?>)"<?php } ?>></div>
					<div class="mission-one_donate-inner wow fadeInRight" data-wow-delay="0ms" data-wow-duration="1500ms">
						<?php if($settings['right_title'] || $settings['right_text']){ ?>
                        <div class="mission-one_title-box">
							<?php if($settings['right_title']){ ?><h3 class="mission-one_title-heading"><?php echo wp_kses($settings['right_title'], true); ?></h3><?php } ?>
							<?php if($settings['right_text']){ ?><div class="mission-one_text"><?php echo wp_kses($settings['right_text'], true); ?></div><?php } ?>
						</div>
                        <?php } ?>
						<div class="mission-one_donar">
							<?php if($settings['donation']){ ?><strong><?php echo wp_kses($settings['donation'], true); ?></strong><?php } ?>
							<div class="select-amount d-flex flex-wrap">
								<?php $i = 1; foreach($settings['slides'] as $key => $item):?>
                                <div class="select-box"><input type="radio" name="payment-group" id="radio-<?php echo esc_attr($i);?>" <?php if($i == 1) echo 'checked'; else echo ''; ?>><label for="radio-<?php echo esc_attr($i);?>"><?php echo esc_attr($item['counter_stop']);?></label></div>
								<?php $i++; endforeach;?>
							</div>
						</div>
						<div class="mission-one_donate-amount">
							<?php if($settings['form_title']){ ?><strong><?php echo wp_kses($settings['form_title'], true); ?></strong><?php } ?>
							<!-- Banner Form Box -->
							<div class="mission-one_form">
								<?php echo do_shortcode('[contact-form-7 id="'.esc_attr($settings['cf7_shortocde']).'"]'); ?>
							</div>
							<!-- End Banner Form Box -->
						</div>
					</div>
				</div>
			</div>
		</div>
	</section>
	<!-- End Mission One -->
    
    <?php elseif($settings['layout_control'] == 4): ?>
	
    <!-- Mission One -->
	<section class="mission-one style-two" <?php if($settings['bg_image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['bg_image']['id'])); ?>)"<?php } ?>>
		<div class="mission-one_pattern-one" <?php if($settings['pattern_image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['pattern_image']['id'])); ?>)"<?php } ?>></div>
		<div class="mission-one_pattern-two" <?php if($settings['pattern_image2']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['pattern_image2']['id'])); ?>)"<?php } ?>></div>
		<div class="auto-container">
			<div class="row clearfix">
				<!-- Image Column -->
				<div class="mission-one_title-column col-lg-6 col-md-12 col-sm-12">
					<div class="mission-one_title-inner">
						<?php if($settings['subtitle'] || $settings['title'] || $settings['text']){ ?>
                        <!-- Sec Title Two / Light -->
						<div class="sec-title_two light">
							<?php if($settings['subtitle']){ ?><div class="sec-title__tagline sec-title_two-title"><?php echo wp_kses($settings['subtitle'], true); ?></div><?php } ?>
							<?php if($settings['title']){ ?><h2 class="sec-title__title sec-title_two-heading"><?php echo wp_kses($settings['title'], true); ?></h2><?php } ?>
							<?php if($settings['text']){ ?><div class="sec-title_two-text"><?php echo wp_kses($settings['text'], true); ?></div><?php } ?>
						</div>
                        <?php } ?>
						<?php if($settings['no_text']){ ?><div class="mission-one_homeless"><?php echo wp_kses($settings['no_text'], true); ?></div><?php } ?>
						<?php if($settings['btn_title']){ ?>
                        <div class="mission-one_button">
							<a href="<?php echo esc_url($settings['btn_link']['url']);?>" class="thm-btn thm-btn--three theme-btn btn-style-three">
								<span class="btn-wrap">
                                	<span class="text-one"><?php echo wp_kses($settings['btn_title'], true);?> <i class="fas fa-arrow-right fa-fw"></i></span>
                    				<span class="text-two"><?php echo wp_kses($settings['btn_title'], true);?> <i class="fas fa-arrow-right fa-fw"></i></span>
								</span>
							</a>
						</div>
                        <?php } ?>
					</div>
				</div>
				<!-- Content Column -->
				<div class="mission-one_donate-column col-lg-6 col-md-12 col-sm-12">
					<div class="mission-one_donate-inner wow fadeInRight" data-wow-delay="0ms" data-wow-duration="1500ms">
						<?php if($settings['right_title'] || $settings['right_text']){ ?>
                        <div class="mission-one_title-box">
							<?php if($settings['right_title']){ ?><h3 class="mission-one_title-heading"><?php echo wp_kses($settings['right_title'], true); ?></h3><?php } ?>
							<?php if($settings['right_text']){ ?><div class="mission-one_text"><?php echo wp_kses($settings['right_text'], true); ?></div><?php } ?>
						</div>
                        <?php } ?>
						<div class="mission-one_donar">
							<?php if($settings['donation']){ ?><strong><?php echo wp_kses($settings['donation'], true); ?></strong><?php } ?>
							<div class="select-amount d-flex flex-wrap">
								<?php $i = 1; foreach($settings['slides'] as $key => $item):?>
                                <div class="select-box"><input type="radio" name="payment-group" id="radio-<?php echo esc_attr($i);?>" <?php if($i == 1) echo 'checked'; else echo ''; ?>><label for="radio-<?php echo esc_attr($i);?>"><?php echo esc_attr($item['counter_stop']);?></label></div>
								<?php $i++; endforeach;?>
							</div>
						</div>
						<div class="mission-one_donate-amount">
							<?php if($settings['form_title']){ ?><strong><?php echo wp_kses($settings['form_title'], true); ?></strong><?php } ?>
							<!-- Banner Form Box -->
							<div class="mission-one_form">
								<?php echo do_shortcode('[contact-form-7 id="'.esc_attr($settings['cf7_shortocde']).'"]'); ?>                                
							</div>
							<!-- End Banner Form Box -->
						</div>
					</div>
				</div>
			</div>
		</div>
	</section>
	<!-- End Mission One -->
    
	<?php elseif($settings['layout_control'] == 3): ?>
    
    <!-- Mission One / Style Two -->
	<section class="mission-one style-two" <?php if($settings['bg_image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['bg_image']['id'])); ?>)"<?php } ?>>		
		<div class="auto-container">
			<div class="row clearfix">
				<!-- Image Column -->
				<div class="mission-one_title-column col-lg-6 col-md-12 col-sm-12">
					<div class="mission-one_title-inner">
						<?php if($settings['subtitle'] || $settings['title'] || $settings['text']){ ?>
                        <!-- Sec Title Two / Light -->
						<div class="sec-title_two light">
							<?php if($settings['subtitle']){ ?><div class="sec-title__tagline sec-title_two-title"><?php echo wp_kses($settings['subtitle'], true); ?></div><?php } ?>
							<?php if($settings['title']){ ?><h2 class="sec-title__title sec-title_two-heading"><?php echo wp_kses($settings['title'], true); ?></h2><?php } ?>
							<?php if($settings['text']){ ?><div class="sec-title_two-text"><?php echo wp_kses($settings['text'], true); ?></div><?php } ?>
						</div>
                        <?php } ?>
						<?php if($settings['no_text']){ ?><div class="mission-one_homeless"><?php echo wp_kses($settings['no_text'], true); ?></div><?php } ?>
						<?php if($settings['btn_title']){ ?>
                        <div class="mission-one_button">
							<a href="<?php echo esc_url($settings['btn_link']['url']);?>" class="thm-btn thm-btn--three theme-btn btn-style-three">
								<span class="btn-wrap">
                                	<span class="text-one"><?php echo wp_kses($settings['btn_title'], true);?> <i class="fas fa-arrow-right fa-fw"></i></span>
                    				<span class="text-two"><?php echo wp_kses($settings['btn_title'], true);?> <i class="fas fa-arrow-right fa-fw"></i></span>
								</span>
							</a>
						</div>
                        <?php } ?>
					</div>
				</div>
				<!-- Content Column -->
				<div class="mission-one_donate-column col-lg-6 col-md-12 col-sm-12">
					<div class="mission-one_donate-inner wow fadeInRight" data-wow-delay="0ms" data-wow-duration="1500ms">
						<?php if($settings['right_title'] || $settings['right_text']){ ?>
                        <div class="mission-one_title-box">
							<?php if($settings['right_title']){ ?><h3 class="mission-one_title-heading"><?php echo wp_kses($settings['right_title'], true); ?></h3><?php } ?>
							<?php if($settings['right_text']){ ?><div class="mission-one_text"><?php echo wp_kses($settings['right_text'], true); ?></div><?php } ?>
						</div>
                        <?php } ?>
						<div class="mission-one_donar">
							<?php if($settings['donation']){ ?><strong><?php echo wp_kses($settings['donation'], true); ?></strong><?php } ?>
							<div class="select-amount d-flex flex-wrap">
								<?php $i = 1; foreach($settings['slides'] as $key => $item):?>
                                <div class="select-box"><input type="radio" name="payment-group" id="radio-<?php echo esc_attr($i);?>" <?php if($i == 1) echo 'checked'; else echo ''; ?>><label for="radio-<?php echo esc_attr($i);?>"><?php echo esc_attr($item['counter_stop']);?></label></div>
								<?php $i++; endforeach;?>
							</div>
						</div>
						<div class="mission-one_donate-amount">
							<?php if($settings['form_title']){ ?><strong><?php echo wp_kses($settings['form_title'], true); ?></strong><?php } ?>
							<!-- Banner Form Box -->
							<div class="mission-one_form">
								<?php echo do_shortcode('[contact-form-7 id="'.esc_attr($settings['cf7_shortocde']).'"]'); ?>                                
							</div>
							<!-- End Banner Form Box -->
						</div>
					</div>
				</div>
			</div>
		</div>
	</section>
	<!-- End Mission One / Style Two -->
    
    <?php elseif($settings['layout_control'] == 2): ?>
    
    <!-- Mission One / Style Two -->
	<section class="mission-one style-two alternate" <?php if($settings['bg_image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['bg_image']['id'])); ?>)"<?php } ?>>
		<div class="mission-one_pattern-one" <?php if($settings['pattern_image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['pattern_image']['id'])); ?>)"<?php } ?>></div>
		<div class="auto-container">
			<div class="row clearfix">
				<!-- Image Column -->
				<div class="mission-one_title-column col-lg-6 col-md-12 col-sm-12">
					<div class="mission-one_title-inner">
						<?php if($settings['subtitle'] || $settings['title'] || $settings['text']){ ?>
                        <!-- Sec Title Two / Light -->
						<div class="sec-title_two light">
							<?php if($settings['subtitle']){ ?><div class="sec-title__tagline sec-title_two-title"><?php echo wp_kses($settings['subtitle'], true); ?></div><?php } ?>
							<?php if($settings['title']){ ?><h2 class="sec-title__title sec-title_two-heading"><?php echo wp_kses($settings['title'], true); ?></h2><?php } ?>
							<?php if($settings['text']){ ?><div class="sec-title_two-text"><?php echo wp_kses($settings['text'], true); ?></div><?php } ?>
						</div>
                        <?php } ?>
						<?php if($settings['no_text']){ ?><div class="mission-one_homeless"><?php echo wp_kses($settings['no_text'], true); ?></div><?php } ?>
						<?php if($settings['btn_title']){ ?>
                        <div class="mission-one_button">
							<a href="<?php echo esc_url($settings['btn_link']['url']);?>" class="thm-btn thm-btn--three theme-btn btn-style-three">
								<span class="btn-wrap">
                                	<span class="text-one"><?php echo wp_kses($settings['btn_title'], true);?> <i class="fas fa-arrow-right fa-fw"></i></span>
                    				<span class="text-two"><?php echo wp_kses($settings['btn_title'], true);?> <i class="fas fa-arrow-right fa-fw"></i></span>
								</span>
							</a>
						</div>
                        <?php } ?>
					</div>
				</div>
				<!-- Content Column -->
				<div class="mission-one_donate-column col-lg-6 col-md-12 col-sm-12">
					<div class="mission-one_donate-inner wow fadeInRight" data-wow-delay="0ms" data-wow-duration="1500ms">
						<?php if($settings['right_title'] || $settings['right_text']){ ?>
                        <div class="mission-one_title-box">
							<?php if($settings['right_title']){ ?><h3 class="mission-one_title-heading"><?php echo wp_kses($settings['right_title'], true); ?></h3><?php } ?>
							<?php if($settings['right_text']){ ?><div class="mission-one_text"><?php echo wp_kses($settings['right_text'], true); ?></div><?php } ?>
						</div>
                        <?php } ?>
						<div class="mission-one_donar">
							<?php if($settings['donation']){ ?><strong><?php echo wp_kses($settings['donation'], true); ?></strong><?php } ?>
							<div class="select-amount d-flex flex-wrap">
								<?php $i = 1; foreach($settings['slides'] as $key => $item):?>
                                <div class="select-box"><input type="radio" name="payment-group" id="radio-<?php echo esc_attr($i);?>" <?php if($i == 1) echo 'checked'; else echo ''; ?>><label for="radio-<?php echo esc_attr($i);?>"><?php echo esc_attr($item['counter_stop']);?></label></div>
								<?php $i++; endforeach;?>
							</div>
						</div>
						<div class="mission-one_donate-amount">
							<?php if($settings['form_title']){ ?><strong><?php echo wp_kses($settings['form_title'], true); ?></strong><?php } ?>
							<!-- Banner Form Box -->
							<div class="mission-one_form">
								<?php echo do_shortcode('[contact-form-7 id="'.esc_attr($settings['cf7_shortocde']).'"]'); ?>                                
							</div>
							<!-- End Banner Form Box -->
						</div>
					</div>
				</div>
			</div>
		</div>
	</section>
	<!-- End Mission One / Style Two -->
    
    <?php else: ?>
    
    <!-- Mission One -->
	<section class="mission-one" <?php if($settings['bg_image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['bg_image']['id'])); ?>)"<?php } ?>>
		<div class="mission-one_pattern-one" <?php if($settings['pattern_image']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['pattern_image']['id'])); ?>)"<?php } ?>></div>
		<div class="mission-one_pattern-two" <?php if($settings['pattern_image2']['id']){ ?> style="background-image:url(<?php echo esc_url(wp_get_attachment_url($settings['pattern_image2']['id'])); ?>)"<?php } ?>></div>
		<div class="auto-container">
			<div class="row clearfix">
				<!-- Image Column -->
				<div class="mission-one_title-column col-lg-6 col-md-12 col-sm-12">
					<div class="mission-one_title-inner">
						<?php if($settings['subtitle'] || $settings['title'] || $settings['text']){ ?>
                        <!-- Sec Title Two / Light -->
						<div class="sec-title_two light">
							<?php if($settings['subtitle']){ ?><div class="sec-title__tagline sec-title_two-title"><?php echo wp_kses($settings['subtitle'], true); ?></div><?php } ?>
							<?php if($settings['title']){ ?><h2 class="sec-title__title sec-title_two-heading"><?php echo wp_kses($settings['title'], true); ?></h2><?php } ?>
							<?php if($settings['text']){ ?><div class="sec-title_two-text"><?php echo wp_kses($settings['text'], true); ?></div><?php } ?>
						</div>
                        <?php } ?>
						<?php if($settings['no_text']){ ?><div class="mission-one_homeless"><?php echo wp_kses($settings['no_text'], true); ?></div><?php } ?>
						<?php if($settings['btn_title']){ ?>
                        <div class="mission-one_button">
							<a href="<?php echo esc_url($settings['btn_link']['url']);?>" class="thm-btn thm-btn--three theme-btn btn-style-three">
								<span class="btn-wrap">
                                	<span class="text-one"><?php echo wp_kses($settings['btn_title'], true);?> <i class="fas fa-arrow-right fa-fw"></i></span>
                    				<span class="text-two"><?php echo wp_kses($settings['btn_title'], true);?> <i class="fas fa-arrow-right fa-fw"></i></span>
								</span>
							</a>
						</div>
                        <?php } ?>
					</div>
				</div>
				<!-- Content Column -->
				<div class="mission-one_donate-column col-lg-6 col-md-12 col-sm-12">
					<div class="mission-one_donate-inner wow fadeInRight" data-wow-delay="0ms" data-wow-duration="1500ms">
						<?php if($settings['right_title'] || $settings['right_text']){ ?>
                        <div class="mission-one_title-box">
							<?php if($settings['right_title']){ ?><h3 class="mission-one_title-heading"><?php echo wp_kses($settings['right_title'], true); ?></h3><?php } ?>
							<?php if($settings['right_text']){ ?><div class="mission-one_text"><?php echo wp_kses($settings['right_text'], true); ?></div><?php } ?>
						</div>
                        <?php } ?>
						<div class="mission-one_donar">
							<?php if($settings['donation']){ ?><strong><?php echo wp_kses($settings['donation'], true); ?></strong><?php } ?>
							<div class="select-amount d-flex flex-wrap">
								<?php $i = 1; foreach($settings['slides'] as $key => $item):?>
                                <div class="select-box"><input type="radio" name="payment-group" id="radio-<?php echo esc_attr($i);?>" <?php if($i == 1) echo 'checked'; else echo ''; ?>><label for="radio-<?php echo esc_attr($i);?>"><?php echo esc_attr($item['counter_stop']);?></label></div>
								<?php $i++; endforeach;?>
							</div>
						</div>
						<div class="mission-one_donate-amount">
							<?php if($settings['form_title']){ ?><strong><?php echo wp_kses($settings['form_title'], true); ?></strong><?php } ?>
							<!-- Banner Form Box -->
							<div class="mission-one_form">
								<?php echo do_shortcode('[contact-form-7 id="'.esc_attr($settings['cf7_shortocde']).'"]'); ?>                                
							</div>
							<!-- End Banner Form Box -->
						</div>
					</div>
				</div>
			</div>
		</div>
	</section>
	<!-- End Mission One -->
    
    <?php endif; ?>
        <?php 
	}
}